@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2012 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2013 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -24,11 +24,13 @@
 #ifndef GNOME_MEDIA_KEYS_H
 #define GNOME_MEDIA_KEYS_H
 
-#include <QtCore/QObject>
+#include <QObject>
 
+class OrgGnomeSettingsDaemonInterface;
 class OrgGnomeSettingsDaemonMediaKeysInterface;
 class QDBusPendingCallWatcher;
 class MainWindow;
+class QDBusServiceWatcher;
 
 class GnomeMediaKeys : public QObject
 {
@@ -38,13 +40,24 @@ public:
     GnomeMediaKeys(MainWindow *parent);
 
     void setEnabled(bool en);
+
+private:
+    bool daemonIsRunning();
+    void releaseKeys();
+    void grabKeys();
+    void disconnectDaemon();
+
 private Q_SLOTS:
+    void serviceOwnerChanged(const QString &name, const QString &oldOwner, const QString &newOwner);
     void registerFinished(QDBusPendingCallWatcher *watcher);
     void keyPressed(const QString &app, const QString &key);
+    void pluginActivated(const QString &name);
 
 private:
     MainWindow *mw;
-    OrgGnomeSettingsDaemonMediaKeysInterface *iface;
+    OrgGnomeSettingsDaemonInterface *daemon;
+    OrgGnomeSettingsDaemonMediaKeysInterface *mk;
+    QDBusServiceWatcher *watcher;
 };
 
 #endif
