@@ -29,6 +29,7 @@
 #include "devicepropertieswidget.h"
 #include "settings.h"
 #include "musiclibrarymodel.h"
+#include "musiclibraryproxymodel.h"
 #include "dirviewmodel.h"
 #include "albumsmodel.h"
 #include "mpdparseutils.h"
@@ -40,10 +41,14 @@
 #include "freespaceinfo.h"
 #include "icons.h"
 #include "config.h"
-#ifdef ENABLE_ONLINE_SERVICES
+#include "tags.h"
+#include "treeview.h"
 #include "onlineservicesmodel.h"
+#ifdef ENABLE_REPLAYGAIN_SUPPORT
+#include "rgdialog.h"
 #endif
 #include <QFile>
+#include <QDebug>
 
 static int iCount=0;
 
@@ -60,24 +65,53 @@ enum Pages
     PAGE_PROGRESS
 };
 
+class SongDialog : public Dialog
+{
+public:
+    SongDialog(ActionDialog *p)
+        : Dialog(p) {
+        setCaption(i18n("Songs To Be Copied"));
+        setButtons(Close);
+        MusicLibraryModel *model=new MusicLibraryModel(this, false);
+        MusicLibraryProxyModel *proxy=new MusicLibraryProxyModel(this);
+        proxy->setSourceModel(model);
+        model->setUseAlbumImages(false);
+        model->setUseArtistImages(false);
+        model->setSupportsAlbumArtistTag(true);
+        TreeView *view=new TreeView(this);
+        view->setPageDefaults();
+        view->setExpandOnClick();
+        view->setModel(proxy);
+        view->setUseSimpleDelegate();
+        model->update(p->songsToAction.toSet());
+        setMainWidget(view);
+        int size=fontMetrics().height();
+        int numArtists=model->rowCount();
+        resize(20*size, qMin(qMax(10, numArtists)+4, 25)*(size*1.25));
+    }
+};
+
 ActionDialog::ActionDialog(QWidget *parent)
     : Dialog(parent)
     , mpdConfigured(false)
     , currentDev(0)
+    , songDialog(0)
 {
     iCount++;
     setButtons(Ok|Cancel);
+    setDefaultButton(Cancel);
     setAttribute(Qt::WA_DeleteOnClose);
     QWidget *mainWidet = new QWidget(this);
     setupUi(mainWidet);
     setMainWidget(mainWidet);
     errorIcon->setPixmap(QIcon::fromTheme("dialog-error").pixmap(64, 64));
     skipIcon->setPixmap(QIcon::fromTheme("dialog-warning").pixmap(64, 64));
-    configureSourceButton->setIcon(Icons::configureIcon);
-    configureDestButton->setIcon(Icons::configureIcon);
+    configureSourceButton->setIcon(Icons::self()->configureIcon);
+    configureDestButton->setIcon(Icons::self()->configureIcon);
     connect(configureSourceButton, SIGNAL(clicked()), SLOT(configureSource()));
     connect(configureDestButton, SIGNAL(clicked()), SLOT(configureDest()));
     connect(this, SIGNAL(update()), MPDConnection::self(), SLOT(update()));
+    connect(songCount, SIGNAL(leftClickedUrl()), SLOT(showSongs()));
 }
 
 ActionDialog::~ActionDialog()
@@ -88,7 +122,7 @@ ActionDialog::~ActionDialog()
 void ActionDialog::controlInfoLabel(Device *dev)
 {
     DeviceOptions opts;
-    if (Device::AudioCd==dev->devType()) {
+    if (sourceIsAudioCd) {
         opts.load(MPDConnectionDetails::configGroupName(MPDConnection::self()->getDetails().name), true);
     } else if (sourceUdi.isEmpty()) {
         opts=dev->options();
@@ -116,14 +150,44 @@ void ActionDialog::controlInfoLabel(Device *dev)
                 index++;
             }
             codec->setText(QString("%1 (%2)").arg(encoder.name).arg(encoder.values.at(settingIndex).descr)+
-                           (Device::AudioCd!=dev->devType() && opts.transcoderWhenDifferent ? QLatin1String("")+i18n("<i>(When different)</i>") : QString()));
+                           (sourceIsAudioCd && opts.transcoderWhenDifferent ? QLatin1String("")+i18n("<i>(When different)</i>") : QString()));
         } else {
             codec->setText(encoder.name+
-                           (Device::AudioCd!=dev->devType() && opts.transcoderWhenDifferent ? QLatin1String("")+i18n("<i>(When different)</i>") : QString()));
+                           (sourceIsAudioCd && opts.transcoderWhenDifferent ? QLatin1String("")+i18n("<i>(When different)</i>") : QString()));
         }
     }
 }
 
+void ActionDialog::showSongs()
+{
+    if (!songDialog) {
+        songDialog=new SongDialog(this);
+    }
+    songDialog->show();
+}
+
+void ActionDialog::hideSongs()
+{
+    if (songDialog) {
+        songDialog->setVisible(false);
+        songDialog->deleteLater();
+        songDialog=0;
+    }
+}
+
+void ActionDialog::updateSongCountLabel()
+{
+    QSet<QString> artists;
+    QSet<QString> albums;
+
+    foreach (const Song &s, songsToAction) {
+        artists.insert(s.albumArtist());
+        albums.insert(s.albumArtist()+"--"+s.album);
+    }
+
+    songCount->setText(i18n("Artists:%1, Albums:%2, Songs:%3", artists.count(), albums.count(), songsToAction.count()));
+}
+
 void ActionDialog::controlInfoLabel()
 {
     controlInfoLabel(getDevice(sourceUdi.isEmpty() ? destUdi : sourceUdi));
@@ -139,6 +203,7 @@ void ActionDialog::copy(const QString &srcUdi, const QString &dstUdi, const QLis
         return;
     }
 
+    sourceIsAudioCd=Device::AudioCd==dev->devType();
     controlInfoLabel(dev);
 
     // check space...
@@ -172,7 +237,7 @@ void ActionDialog::copy(const QString &srcUdi, const QString &dstUdi, const QLis
         FreeSpaceInfo inf=FreeSpaceInfo(MPDConnection::self()->getDetails().dir);
         spaceAvailable=inf.size()-inf.used();
         usedCapacity=(inf.used()*1.0)/(inf.size()*1.0);
-        capacityString=i18n("%1 free").arg(Utils::formatByteSize(inf.size()-inf.used()));
+        capacityString=i18n("%1 free", Utils::formatByteSize(inf.size()-inf.used()));
     }
 
     bool enoughSpace=spaceAvailable>spaceRequired;
@@ -186,7 +251,7 @@ void ActionDialog::copy(const QString &srcUdi, const QString &dstUdi, const QLis
         overwrite->setChecked(Settings::self()->overwriteSongs());
         sourceLabel->setText(QLatin1String("<b>")+(sourceUdi.isEmpty()
                                 ? i18n("Local Music Library")
-                                : Device::AudioCd==dev->devType()
+                                : sourceIsAudioCd
                                     ? i18n("Audio CD")
                                     : dev->data())+QLatin1String("</b>"));
         destinationLabel->setText(QLatin1String("<b>")+(destUdi.isEmpty() ? i18n("Local Music Library") : dev->data())+QLatin1String("</b>"));
@@ -203,19 +268,24 @@ void ActionDialog::copy(const QString &srcUdi, const QString &dstUdi, const QLis
         //configureSourceLabel->setVisible(!isFromOnline && ((!destIsDev && !dev->isConfigured()) || (destIsDev && !mpdConfigured)));
         configureSourceButton->setVisible(false);
         configureSourceLabel->setVisible(false);
+        songCount->setVisible(!sourceIsAudioCd);
+        songCountLabel->setVisible(!sourceIsAudioCd);
+        if (!sourceIsAudioCd) {
+            updateSongCountLabel();
+        }
         show();
         if (!enoughSpace) {
             MessageBox::information(this, i18n("There is insufficient space left on the destination device.\n"
                                                "The selected songs consume %1, but there is only %2 left.\n"
-                                               "The songs will need to be transcoded to a smaller filesize in order to be successfully copied.")
-                                               .arg(Utils::formatByteSize(spaceRequired))
-                                               .arg(Utils::formatByteSize(spaceAvailable)));
+                                               "The songs will need to be transcoded to a smaller filesize in order to be successfully copied.",
+                                               Utils::formatByteSize(spaceRequired),
+                                               Utils::formatByteSize(spaceAvailable)));
         }
     } else {
         MessageBox::error(parentWidget(), i18n("There is insufficient space left on the destination.\n"
-                                               "The selected songs consume %1, but there is only %2 left.")
-                                               .arg(Utils::formatByteSize(spaceRequired))
-                                               .arg(Utils::formatByteSize(spaceAvailable)));
+                                               "The selected songs consume %1, but there is only %2 left.",
+                                               Utils::formatByteSize(spaceRequired),
+                                               Utils::formatByteSize(spaceAvailable)));
         deleteLater();
     }
 }
@@ -225,6 +295,8 @@ void ActionDialog::remove(const QString &udi, const QList<Song> &songs)
     init(udi, QString(), songs, Remove);
     codecLabel->setVisible(false);
     codec->setVisible(false);
+    songCountLabel->setVisible(false);
+    songCount->setVisible(false);
     QString baseDir;
 
     if (udi.isEmpty()) {
@@ -245,6 +317,9 @@ void ActionDialog::remove(const QString &udi, const QList<Song> &songs)
         dirsToClean.insert(baseDir+Utils::getDir(s.file));
     }
     show();
+    #ifdef ACTION_DIALOG_SHOW_TIME_REMAINING
+    timer.start();
+    #endif
     doNext();
 }
 
@@ -253,6 +328,7 @@ void ActionDialog::init(const QString &srcUdi, const QString &dstUdi, const QLis
     resize(500, 160);
     sourceUdi=srcUdi;
     destUdi=dstUdi;
+    sourceIsAudioCd=false;
     songsToAction=songs;
     mode=m;
     setCaption(Copy==mode ? i18n("Copy Songs") : i18n("Delete Songs"));
@@ -272,6 +348,9 @@ void ActionDialog::init(const QString &srcUdi, const QString &dstUdi, const QLis
     currentPercent=0;
     currentDev=0;
     count=0;
+    #ifdef ENABLE_REPLAYGAIN_SUPPORT
+    albumsWithoutRgTags.clear();
+    #endif
 }
 
 void ActionDialog::slotButtonClicked(int button)
@@ -283,14 +362,17 @@ void ActionDialog::slotButtonClicked(int button)
             if (haveVariousArtists &&
                 ((configureDestLabel->isVisible() && sourceUdi.isEmpty() && // Only warn if copying FROM library
                   MessageBox::No==MessageBox::warningYesNo(this, i18n("<p>You have not configured the destination device.<br/>"
-                                                                      "Continue with the default settings?</p>"))) ||
+                                                                      "Continue with the default settings?</p>"), i18n("Not Configured"),
+                                                           GuiItem(i18n("Use Defaults")), StdGuiItem::cancel())) ||
                  (configureSourceLabel->isVisible() && !sourceUdi.isEmpty() && // Only warn if copying TO library
                   MessageBox::No==MessageBox::warningYesNo(this, i18n("<p>You have not configured the source device.<br/>"
-                                                                      "Continue with the default settings?</p>"))))) {
+                                                                      "Continue with the default settings?</p>"), i18n("Not Configured"),
+                                                           GuiItem(i18n("Use Defaults")), StdGuiItem::cancel())) ) ) {
                 return;
             }
             Settings::self()->saveOverwriteSongs(overwrite->isChecked());
             setPage(PAGE_PROGRESS);
+            hideSongs();
             #ifdef ACTION_DIALOG_SHOW_TIME_REMAINING
             timer.start();
             #endif
@@ -345,7 +427,8 @@ void ActionDialog::slotButtonClicked(int button)
         break;
     case PAGE_PROGRESS:
         paused=true;
-        if (MessageBox::Yes==MessageBox::questionYesNo(this, i18n("Are you sure you wish to cancel?"))) {
+        if (MessageBox::Yes==MessageBox::questionYesNo(this, i18n("Are you sure you wish to stop?"), i18n("Stop"),
+                                                       StdGuiItem::stop(), StdGuiItem::cont())) {
             Device *dev=0;
             if(Copy==mode) {
                 dev=getDevice(sourceUdi.isEmpty() ? destUdi : sourceUdi, false);
@@ -376,11 +459,9 @@ void ActionDialog::slotButtonClicked(int button)
 
 Device * ActionDialog::getDevice(const QString &udi, bool logErrors)
 {
-    #ifdef ENABLE_ONLINE_SERVICES
     if (udi.startsWith(OnlineServicesModel::constUdiPrefix)) {
         return OnlineServicesModel::self()->device(udi);
     }
-    #endif
     Device *dev=DevicesModel::self()->device(udi);
 
     if (!logErrors) {
@@ -474,6 +555,25 @@ void ActionDialog::doNext()
         if (!refreshLibrary()) {
             emit completed();
             accept();
+            #ifdef ENABLE_REPLAYGAIN_SUPPORT
+            if (Copy==mode && !albumsWithoutRgTags.isEmpty() && sourceIsAudioCd) {
+                QWidget *pw=parentWidget();
+                if (MessageBox::Yes==MessageBox::questionYesNo(pw, i18n("Calculate ReplayGain for ripped tracks?"), i18n("ReplyGain"),
+                                                               GuiItem(i18n("Calculate")), StdGuiItem::no())) {
+                    RgDialog *dlg=new RgDialog(pw);
+                    QList<Song> songs;
+
+                    foreach (const Song &s, actionedSongs) {
+                        if (albumsWithoutRgTags.contains(s.album)) {
+                            Song song=s;
+                            song.file=namingOptions.createFilename(s);
+                            songs.append(song);
+                        }
+                    }
+                    dlg->show(songs, QString(), true);
+                }
+            }
+            #endif
         }
     }
 }
@@ -499,6 +599,11 @@ void ActionDialog::actionStatus(int status, bool copiedCover)
                 #ifdef ACTION_DIALOG_SHOW_TIME_REMAINING
                 actionedTime+=currentSong.time;
                 #endif
+                #ifdef ENABLE_REPLAYGAIN_SUPPORT
+                if (Copy==mode && sourceIsAudioCd && !albumsWithoutRgTags.contains(currentSong.album) && Tags::readReplaygain(destFile).isEmpty()) {
+                    albumsWithoutRgTags.insert(currentSong.album);
+                }
+                #endif
             }
             if (copiedCover) {
                 copiedCovers.insert(Utils::getDir(destFile));
@@ -510,56 +615,56 @@ void ActionDialog::actionStatus(int status, bool copiedCover)
         }
         break;
     case Device::FileExists:
-        setPage(PAGE_SKIP, i18n("The destination filename already exists!<hr/>%1").arg(formatSong(currentSong, true)));
+        setPage(PAGE_SKIP, i18n("The destination filename already exists!<hr/>%1", formatSong(currentSong, true)));
         break;
     case Device::SongExists:
-        setPage(PAGE_SKIP, i18n("Song already exists!<hr/>%1").arg(formatSong(currentSong)));
+        setPage(PAGE_SKIP, i18n("Song already exists!<hr/>%1", formatSong(currentSong)));
         break;
     case Device::SongDoesNotExist:
-        setPage(PAGE_SKIP, i18n("Song does not exist!<hr/>%1").arg(formatSong(currentSong)));
+        setPage(PAGE_SKIP, i18n("Song does not exist!<hr/>%1", formatSong(currentSong)));
         break;
     case Device::DirCreationFaild:
-        setPage(PAGE_SKIP, i18n("Failed to create destination folder!<br/>Please check you have sufficient permissions.<hr/>%1").arg(formatSong(currentSong, true)));
+        setPage(PAGE_SKIP, i18n("Failed to create destination folder!<br/>Please check you have sufficient permissions.<hr/>%1", formatSong(currentSong, true)));
         break;
     case Device::SourceFileDoesNotExist:
-        setPage(PAGE_SKIP, i18n("Source file no longer exists?<br/><br/<hr/>%1").arg(formatSong(currentSong, true)));
+        setPage(PAGE_SKIP, i18n("Source file no longer exists?<br/><br/<hr/>%1", formatSong(currentSong, true)));
         break;
     case Device::Failed:
-        setPage(PAGE_SKIP, Copy==mode ? i18n("Failed to copy.<hr/>%1").arg(formatSong(currentSong))
-                                      : i18n("Failed to delete.<hr/>%1").arg(formatSong(currentSong)));
+        setPage(PAGE_SKIP, Copy==mode ? i18n("Failed to copy.<hr/>%1", formatSong(currentSong))
+                                      : i18n("Failed to delete.<hr/>%1", formatSong(currentSong)));
         break;
     case Device::NotConnected:
-        setPage(PAGE_ERROR, i18n("Not connected to device.<hr/>%1").arg(formatSong(currentSong)));
+        setPage(PAGE_ERROR, i18n("Not connected to device.<hr/>%1", formatSong(currentSong)));
         break;
     case Device::CodecNotAvailable:
-        setPage(PAGE_ERROR, i18n("Selected codec is not available.<hr/>%1").arg(formatSong(currentSong)));
+        setPage(PAGE_ERROR, i18n("Selected codec is not available.<hr/>%1", formatSong(currentSong)));
         break;
     case Device::TranscodeFailed:
-        setPage(PAGE_SKIP, i18n("Transcoding failed.<br/><br/<hr/>%1").arg(formatSong(currentSong)));
+        setPage(PAGE_SKIP, i18n("Transcoding failed.<br/><br/<hr/>%1", formatSong(currentSong)));
         break;
     case Device::FailedToCreateTempFile:
-        setPage(PAGE_ERROR, i18n("Failed to create temporary file.<br/>(Required for transcoding to MTP devices.)<hr/>%1").arg(formatSong(currentSong)));
+        setPage(PAGE_ERROR, i18n("Failed to create temporary file.<br/>(Required for transcoding to MTP devices.)<hr/>%1", formatSong(currentSong)));
         break;
     case Device::ReadFailed:
-        setPage(PAGE_SKIP, i18n("Failed to read source file.<br/><br/<hr/>%1").arg(formatSong(currentSong)));
+        setPage(PAGE_SKIP, i18n("Failed to read source file.<br/><br/<hr/>%1", formatSong(currentSong)));
         break;
     case Device::WriteFailed:
-        setPage(PAGE_SKIP, i18n("Failed to write to destination file.<br/><br/<hr/>%1").arg(formatSong(currentSong)));
+        setPage(PAGE_SKIP, i18n("Failed to write to destination file.<br/><br/<hr/>%1", formatSong(currentSong)));
         break;
     case Device::NoSpace:
-        setPage(PAGE_SKIP, i18n("No space left on device.<br/><br/<hr/>%1").arg(formatSong(currentSong)));
+        setPage(PAGE_SKIP, i18n("No space left on device.<br/><br/<hr/>%1", formatSong(currentSong)));
         break;
     case Device::FailedToUpdateTags:
-        setPage(PAGE_SKIP, i18n("Failed to update metadata.<br/><br/<hr/>%1").arg(formatSong(currentSong)));
+        setPage(PAGE_SKIP, i18n("Failed to update metadata.<br/><br/<hr/>%1", formatSong(currentSong)));
         break;
     case Device::TooManyRedirects:
-        setPage(PAGE_SKIP, i18n("Failed to download track - too many redirects encountered.<br/><br/<hr/>%1").arg(formatSong(currentSong)));
+        setPage(PAGE_SKIP, i18n("Failed to download track - too many redirects encountered.<br/><br/<hr/>%1", formatSong(currentSong)));
         break;
     case Device::DownloadFailed:
-        setPage(PAGE_SKIP, i18n("Failed to download track.<br/><br/<hr/>%1").arg(formatSong(currentSong)));
+        setPage(PAGE_SKIP, i18n("Failed to download track.<br/><br/<hr/>%1", formatSong(currentSong)));
         break;
     case Device::FailedToLockDevice:
-        setPage(PAGE_ERROR, i18n("Failed to lock device.<hr/>%1").arg(formatSong(currentSong)));
+        setPage(PAGE_ERROR, i18n("Failed to lock device.<hr/>%1", formatSong(currentSong)));
         break;
     case Device::Cancelled:
         break;
@@ -583,18 +688,13 @@ void ActionDialog::configureSource()
 void ActionDialog::configure(const QString &udi)
 {
     if (udi.isEmpty()) {
-        Device *dev=DevicesModel::self()->device(sourceUdi);
-        bool isCd=false;
-        if (dev) {
-            isCd=Device::AudioCd==dev->devType();
-        }
         DevicePropertiesDialog *dlg=new DevicePropertiesDialog(this);
         connect(dlg, SIGNAL(updatedSettings(const QString &, const DeviceOptions &)), SLOT(saveProperties(const QString &, const DeviceOptions &)));
         if (!mpdConfigured) {
             connect(dlg, SIGNAL(cancelled()), SLOT(saveProperties()));
         }
         dlg->setCaption(i18n("Local Music Library Properties"));
-        dlg->show(MPDConnection::self()->getDetails().dir, namingOptions, DevicePropertiesWidget::Prop_Basic|(isCd ? DevicePropertiesWidget::Prop_Encoder : 0));
+        dlg->show(MPDConnection::self()->getDetails().dir, namingOptions, DevicePropertiesWidget::Prop_Basic|(sourceIsAudioCd ? DevicePropertiesWidget::Prop_Encoder : 0));
         connect(dlg, SIGNAL(destroyed()), SLOT(controlInfoLabel()));
     } else {
         Device *dev=DevicesModel::self()->device(udi);
@@ -608,24 +708,14 @@ void ActionDialog::configure(const QString &udi)
 void ActionDialog::saveProperties(const QString &path, const DeviceOptions &opts)
 {
     Q_UNUSED(path)
-    Device *dev=DevicesModel::self()->device(sourceUdi);
-    bool isCd=false;
-    if (dev) {
-        isCd=Device::AudioCd==dev->devType();
-    }
     namingOptions=opts;
-    namingOptions.save(MPDConnectionDetails::configGroupName(MPDConnection::self()->getDetails().name), true, isCd);
+    namingOptions.save(MPDConnectionDetails::configGroupName(MPDConnection::self()->getDetails().name), true, sourceIsAudioCd);
     mpdConfigured=true;
 }
 
 void ActionDialog::saveProperties()
 {
-    Device *dev=DevicesModel::self()->device(sourceUdi);
-    bool isCd=false;
-    if (dev) {
-        isCd=Device::AudioCd==dev->devType();
-    }
-    namingOptions.save(MPDConnectionDetails::configGroupName(MPDConnection::self()->getDetails().name), true, isCd);
+    namingOptions.save(MPDConnectionDetails::configGroupName(MPDConnection::self()->getDetails().name), true, sourceIsAudioCd);
     mpdConfigured=true;
 }
 
@@ -670,37 +760,33 @@ QString ActionDialog::formatSong(const Song &s, bool showFiles, bool showTime)
     QString str("<table>");
     str+=i18n("<tr><td align=\"right\">Artist:</td><td>%1</td></tr>"
               "<tr><td align=\"right\">Album:</td><td>%2</td></tr>"
-              "<tr><td align=\"right\">Track:</td><td>%3</td></tr>")
-              .arg(s.albumArtist())
-              .arg(s.album)
-              .arg(s.trackAndTitleStr(Song::isVariousArtists(s.albumArtist()) && !Song::isVariousArtists(s.artist)));
+              "<tr><td align=\"right\">Track:</td><td>%3</td></tr>",
+              s.albumArtist(), s.album, s.trackAndTitleStr(Song::isVariousArtists(s.albumArtist()) && !Song::isVariousArtists(s.artist)));
 
     if (showFiles) {
         if (Copy==mode) {
             str+=i18n("<tr><td align=\"right\">Source file:</td><td>%1</td></tr>"
-                      "<tr><td align=\"right\">Destination file:</td><td>%2</td></tr>")
-                      .arg(DevicesModel::fixDevicePath(s.file))
-                      .arg(DevicesModel::fixDevicePath(destFile));
+                      "<tr><td align=\"right\">Destination file:</td><td>%2</td></tr>",
+                      DevicesModel::fixDevicePath(s.file), DevicesModel::fixDevicePath(destFile));
 
         } else {
-            str+=i18n("<tr><td align=\"right\">File:</td><td>%1</td></tr>")
-                      .arg(DevicesModel::fixDevicePath(s.file));
+            str+=i18n("<tr><td align=\"right\">File:</td><td>%1</td></tr>", DevicesModel::fixDevicePath(s.file));
         }
     }
 
     #ifdef ACTION_DIALOG_SHOW_TIME_REMAINING
     if (showTime) {
-        QString estimate=i18n("Unknown");
-
+        QString estimate=i18n("Calculating...");
         double taken=timeTaken+timer.elapsed();
         if (taken>5.0) {
-            double percent=(actionedTime+(currentPercent*currentSong.time))/totalTime;
+            double pc=(progressBar->value()*1.0)/(progressBar->maximum()*1.0);
+            double percent=Copy==mode ? (actionedTime+(currentPercent*0.01*currentSong.time))/totalTime : pc;
+            percent-=percent*((1.0-percent)*0.15);
             quint64 timeRemaining=((taken/percent)-taken)/1000.0;
-            estimate=i18nc("time (EStimated)", "%1 (Estimated)").arg(Song::formattedTime(timeRemaining>0 ? timeRemaining : 0));
+            estimate=i18nc("time (Estimated)", "%1 (Estimated)", Song::formattedTime(timeRemaining>0 ? timeRemaining : 0));
         }
 
-        str+=i18n("<tr><i><td align=\"right\"><i>Time remaining:</i></td><td><i>%5</i></td></i></tr>")
-                .arg(estimate);
+        str+=i18n("<tr><i><td align=\"right\"><i>Time remaining:</i></td><td><i>%5</i></td></i></tr>", estimate);
     }
     #else
     Q_UNUSED(showTime)
@@ -773,22 +859,19 @@ void ActionDialog::cleanDirsResult(int status)
 
 void ActionDialog::jobPercent(int percent)
 {
-    progressBar->setValue((100*count)+percent);
-    currentPercent=percent/100.00;
-    if (PAGE_PROGRESS==stack->currentIndex()) {
-        progressLabel->setText(formatSong(currentSong, false, true));
+    if (percent!=currentPercent) {
+        progressBar->setValue((100*count)+percent);
+        currentPercent=percent;
+        if (PAGE_PROGRESS==stack->currentIndex()) {
+            progressLabel->setText(formatSong(currentSong, false, true));
+        }
     }
 }
 
 void ActionDialog::incProgress()
 {
-    if (Copy==mode) {
-        count++;
-        progressBar->setValue(100*count);
-    } else {
-        int val=progressBar->value()+100;
-        progressBar->setValue(val<=progressBar->maximum() ? val : progressBar->maximum());
-    }
+    count++;
+    progressBar->setValue(100*count);
 }
 
 void ActionDialog::cacheSaved()
