@@ -25,7 +25,7 @@
 #define CDDBSELECTIONDIALOG_H
 
 #include "dialog.h"
-#include "cddb.h"
+#include "cdalbum.h"
 #include <QList>
 
 class QComboBox;
