@@ -24,50 +24,51 @@
 #include "filejob.h"
 #include "utils.h"
 #include "device.h"
-#include "lyricspage.h"
+#include "songview.h"
 #include "covers.h"
 #include "thread.h"
 #include <QFile>
 #include <QTimer>
 #include <QTemporaryFile>
+#include <QDebug>
 
 #ifdef ENABLE_KDE_SUPPORT
 #include <KDE/KGlobal>
-K_GLOBAL_STATIC(FileScheduler, instance)
+K_GLOBAL_STATIC(FileThread, instance)
 #endif
 
-FileScheduler * FileScheduler::self()
+FileThread * FileThread::self()
 {
     #ifdef ENABLE_KDE_SUPPORT
     return instance;
     #else
-    static FileScheduler *instance=0;
+    static FileThread *instance=0;
     if(!instance) {
-        instance=new FileScheduler;
+        instance=new FileThread;
     }
     return instance;
     #endif
 }
 
-FileScheduler::FileScheduler()
+FileThread::FileThread()
     : thread(0)
 {
 }
 
-void FileScheduler::addJob(FileJob *job)
+void FileThread::addJob(FileJob *job)
 {
     if (!thread) {
         thread=new Thread(metaObject()->className());
-        moveToThread(thread);
         thread->start();
     }
     job->moveToThread(thread);
 }
 
-void FileScheduler::stop()
+void FileThread::stop()
 {
     if (thread) {
         thread->stop();
+        thread=0;
     }
 }
 
@@ -75,7 +76,7 @@ FileJob::FileJob()
     : stopRequested(false)
     , progressPercent(0)
 {
-    FileScheduler::self()->addJob(this);
+    FileThread::self()->addJob(this);
     // Cant call deleteLater here, as in the device's xxResult() slots "sender()" returns
     // null. Therefore, xxResult() slots need to call finished()
     //connect(this, SIGNAL(result(int)), SLOT(deleteLater()));
@@ -226,7 +227,7 @@ void DeleteJob::run()
 {
     int status=QFile::remove(fileName) ? Device::Ok : Device::Failed;
     if (remLyrics && Device::Ok==status) {
-        QString lyrics=Utils::changeExtension(fileName, LyricsPage::constExtension);
+        QString lyrics=Utils::changeExtension(fileName, SongView::constExtension);
         if (lyrics!=fileName) {
             QFile::remove(lyrics);
         }
