@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2012 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2013 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -24,9 +24,9 @@
 #ifndef MOUNTPOINTS_H
 #define MOUNTPOINTS_H
 
-#include <QtCore/QObject>
-#include <QtCore/QSet>
-#include <QtCore/QString>
+#include <QObject>
+#include <QSet>
+#include <QString>
 
 class QFile;
 
