@@ -118,7 +118,7 @@ static inline bool isMountable(const RemoteFsDevice::Details &d)
            RemoteFsDevice::constSambaProtocol==d.url.scheme() || RemoteFsDevice::constSambaAvahiProtocol==d.url.scheme();
 }
 
-QList<Device *> RemoteFsDevice::loadAll(DevicesModel *m)
+QList<Device *> RemoteFsDevice::loadAll(MusicModel *m)
 {
     QList<Device *> devices;
     #ifdef ENABLE_KDE_SUPPORT
@@ -142,7 +142,7 @@ QList<Device *> RemoteFsDevice::loadAll(DevicesModel *m)
     return devices;
 }
 
-Device * RemoteFsDevice::create(DevicesModel *m, const DeviceOptions &options, const Details &d)
+Device * RemoteFsDevice::create(MusicModel *m, const DeviceOptions &options, const Details &d)
 {
     if (d.isEmpty()) {
         return 0;
@@ -176,7 +176,7 @@ void RemoteFsDevice::destroy(bool removeFromConfig)
         QStringList names=GET_STRINGLIST(constCfgKey, QStringList());
         if (names.contains(details.name)) {
             names.removeAll(details.name);
-            REMOVE_GROUP(udi());
+            REMOVE_GROUP(id());
             SET_VALUE(constCfgKey, names);
             CFG_SYNC;
         }
@@ -237,7 +237,7 @@ void RemoteFsDevice::renamed(const QString &oldName, const QString &newName)
     CFG_SYNC;
 }
 
-RemoteFsDevice::RemoteFsDevice(DevicesModel *m, const DeviceOptions &options, const Details &d)
+RemoteFsDevice::RemoteFsDevice(MusicModel *m, const DeviceOptions &options, const Details &d)
     : FsDevice(m, d.name, createUdi(d.name))
     , mountToken(0)
     , currentMountStatus(false)
@@ -250,9 +250,10 @@ RemoteFsDevice::RemoteFsDevice(DevicesModel *m, const DeviceOptions &options, co
 //    details.path=Utils::fixPath(details.path);
     load();
     mount();
+    icn=Icon(details.isLocalFile() ? "inode-directory" : (constSshfsProtocol==details.url.scheme() ? "utilities-terminal" : "network-server"));
 }
 
-RemoteFsDevice::RemoteFsDevice(DevicesModel *m, const Details &d)
+RemoteFsDevice::RemoteFsDevice(MusicModel *m, const Details &d)
     : FsDevice(m, d.name, createUdi(d.name))
     , mountToken(0)
     , currentMountStatus(false)
@@ -263,6 +264,7 @@ RemoteFsDevice::RemoteFsDevice(DevicesModel *m, const Details &d)
 {
 //    details.path=Utils::fixPath(details.path);
     setup();
+    icn=Icon(details.isLocalFile() ? "inode-directory" : (constSshfsProtocol==details.url.scheme() ? "utilities-terminal" : "network-server"));
 }
 
 RemoteFsDevice::~RemoteFsDevice() {
@@ -310,7 +312,7 @@ void RemoteFsDevice::mount()
         Details det=details;
         AvahiService *srv=Avahi::self()->getService(det.serviceName);
         if (!srv || srv->getHost().isEmpty() || 0==srv->getPort()) {
-            emit error(i18n("Failed to resolve connection details for %1").arg(details.name));
+            emit error(i18n("Failed to resolve connection details for %1", details.name));
             return;
         }
         if (constPromptPassword==det.url.password()) {
@@ -381,7 +383,7 @@ void RemoteFsDevice::mount()
         cmd=Utils::findExe("sshfs");
         if (!cmd.isEmpty()) {
             if (!QDir(mountPoint(details, true)).entryList(QDir::NoDot|QDir::NoDotDot|QDir::AllEntries|QDir::Hidden).isEmpty()) {
-                emit error(i18n("Mount point (\"%1\") is not empty!").arg(mountPoint(details, true)));
+                emit error(i18n("Mount point (\"%1\") is not empty!", mountPoint(details, true)));
                 return;
             }
 
@@ -456,19 +458,19 @@ void RemoteFsDevice::procFinished(int exitCode)
     proc=0;
 
     if (0!=exitCode) {
-        emit error(wasMount ? i18n("Failed to connect to \"%1\"").arg(details.name)
-                            : i18n("Failed to disconnect from \"%1\"").arg(details.name));
+        emit error(wasMount ? i18n("Failed to connect to \"%1\"", details.name)
+                            : i18n("Failed to disconnect from \"%1\"", details.name));
         setStatusMessage(QString());
     } else if (wasMount) {
         setStatusMessage(i18n("Updating tracks..."));
         load();
-        emit connectionStateHasChanged(udi(), true);
+        emit connectionStateHasChanged(id(), true);
     } else {
         setStatusMessage(QString());
         update=new MusicLibraryItemRoot;
         scanned=false;
-        emit updating(udi(), false);
-        emit connectionStateHasChanged(udi(), false);
+        emit updating(id(), false);
+        emit connectionStateHasChanged(id(), false);
     }
 }
 
@@ -477,12 +479,12 @@ void RemoteFsDevice::mountStatus(const QString &mp, int pid, int st)
     if (pid==getpid() && mp==mountPoint(details, false)) {
         messageSent=false;
         if (0!=st) {
-            emit error(i18n("Failed to connect to \"%1\"").arg(details.name));
+            emit error(i18n("Failed to connect to \"%1\"", details.name));
             setStatusMessage(QString());
         } else {
             setStatusMessage(i18n("Updating tracks..."));
             load();
-            emit connectionStateHasChanged(udi(), true);
+            emit connectionStateHasChanged(id(), true);
         }
     }
 }
@@ -492,13 +494,13 @@ void RemoteFsDevice::umountStatus(const QString &mp, int pid, int st)
     if (pid==getpid() && mp==mountPoint(details, false)) {
         messageSent=false;
         if (0!=st) {
-            emit error(i18n("Failed to disconnect from \"%1\"").arg(details.name));
+            emit error(i18n("Failed to disconnect from \"%1\"", details.name));
             setStatusMessage(QString());
         } else {
             setStatusMessage(QString());
             update=new MusicLibraryItemRoot;
-            emit updating(udi(), false);
-            emit connectionStateHasChanged(udi(), false);
+            emit updating(id(), false);
+            emit connectionStateHasChanged(id(), false);
         }
     }
 }
@@ -570,7 +572,7 @@ QString RemoteFsDevice::capacityString()
     if (isOldSshfs()) {
         return i18n("Capacity Unknown");
     }
-    return i18n("%1 free").arg(Utils::formatByteSize(spaceInfo.size()-spaceInfo.used()));
+    return i18n("%1 free", Utils::formatByteSize(spaceInfo.size()-spaceInfo.used()));
 }
 
 qint64 RemoteFsDevice::freeSpace()
@@ -665,7 +667,7 @@ static inline QString toString(bool b)
 
 void RemoteFsDevice::saveOptions()
 {
-    opts.save(udi());
+    opts.save(id());
 }
 
 void RemoteFsDevice::saveProperties()
