@@ -31,6 +31,8 @@
 
 class QTimer;
 class MusicLibraryProxyModel;
+class Action;
+class Icon;
 
 class SyncCollectionWidget : public QWidget, Ui::SyncCollectionWidget
 {
@@ -43,21 +45,36 @@ public:
     void update(const QSet<Song> &songs) { model->update(songs); }
     void setSupportsAlbumArtistTag(bool s) { model->setSupportsAlbumArtistTag(s); }
     int numArtists() { return model->rowCount(); }
+    void setIcon(const Icon &icon);
 
 Q_SIGNALS:
     void copy(const QList<Song> &songs);
 
 private Q_SLOTS:
+    void songsChecked(const QSet<Song> &songs);
+    void dataChanged(const QModelIndex &tl, const QModelIndex &br);
+    void checkItems();
+    void unCheckItems();
     void copySongs();
     void delaySearchItems();
     void searchItems();
     void expandAll();
     void collapseAll();
+    void itemClicked(const QModelIndex &index);
+    void itemActivated(const QModelIndex &index);
+
+private:
+    void checkItems(bool c);
+    void updateStats();
 
 private:
     MusicLibraryModel *model;
     MusicLibraryProxyModel *proxy;
     QTimer *searchTimer;
+    QSet<Song> checkedSongs;
+    Action *copyAction;
+    Action *checkAction;
+    Action *unCheckAction;
 };
 
 #endif
