@@ -29,6 +29,7 @@
 #include "devicesmodel.h"
 #include "localize.h"
 #include "messagebox.h"
+#include "icons.h"
 #include <QSplitter>
 
 struct SyncSong : public Song
@@ -92,7 +93,7 @@ int SyncDialog::instanceCount()
 }
 
 SyncDialog::SyncDialog(QWidget *parent)
-    : Dialog(parent)
+    : Dialog(parent, "SyncDialog", QSize(680, 680))
     , currentDev(0)
 {
     iCount++;
@@ -106,6 +107,8 @@ SyncDialog::SyncDialog(QWidget *parent)
     setCaption(i18n("Synchronize"));
     connect(libWidget, SIGNAL(copy(const QList<Song> &)), SLOT(copy(const QList<Song> &)));
     connect(devWidget, SIGNAL(copy(const QList<Song> &)), SLOT(copy(const QList<Song> &)));
+
+//    libWidget->setIcon(Icons::self()->libraryIcon);
 }
 
 SyncDialog::~SyncDialog()
@@ -116,11 +119,12 @@ SyncDialog::~SyncDialog()
 void SyncDialog::sync(const QString &udi)
 {
     devUdi=udi;
+//    Device *dev=getDevice();
+//    if (dev) {
+//        devWidget->setIcon(Icon(dev->icon()));
+//    }
+
     if (updateSongs(true)) {
-        int numArtists=qMax(devWidget->numArtists(), libWidget->numArtists());
-        int listSize=QFontMetrics(font()).height()*numArtists;
-        int size=140+listSize;
-        resize(680, size=size<300 ? 300 : (size>680 ? 680 : size));
         show();
     }
 }
@@ -136,7 +140,7 @@ void SyncDialog::copy(const QList<Song> &songs)
     bool fromDev=sender()==devWidget;
     ActionDialog *dlg=new ActionDialog(this);
     connect(dlg, SIGNAL(completed()), SLOT(updateSongs()));
-    dlg->copy(fromDev ? dev->udi() : QString(), fromDev ? QString() : dev->udi(), songs);
+    dlg->copy(fromDev ? dev->id() : QString(), fromDev ? QString() : dev->id(), songs);
 }
 
 bool SyncDialog::updateSongs(bool firstRun)
