@@ -35,7 +35,7 @@
 static const QLatin1String constSettingsFile("/.is_audio_player");
 static const QLatin1String constMusicFolderKey("audio_folder");
 
-UmsDevice::UmsDevice(DevicesModel *m, Solid::Device &dev)
+UmsDevice::UmsDevice(MusicModel *m, Solid::Device &dev)
     : FsDevice(m, dev)
     , access(dev.as<Solid::StorageAccess>())
 {
@@ -102,7 +102,7 @@ QString UmsDevice::capacityString()
         return i18n("Not Connected");
     }
 
-    return i18n("%1 free").arg(Utils::formatByteSize(spaceInfo.size()-spaceInfo.used()));
+    return i18n("%1 free", Utils::formatByteSize(spaceInfo.size()-spaceInfo.used()));
 }
 
 qint64 UmsDevice::freeSpace()
