@@ -36,7 +36,7 @@ class UmsDevice : public FsDevice
     Q_OBJECT
 
 public:
-    UmsDevice(DevicesModel *m, Solid::Device &dev);
+    UmsDevice(MusicModel *m, Solid::Device &dev);
     virtual ~UmsDevice();
 
     void connectionStateChanged();
