@@ -30,6 +30,7 @@
 #include "networkaccessmanager.h"
 #include "settings.h"
 #include "localize.h"
+#include "qtplural.h"
 #include "actioncollection.h"
 #ifdef ENABLE_KDE_SUPPORT
 #include <KDE/KGlobal>
@@ -42,16 +43,27 @@ K_GLOBAL_STATIC(Dynamic, instance)
 #include <QTimer>
 #include <QIcon>
 #include <QUrl>
+#include <QUdpSocket>
+#include <QNetworkProxy>
 #if QT_VERSION >= 0x050000
 #include <QUrlQuery>
 #endif
 #include <signal.h>
 
+#include <QDebug>
+static bool debugEnabled=false;
+#define DBUG if (debugEnabled) qWarning() << metaObject()->className() << __FUNCTION__
+void Dynamic::enableDebug()
+{
+    debugEnabled=true;
+}
+
 static const QString constDir=QLatin1String("dynamic");
 static const QString constExtension=QLatin1String(".rules");
 static const QString constActiveRules=QLatin1String("rules");
 static const QString constLockFile=QLatin1String("lock");
 
+static const QString constIdCmd=QLatin1String("id");
 static const QString constListCmd=QLatin1String("list");
 static const QString constStatusCmd=QLatin1String("status");
 static const QString constSaveCmd=QLatin1String("save");
@@ -64,6 +76,47 @@ static const QString constStatusStateResp=QLatin1String("STATE:");
 static const QString constStatusRuleResp=QLatin1String("RULES:");
 static const QString constUpdateRequiredResp=QLatin1String("UPDATE_REQUIRED");
 
+Dynamic::Command Dynamic::toCommand(const QString &cmd)
+{
+    if (constIdCmd==cmd) {
+        return Id;
+    }
+    if (constListCmd==cmd) {
+        return List;
+    }
+    if (constStatusCmd==cmd) {
+        return Status;
+    }
+    if (constSaveCmd==cmd) {
+        return Save;
+    }
+    if (constDeleteCmd==cmd) {
+        return Del;
+    }
+    if (constSetActiveCmd==cmd) {
+        return SetActive;
+    }
+    if (constControlCmd==cmd) {
+        return Control;
+    }
+    return Unknown;
+}
+
+QString Dynamic::toString(Command cmd)
+{
+    switch (cmd) {
+    case Unknown:   return QString();
+    case Id:        return constIdCmd;
+    case List:      return constListCmd;
+    case Status:    return constStatusCmd;
+    case Save:      return constSaveCmd;
+    case Del:       return constDeleteCmd;
+    case SetActive: return constSetActiveCmd;
+    case Control:   return constControlCmd;
+    }
+    return QString();
+}
+
 Dynamic * Dynamic::self()
 {
     #ifdef ENABLE_KDE_SUPPORT
@@ -88,15 +141,56 @@ const QString Dynamic::constDateKey=QLatin1String("Date");
 const QString Dynamic::constExactKey=QLatin1String("Exact");
 const QString Dynamic::constExcludeKey=QLatin1String("Exclude");
 
+static const char * constMulticastMsgHeader="{CANTATA/";
+const QString constStatusMsg(QLatin1String("STATUS:"));
+
+MulticastReceiver::MulticastReceiver(QObject *parent, const QString &i, const QString &group, quint16 port)
+    : QObject(parent)
+    , id(i)
+{
+    socket = new QUdpSocket(this);
+    socket->setProxy(QNetworkProxy(QNetworkProxy::NoProxy));
+    #if QT_VERSION < 0x050000
+    socket->bind(QHostAddress::Any, port, QUdpSocket::ShareAddress);
+    #else
+    socket->bind(QHostAddress::AnyIPv4, port, QAbstractSocket::ShareAddress);
+    #endif
+    socket->joinMulticastGroup(QHostAddress(group));
+    connect(socket, SIGNAL(readyRead()), this, SLOT(processMessages()));
+}
+
+void MulticastReceiver::processMessages()
+{
+    static int headerLen=strlen(constMulticastMsgHeader);
+
+    while (socket->hasPendingDatagrams()) {
+        QByteArray datagram;
+        datagram.resize(socket->pendingDatagramSize());
+        socket->readDatagram(datagram.data(), datagram.size());
+        if (datagram.length()>headerLen && datagram.startsWith(constMulticastMsgHeader)) {
+            QString header(constMulticastMsgHeader+id+"}");
+            QString message=QString::fromUtf8(&(datagram.constData()[header.length()]));
+            DBUG << message;
+            if (message.startsWith(constStatusMsg)) {
+                emit status(message.mid(constStatusMsg.length()));
+            }
+        }
+    }
+}
+
 Dynamic::Dynamic()
-    : timer(0)
+    : localTimer(0)
+    , remoteTimer(0)
+    , remotePollingEnabled(false)
     , statusTime(1)
     , currentJob(0)
+    , currentCommand(Unknown)
+    , receiver(0)
 {
     loadLocal();
     connect(this, SIGNAL(clear()), MPDConnection::self(), SLOT(clear()));
     connect(MPDConnection::self(), SIGNAL(dynamicUrl(const QString &)), this, SLOT(dynamicUrlChanged(const QString &)));
-    connect(MPDConnection::self(), SIGNAL(statusUpdated(const MPDStatusValues &)), this, SLOT(checkRemoteHelper()));
+//    connect(MPDConnection::self(), SIGNAL(statusUpdated(const MPDStatusValues &)), this, SLOT(updateRemoteStatus()));
     QTimer::singleShot(500, this, SLOT(checkHelper()));
     startAction = ActionCollection::get()->createAction("startdynamic", i18n("Start Dynamic Playlist"), "media-playback-start");
     stopAction = ActionCollection::get()->createAction("stopdynamic", i18n("Stop Dynamic Mode"), "process-stop");
@@ -144,7 +238,7 @@ QVariant Dynamic::data(const QModelIndex &index, int role) const
     case Qt::ToolTipRole:
         return entryList.at(index.row()).name;
     case Qt::DecorationRole:
-        return IS_ACTIVE(entryList.at(index.row()).name) ? QIcon::fromTheme("media-playback-start") : Icons::dynamicRuleIcon;
+        return IS_ACTIVE(entryList.at(index.row()).name) ? QIcon::fromTheme("media-playback-start") : Icons::self()->dynamicRuleIcon;
     case ItemView::Role_SubText: {
         #ifdef ENABLE_KDE_SUPPORT
         return i18np("1 Rule", "%1 Rules", entryList.at(index.row()).rules.count());
@@ -202,7 +296,7 @@ bool Dynamic::save(const Entry &e)
     }
 
     if (isRemote()) {
-        if (currentCommand!=constStatusCmd && (!currentCommand.isEmpty() || !currentArgs.isEmpty())) {
+        if (currentCommand!=Status && (currentCommand!=Unknown || !currentArgs.isEmpty())) {
             return false;
         }
 
@@ -218,9 +312,11 @@ bool Dynamic::save(const Entry &e)
         url.setQuery(query);
         #endif
 
-        currentJob=NetworkAccessManager::self()->post(QNetworkRequest(url), string.toUtf8());
-        connect(currentJob, SIGNAL(finished()), this, SLOT(jobFinished()));
-        currentCommand=constSaveCmd;
+        QNetworkRequest req(url);
+        req.setHeader(QNetworkRequest::ContentTypeHeader, "text/plain");
+        currentJob=NetworkAccessManager::self()->post(req, string.toUtf8());
+        connect(currentJob, SIGNAL(finished()), this, SLOT(remoteJobFinished()));
+        currentCommand=Save;
         currentArgs.clear();
         currentSave=e;
         return true;
@@ -254,7 +350,7 @@ void Dynamic::updateEntry(const Entry &e)
 void Dynamic::del(const QString &name)
 {
     if (isRemote()) {
-        sendCommand(constDeleteCmd, QStringList() << name);
+        sendCommand(Del, QStringList() << name);
         return;
     }
 
@@ -279,14 +375,19 @@ void Dynamic::del(const QString &name)
 void Dynamic::start(const QString &name)
 {
     if (isRemote()) {
-        sendCommand(constSetActiveCmd, QStringList() << "name" << name << "start" << "1");
+        sendCommand(SetActive, QStringList() << "name" << name << "start" << "1");
+        return;
+    }
+
+    if (Utils::findExe("perl").isEmpty()) {
+        emit error(i18n("You need to install \"perl\" on your system in order for Cantata's dynamic mode to function."));
         return;
     }
 
     QString fName(Utils::configDir(constDir, false)+name+constExtension);
 
     if (!QFile::exists(fName)) {
-        emit error(i18n("Failed to locate rules file - %1").arg(fName));
+        emit error(i18n("Failed to locate rules file - %1", fName));
         return;
     }
 
@@ -294,12 +395,12 @@ void Dynamic::start(const QString &name)
 
     QFile::remove(rules);
     if (QFile::exists(rules)) {
-        emit error(i18n("Failed to remove previous rules file - %1").arg(rules));
+        emit error(i18n("Failed to remove previous rules file - %1", rules));
         return;
     }
 
     if (!QFile::link(fName, rules)) {
-        emit error(i18n("Failed to install rules file - %1 -> %2").arg(fName).arg(rules));
+        emit error(i18n("Failed to install rules file - %1 -> %2", fName, rules));
         return;
     }
 
@@ -332,7 +433,7 @@ void Dynamic::start(const QString &name)
 void Dynamic::stop()
 {
     if (isRemote()) {
-        sendCommand(constControlCmd, QStringList() << "state" << "stop");
+        sendCommand(Control, QStringList() << "state" << "stop");
         return;
     }
 
@@ -389,6 +490,17 @@ bool Dynamic::isRunning()
     #endif
 }
 
+void Dynamic::enableRemotePolling(bool e)
+{
+    remotePollingEnabled=e;
+    if (remoteTimer && remoteTimer->isActive()) {
+        if (remotePollingEnabled) {
+            checkIfRemoteIsRunning();
+        }
+        remoteTimer->start(remotePollingEnabled ? 2000 : 30000);
+    }
+}
+
 int Dynamic::getPid() const
 {
     QFile pidFile(Utils::cacheDir(constDir, false)+constLockFile);
@@ -417,12 +529,12 @@ bool Dynamic::controlApp(bool isStart)
     }
     process.start(cmd, QStringList() << QLatin1String(isStart ? "start" : "stop"), QIODevice::WriteOnly);
 
-    if (!timer) {
-        timer=new QTimer(this);
-        connect(timer, SIGNAL(timeout()), SLOT(checkHelper()));
+    if (!localTimer) {
+        localTimer=new QTimer(this);
+        connect(localTimer, SIGNAL(timeout()), SLOT(checkHelper()));
     }
     bool rv=process.waitForFinished(1000);
-    timer->start(1000);
+    localTimer->start(1000);
     return rv;
 }
 
@@ -499,7 +611,7 @@ void Dynamic::loadRemote()
     entryList.clear();
     currentEntry=QString();
     endResetModel();
-    sendCommand(constListCmd, QStringList() << "withDetails" << "1");
+    sendCommand(Id);
 }
 
 void Dynamic::parseRemote(const QString &response)
@@ -570,6 +682,7 @@ void Dynamic::parseStatus(const QString &response)
 
     bool stateChanged=lastState!=state;
     bool noSongs=QLatin1String("NO_SONGS")==state;
+    bool terminated=false;
 
     if (stateChanged) {
         lastState=state;
@@ -584,6 +697,13 @@ void Dynamic::parseStatus(const QString &response)
         } else if (QLatin1String("IDLE")==state) {
             currentEntry.clear();
             emit running(false);
+        } else if (QLatin1String("TERMINATED")==state) {
+            currentEntry.clear();
+            emit running(false);
+            emit error(i18n("Dynamizer has been terminated."));
+            pollRemoteHelper();
+            terminated=true;
+            currentEntry=QString();
         }
     }
 
@@ -606,14 +726,36 @@ void Dynamic::parseStatus(const QString &response)
         }
     }
 
-    if (st>statusTime) {
-        if (currentCommand.isEmpty() && currentArgs.isEmpty()) {
+    if (st>statusTime && !terminated) {
+        if (Unknown==currentCommand && currentArgs.isEmpty()) {
             statusTime=st;
-            sendCommand(constListCmd, QStringList() << "withDetails" << "1");
+            sendCommand(List, QStringList() << "withDetails" << "1");
         }
     }
 }
 
+void Dynamic::parseId(const QString &response)
+{
+    QStringList list=response.split("\n");
+    QString id;
+    quint16 port=0;
+    QString group;
+
+    foreach (const QString &param, list) {
+        if (param.startsWith(QLatin1String("ID:"))) {
+            id=param.mid(3);
+        } else if (param.startsWith(QLatin1String("GROUP:"))) {
+            group=param.mid(6);
+        } else if (param.startsWith(QLatin1String("PORT:"))) {
+            port=param.mid(5).toUInt();
+        }
+    }
+
+    if (!id.isEmpty() && !group.isEmpty() && 0!=port) {
+        startReceiver(id, group, port);
+    }
+}
+
 void Dynamic::checkResponse(const QString &response)
 {
     QStringList list=response.split("\n");
@@ -627,37 +769,35 @@ void Dynamic::checkResponse(const QString &response)
     }
 
     if (updateReq) {
-        sendCommand(constListCmd, QStringList() << "withDetails" << "1");
+        sendCommand(List, QStringList() << "withDetails" << "1");
     }
 }
 
-void Dynamic::sendCommand(const QString &cmd, const QStringList &args)
+void Dynamic::sendCommand(Command cmd, const QStringList &args)
 {
-    if (currentCommand==constStatusCmd) {
-        if (cmd==constStatusCmd) {
+    if (Status==currentCommand) {
+        if (cmd==Status) {
             return;
         }
-        currentCommand.clear();
+        currentCommand=Unknown;
         currentArgs.clear();
         if (currentJob) {
-            disconnect(currentJob, SIGNAL(finished()), this, SLOT(jobFinished()));
+            disconnect(currentJob, SIGNAL(finished()), this, SLOT(remoteJobFinished()));
         }
     }
-    if (!currentCommand.isEmpty() || !currentArgs.isEmpty()) {
-        if (cmd!=constStatusCmd) {
+    if (Unknown!=currentCommand) {
+        if (Status!=cmd) {
             QString cmdStr=i18n("Uknown");
-            if (constListCmd==cmd) {
-                cmdStr=i18n("Loading list of rules");
-            } else if (constSaveCmd==cmd) {
-                cmdStr=i18n("Saving rule");
-            } else if (constDeleteCmd==cmd) {
-                cmdStr=i18n("Deleting rule");
-            } else if (constSetActiveCmd==cmd) {
-                cmdStr=i18n("Setting active rule");
-            } else if (constControlCmd==cmd) {
-                cmdStr=i18n("Stopping dynamizer");
+            switch(cmd) {
+            case List:      cmdStr=i18n("Loading list of rules"); break;
+            case Save:      cmdStr=i18n("Saving rule"); break;
+            case Del:       cmdStr=i18n("Deleting rule"); break;
+            case SetActive: cmdStr=i18n("Setting active rule"); break;
+            case Control:   cmdStr=i18n("Stopping dynamizer"); break;
+            case Id:        cmdStr=i18n("Requesting ID details"); break;
+            default: break;
             }
-            emit error(i18n("Awaiting response for previous command. (%1)").arg(cmdStr));
+            emit error(i18n("Awaiting response for previous command. (%1)", cmdStr));
         }
         return;
     }
@@ -665,7 +805,8 @@ void Dynamic::sendCommand(const QString &cmd, const QStringList &args)
     currentCommand=cmd;
     currentArgs=args;
 
-    if (constDeleteCmd==cmd) {
+    DBUG << toString(cmd) << args;
+    if (Del==cmd) {
         if (!args.isEmpty()) {
             #if QT_VERSION < 0x050000
             QUrl url(dynamicUrl+"/"+args.at(0));
@@ -679,11 +820,11 @@ void Dynamic::sendCommand(const QString &cmd, const QStringList &args)
         
             currentJob=NetworkAccessManager::self()->deleteResource(QNetworkRequest(url));
         } else {
-            currentCommand.clear();
+            currentCommand=Unknown;
             currentArgs.clear();
         }
     } else {
-        QUrl url(dynamicUrl+"/"+currentCommand);
+        QUrl url(dynamicUrl+"/"+toString(currentCommand));
         #if QT_VERSION < 0x050000
         QUrl &query=url;
         #else
@@ -698,22 +839,24 @@ void Dynamic::sendCommand(const QString &cmd, const QStringList &args)
         #if QT_VERSION >= 0x050000
         url.setQuery(query);
         #endif
-        if (constSetActiveCmd==cmd || constControlCmd==cmd) {
-            currentJob=NetworkAccessManager::self()->post(QNetworkRequest(url), QByteArray());
+        if (SetActive==cmd || Control==cmd) {
+            QNetworkRequest req(url);
+            req.setHeader(QNetworkRequest::ContentTypeHeader, "text/plain");
+            currentJob=NetworkAccessManager::self()->post(req, QByteArray());
         } else {
             currentJob=NetworkAccessManager::self()->get(QNetworkRequest(url));
         }
     }
-    if (constListCmd==cmd) {
+    if (List==cmd) {
         emit loadingList();
     }
-    connect(currentJob, SIGNAL(finished()), this, SLOT(jobFinished()));
+    connect(currentJob, SIGNAL(finished()), this, SLOT(remoteJobFinished()));
 }
 
 void Dynamic::refreshList()
 {
     if (isRemote()) {
-        sendCommand(constListCmd, QStringList() << "withDetails" << "1");
+        sendCommand(List, QStringList() << "withDetails" << "1");
     }
 }
 
@@ -731,14 +874,14 @@ void Dynamic::checkHelper()
             QModelIndex idx=index(i, 0, QModelIndex());
             emit dataChanged(idx, idx);
         }
-        if (timer) {
-            timer->stop();
+        if (localTimer) {
+            localTimer->stop();
         }
     } else {
-        if (timer && timer->isActive()) {
+        if (localTimer && localTimer->isActive()) {
             static const int constAppCheck=15*1000;
-            if (timer->interval()<constAppCheck) {
-                timer->start(constAppCheck);
+            if (localTimer->interval()<constAppCheck) {
+                localTimer->start(constAppCheck);
             }
         } else { // No timer => app startup!
             // Attempt to read current name...
@@ -758,14 +901,39 @@ void Dynamic::checkHelper()
     }
 }
 
-void Dynamic::checkRemoteHelper()
+void Dynamic::pollRemoteHelper()
 {
-    if (isRemote()) {
-        sendCommand(constStatusCmd);
+    if (!remoteTimer) {
+        remoteTimer=new QTimer(this);
+        connect(remoteTimer, SIGNAL(timeout()), SLOT(checkIfRemoteIsRunning()));
+    }
+    beginResetModel();
+    entryList.clear();
+    currentEntry=QString();
+    endResetModel();
+    remoteTimer->start(remotePollingEnabled ? 2000 : 30000);
+    emit remoteRunning(false);
+}
+
+void Dynamic::checkIfRemoteIsRunning()
+{
+    if (isRemote() && entryList.isEmpty()) {
+        if (remotePollingEnabled) {
+            sendCommand(Id);
+        }
+    } else if (remoteTimer) {
+        remoteTimer->stop();
     }
 }
 
-void Dynamic::jobFinished()
+void Dynamic::updateRemoteStatus()
+{
+    if (isRemote()) {
+        sendCommand(Status);
+    }
+}
+
+void Dynamic::remoteJobFinished()
 {
     QNetworkReply *reply=qobject_cast<QNetworkReply *>(sender());
     if (!reply || reply!=currentJob) {
@@ -777,7 +945,7 @@ void Dynamic::jobFinished()
 
     int httpResponse=reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
     bool cmdOk=QNetworkReply::NoError==reply->error() && (200==httpResponse || 201==httpResponse);
-    bool isStatus=constStatusCmd==currentCommand;
+    DBUG << toString(currentCommand) << currentArgs << cmdOk;
     QString response;
     if (cmdOk) {
         reply->open(QIODevice::ReadOnly | QIODevice::Text);
@@ -787,20 +955,23 @@ void Dynamic::jobFinished()
         response=0==httpResponse ? i18n("Dynamizer is not active") : QString::number(httpResponse);
     }
 
-    if (constListCmd==currentCommand) {
+    switch (currentCommand) {
+    case List:
         if (cmdOk) {
             parseRemote(response);
         } else {
-            emit error(i18n("Failed to retrieve list of dynamic rules. (%1)").arg(response));
+            emit error(i18n("Failed to retrieve list of dynamic rules. (%1)", response));
         }
         emit loadedList();
-    } else if (isStatus) {
+        break;
+    case Status:
         if (cmdOk) {
             parseStatus(response);
         } else {
             emit running(false);
         }
-    } else if (constSaveCmd==currentCommand) {
+        break;
+    case Save:
         if (cmdOk) {
             updateEntry(currentSave);
             currentSave.name=QString();
@@ -808,7 +979,8 @@ void Dynamic::jobFinished()
         }
         checkResponse(response);
         emit saved(cmdOk);
-    } else if (constDeleteCmd==currentCommand) {
+        break;
+    case Del:
         if (cmdOk) {
             QString name=currentArgs.isEmpty() ? QString() : currentArgs.at(0);
             QList<Dynamic::Entry>::Iterator it=find(name);
@@ -819,45 +991,86 @@ void Dynamic::jobFinished()
             }
             checkResponse(response);
         } else {
-            emit error(i18n("Failed to delete rules file. (%1)").arg(response));
+            emit error(i18n("Failed to delete rules file. (%1)", response));
         }
-    } else if (constControlCmd==currentCommand) {
+        break;
+    case Control:
         if (cmdOk) {
             checkResponse(response);
         } else {
-            emit error(i18n("Failed to control dynamizer state. (%1)").arg(response));
+            emit error(i18n("Failed to control dynamizer state. (%1)", response));
         }
         lastState.clear();
-    } else if (constSetActiveCmd==currentCommand) {
+        break;
+    case SetActive:
         if (cmdOk) {
             checkResponse(response);
-            QTimer::singleShot(1000, this, SLOT(checkRemoteHelper()));
+            QTimer::singleShot(1000, this, SLOT(updateRemoteStatus()));
         } else {
-            emit error(i18n("Failed to set the current dynamic rules. (%1)").arg(response));
+            emit error(i18n("Failed to set the current dynamic rules. (%1)", response));
         }
         lastState.clear();
+        break;
+    case Id:
+        if (cmdOk) {
+            parseId(response);
+            currentCommand=Unknown;
+            currentArgs.clear();
+            sendCommand(List, QStringList() << "withDetails" << "1");
+            emit remoteRunning(true);
+            return;
+        }
+    default:
+        break;
     }
 
-    currentCommand.clear();
+    Command prevCommand=currentCommand;
+    currentCommand=Unknown;
     currentArgs.clear();
 
-    if (cmdOk && !isStatus) {
-        sendCommand(constStatusCmd);
+    if (cmdOk) {
+        if (remoteTimer) {
+            remoteTimer->stop();
+        }
+        if (Status!=prevCommand) {
+            sendCommand(Status);
+        }
+    } else if (0==httpResponse) {
+        pollRemoteHelper();
     }
 }
 
 void Dynamic::dynamicUrlChanged(const QString &url)
 {
     if (url!=dynamicUrl) {
-        bool wasRemote=isRemote();
         dynamicUrl=url;
-        if (wasRemote && !isRemote()) {
-            loadLocal();
-        } else {
-            if (timer) {
-                timer->stop();
+        stopReceiver();
+        if (isRemote()) {
+            if (localTimer) {
+                localTimer->stop();
             }
             loadRemote();
+        } else {
+            if (remoteTimer) {
+                remoteTimer->stop();
+            }
+            loadLocal();
         }
     }
 }
+
+void Dynamic::stopReceiver()
+{
+    if (receiver) {
+        disconnect(receiver, SIGNAL(status(QString)), this, SLOT(parseStatus(QString)));
+        receiver->deleteLater();
+        receiver=0;
+    }
+}
+
+void Dynamic::startReceiver(const QString &id, const QString &group, quint16 port)
+{
+    stopReceiver();
+    receiver=new MulticastReceiver(this, id, group, port);
+    connect(receiver, SIGNAL(status(QString)), this, SLOT(parseStatus(QString)));
+}
