@@ -33,12 +33,45 @@
 
 class QTimer;
 class QNetworkReply;
+class QUdpSocket;
+
+class MulticastReceiver : public QObject
+{
+    Q_OBJECT
+public:
+    MulticastReceiver(QObject *parent, const QString &i, const QString &group, quint16 port);
+
+Q_SIGNALS:
+    void status(const QString &st);
+
+private Q_SLOTS:
+    void processMessages();
+
+private:
+    QUdpSocket *socket;
+    QString id;
+};
 
 class Dynamic : public ActionModel
 {
     Q_OBJECT
 
 public:
+    enum Command {
+        Unknown,
+        Id,
+        List,
+        Status,
+        Save,
+        Del,
+        SetActive,
+        Control
+    };
+
+    static Command toCommand(const QString &cmd);
+    static QString toString(Command cmd);
+    static void enableDebug();
+
     typedef QMap<QString, QString> Rule;
     struct Entry {
         Entry(const QString &n=QString()) : name(n) { }
@@ -61,6 +94,7 @@ public:
     static const QString constExcludeKey;
 
     Dynamic();
+    virtual ~Dynamic() { stopReceiver(); }
 
     bool isRemote() const { return !dynamicUrl.isEmpty(); }
     QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
@@ -72,6 +106,7 @@ public:
     QVariant data(const QModelIndex &, int) const;
     Qt::ItemFlags flags(const QModelIndex &index) const;
     Entry entry(const QString &e);
+    Entry entry(int row) const { return row>=0 && row<entryList.count() ? entryList.at(row) : Entry(); }
     bool exists(const QString &e) { return entryList.end()!=find(e); }
     bool save(const Entry &e);
     void del(const QString &name);
@@ -84,9 +119,11 @@ public:
     void helperMessage(const QString &message) {  Q_UNUSED(message) checkHelper(); }
     Action * startAct() const { return startAction; }
     Action * stopAct() const { return stopAction; }
+    void enableRemotePolling(bool e);
 
 Q_SIGNALS:
     void running(bool status);
+    void remoteRunning(bool status);
     void error(const QString &str);
 
     // These are for communicating with MPD object (which is in its own thread, so need to talk via signal/slots)
@@ -102,37 +139,45 @@ public Q_SLOTS:
 
 private Q_SLOTS:
     void checkHelper();
-    void checkRemoteHelper();
-    void jobFinished();
+    void checkIfRemoteIsRunning();
+    void updateRemoteStatus();
+    void remoteJobFinished();
     void dynamicUrlChanged(const QString &url);
+    void parseStatus(const QString &response);
 
 private:
+    void pollRemoteHelper();
     int getPid() const;
     bool controlApp(bool isStart);
     QList<Entry>::Iterator find(const QString &e);
-    void sendCommand(const QString &cmd, const QStringList &args=QStringList());
+    void sendCommand(Command cmd, const QStringList &args=QStringList());
     void loadLocal();
     void loadRemote();
     void parseRemote(const QString &response);
-    void parseStatus(const QString &response);
+    void parseId(const QString &response);
     void checkResponse(const QString &response);
     void updateEntry(const Entry &e);
+    void stopReceiver();
+    void startReceiver(const QString &id, const QString &group, quint16 port);
 
 private:
-    QTimer *timer;
+    QTimer *localTimer;
     QList<Entry> entryList;
     QString currentEntry;
     Action *startAction;
     Action *stopAction;
 
     // For remote dynamic servers...
+    QTimer *remoteTimer;
+    bool remotePollingEnabled;
     int statusTime;
     QString lastState;
     QString dynamicUrl;
     QNetworkReply *currentJob;
-    QString currentCommand;
+    Command currentCommand;
     QStringList currentArgs;
     Entry currentSave;
+    MulticastReceiver *receiver;
 };
 
 #endif
