@@ -52,6 +52,12 @@ private Q_SLOTS:
     void stop();
     void toggle();
     void running(bool status);
+    void remoteRunning(bool status);
+
+private:
+    void enableWidgets(bool enable);
+    void showEvent(QShowEvent *e);
+    void hideEvent(QHideEvent *e);
 
 private:
     DynamicProxyModel proxy;
