@@ -27,6 +27,7 @@
 #include "messagebox.h"
 #include "localize.h"
 #include "icons.h"
+#include "basicitemdelegate.h"
 #include <QIcon>
 #include <QStandardItem>
 #include <QStandardItemModel>
@@ -140,7 +141,7 @@ DynamicRulesDialog::DynamicRulesDialog(QWidget *parent)
     connect(removeBtn, SIGNAL(clicked()), SLOT(remove()));
 
     addBtn->setIcon(QIcon::fromTheme("list-add"));
-    editBtn->setIcon(Icons::editIcon);
+    editBtn->setIcon(Icons::self()->editIcon);
     removeBtn->setIcon(QIcon::fromTheme("list-remove"));
 
     connect(rulesList, SIGNAL(itemsSelected(bool)), SLOT(controlButtons()));
@@ -153,6 +154,8 @@ DynamicRulesDialog::DynamicRulesDialog(QWidget *parent)
     proxy=new RulesSort(this);
     proxy->setSourceModel(model);
     rulesList->setModel(proxy);
+    rulesList->setItemDelegate(new BasicItemDelegate(rulesList));
+    rulesList->setAlternatingRowColors(false);
 
     controlButtons();
     resize(500, 240);
@@ -301,7 +304,7 @@ void DynamicRulesDialog::saved(bool s)
     if (s) {
         accept();
     } else {
-        messageWidget->setError(i18n("Failed to save %1").arg(nameText->text().trimmed()));
+        messageWidget->setError(i18n("Failed to save %1", nameText->text().trimmed()));
         controls->setEnabled(true);
     }
 }
@@ -319,8 +322,8 @@ bool DynamicRulesDialog::save()
     }
 
     if (name!=origName && Dynamic::self()->exists(name) &&
-        MessageBox::No==MessageBox::warningYesNo(this, i18n("A set of rules named \'%1\' already exists!\nOverwrite?").arg(name),
-                                                     i18n("Already Exists"))) {
+        MessageBox::No==MessageBox::warningYesNo(this, i18n("A set of rules named \'%1\' already exists!\nOverwrite?", name),
+                                                  i18n("Overwrite Rules"), StdGuiItem::overwrite(), StdGuiItem::cancel())) {
         return false;
     }
 
@@ -345,7 +348,7 @@ bool DynamicRulesDialog::save()
 
     if (Dynamic::self()->isRemote()) {
         if (saved) {
-            messageWidget->setInformation(i18n("Saving %1").arg(name));
+            messageWidget->setInformation(i18n("Saving %1", name));
             controls->setEnabled(false);
             enableButton(Ok, false);
         }
