@@ -31,7 +31,6 @@
 #include "utils.h"
 #include "spinner.h"
 #include "icon.h"
-#include "sha2/sha2.h"
 #include "qjson/parser.h"
 #include <QVBoxLayout>
 #include <QLabel>
@@ -65,6 +64,7 @@
 #include <QXmlStreamReader>
 #include <QDomDocument>
 #include <QDomElement>
+#include <QDebug>
 
 static int iCount=0;
 static const int constMaxTempFiles=20;
@@ -78,33 +78,6 @@ static QImage cropImage(QImage img, bool isArtist)
     return img;
 }
 
-static QByteArray sha256(const QByteArray &data)
-{
-    SHA256_CTX context;
-    SHA256_Init(&context);
-    SHA256_Update(&context, reinterpret_cast<const u_int8_t*>(data.constData()),
-                  data.length());
-
-    QByteArray ret(SHA256_DIGEST_LENGTH, '\0');
-    SHA256_Final(reinterpret_cast<u_int8_t*>(ret.data()), &context);
-    return ret;
-}
-
-static QByteArray hmacSha256(const QByteArray &key, const QByteArray &data)
-{
-    static const int constBlockSize = 64; // bytes
-    Q_ASSERT(key.length() <= constBlockSize);
-
-    QByteArray innerPadding(constBlockSize, char(0x36));
-    QByteArray outerPadding(constBlockSize, char(0x5c));
-
-    for (int i=0 ; i<key.length() ; ++i) {
-        innerPadding[i] = innerPadding[i] ^ key[i];
-        outerPadding[i] = outerPadding[i] ^ key[i];
-    }
-    return sha256(outerPadding + sha256(innerPadding + data));
-}
-
 int CoverDialog::instanceCount()
 {
     return iCount;
@@ -125,7 +98,6 @@ public:
         Type_LastFm,
         Type_Google,
         Type_Discogs,
-        Type_Amazon,
         Type_CoverArtArchive
     };
 
@@ -189,8 +161,8 @@ public:
         : CoverItem(u, QString(), parent)
         , img(i) {
         setImage(i);
-        setText(i18nc("name\nwidth x height (file size)", "%1\n%2 x %3 (%4)")
-                .arg(Utils::getFile(u)).arg(img.width()).arg(img.height()).arg(Utils::formatByteSize(QFileInfo(u).size())));
+        setText(i18nc("name\nwidth x height (file size)", "%1\n%2 x %3 (%4)",
+                Utils::getFile(u), img.width(), img.height(), Utils::formatByteSize(QFileInfo(u).size())));
     }
 
     quint32 key() const { return 0xFFFFFFFE; }
@@ -208,7 +180,7 @@ public:
         , width(w)
         , height(h) {
         setImage(img);
-        setText(i18nc("Google\nwidth x height (file size)", "Google\n%1 x %2 (%3)").arg(width).arg(height).arg(Utils::formatByteSize(size*1024)));
+        setText(i18nc("Google\nwidth x height (file size)", "Google\n%1 x %2 (%3)", width, height, Utils::formatByteSize(size*1024)));
     }
 
     quint32 key() const { return width*height; }
@@ -227,7 +199,9 @@ public:
         , width(w)
         , height(h) {
         setImage(img);
-        setText(i18nc("Discogs\nwidth x height", "Discogs\n%1 x %2").arg(width).arg(height));
+        setText(width>10 && height>10
+                    ? i18nc("Discogs\nwidth x height", "Discogs\n%1 x %2", width, height)
+                    : QLatin1String("Discogs"));
     }
 
     quint32 key() const { return width*height; }
@@ -237,25 +211,6 @@ private:
     int height;
 };
 
-class AmazonCover : public CoverItem
-{
-public:
-    AmazonCover(const QString &u, const QString &tu, const QImage &img, int w, int h, QListWidget *parent)
-        : CoverItem(u, tu, parent)
-        , width(w)
-        , height(h) {
-        setImage(img);
-        setText(i18nc("Amazon\nwidth x height", "Amazon\n%1 x %2").arg(width).arg(height));
-    }
-
-    quint32 key() const { return width*height; }
-    Type type()  const { return Type_Amazon; }
-
-private:
-    int width;
-    int height;
-};
-
 class CoverArtArchiveCover : public CoverItem
 {
 public:
@@ -279,7 +234,7 @@ public:
         QFont f(font());
         f.setBold((true));
         setFont(f);
-        setText(i18nc("Current Cover\nwidth x height", "Current Cover\n%1 x %2").arg(img.img.width()).arg(img.img.height()));
+        setText(i18nc("Current Cover\nwidth x height", "Current Cover\n%1 x %2", img.img.width(), img.img.height()));
     }
 
     quint32 key() const { return 0xFFFFFFFF; }
@@ -345,7 +300,7 @@ void CoverPreview::showImage(const QImage &img, const QString &u)
         imgW=img.width();
         imgH=img.height();
         resize(lrPad+qMax(100, qMin(maxWidth, imgW+fw)), tbPad+qMax(100, qMin(maxHeight, imgH+fw)));
-        setWindowTitle(i18nc("Image (width x height zoom%)", "Image (%1 x %2 %3%)").arg(imgW).arg(imgH).arg(zoom*100));
+        setWindowTitle(i18nc("Image (width x height zoom%)", "Image (%1 x %2 %3%)", imgW, imgH, zoom*100));
         show();
     }
 }
@@ -358,10 +313,7 @@ void CoverPreview::downloading(const QString &u)
         scrollArea->hide();
         pbar->show();
         pbar->setValue(0);
-        int spacing=style()->layoutSpacing(QSizePolicy::DefaultType, QSizePolicy::DefaultType, Qt::Vertical);
-        if (spacing<0) {
-            spacing=4;
-        }
+        int spacing=Utils::layoutSpacing(this);
         QApplication::processEvents();
         adjustSize();
         resize(qMin(200, loadingLabel->width()+32), loadingLabel->height()+pbar->height()+(3*spacing));
@@ -383,7 +335,7 @@ void CoverPreview::scaleImage(int adjust)
     }
     zoom=newZoom;
     imageLabel->resize(zoom * imageLabel->pixmap()->size());
-    setWindowTitle(i18nc("Image (width x height zoom%)", "Image (%1 x %2 %3%)").arg(imgW).arg(imgH).arg(zoom*100));
+    setWindowTitle(i18nc("Image (width x height zoom%)", "Image (%1 x %2 %3%)", imgW, imgH, zoom*100));
 }
 
 void CoverPreview::wheelEvent(QWheelEvent *event)
@@ -458,8 +410,6 @@ CoverDialog::CoverDialog(QWidget *parent)
     cancelButton->setAutoRaise(true);
     addFileButton->setAutoRaise(true);
     setAcceptDrops(true);
-    amazonAccessKey=Settings::self()->amazonAccessKey();
-    amazonSecretAccessKey=Settings::self()->amazonSecretAccessKey();
 }
 
 CoverDialog::~CoverDialog()
@@ -476,14 +426,17 @@ void CoverDialog::show(const Song &s, const Covers::Image &current)
     Covers::Image img=current.img.isNull() ? Covers::locateImage(song) : current;
 
     if (!img.fileName.isEmpty() && !QFileInfo(img.fileName).isWritable()) {
-        MessageBox::error(parentWidget(), i18n("<p>A cover already exists for this album, and the file is not writeable.<p></p><i>%1</i></p>").arg(img.fileName));
+        MessageBox::error(parentWidget(),
+                          isArtist
+                            ? i18n("<p>An image already exists for this artist, and the file is not writeable.<p></p><i>%1</i></p>", img.fileName)
+                            : i18n("<p>A cover already exists for this album, and the file is not writeable.<p></p><i>%1</i></p>", img.fileName));
         deleteLater();
         return;
     }
     if (isArtist) {
         setCaption(song.albumartist);
     } else {
-        setCaption(i18nc("Album by Artist", "%1 by %2").arg(song.album).arg(song.albumArtist()));
+        setCaption(i18nc("Album by Artist", "%1 by %2", song.album, song.albumArtist()));
     }
     if (!img.img.isNull()) {
         existing=new ExistingCover(isArtist ? Covers::Image(cropImage(img.img, true), img.fileName) : img, list);
@@ -506,9 +459,6 @@ static const char * constLastFmHost="ws.audioscrobbler.com";
 static const char * constGoogleHost="images.google.com";
 static const char * constDiscogsHost="api.discogs.com";
 static const char * constCoverArtArchiveHost="coverartarchive.org";
-static const char * constAmazonHost="ecs.amazonaws.com";
-static const char * constAmazonUrl="http://ecs.amazonaws.com/onca/xml";
-static const char * constAmazonAssociateTag="cantata";
 
 static const int constMaxRedirects=5;
 
@@ -538,8 +488,6 @@ void CoverDialog::queryJobFinished()
                 parseDiscogsQueryResponse(resp);
             } else if (constCoverArtArchiveHost==host) {
                 parseCoverArtArchiveQueryResponse(resp);
-            } else if (constAmazonHost==host) {
-                parseAmazonQueryResponse(resp);
             }
         }
     }
@@ -673,23 +621,13 @@ void CoverDialog::downloadJobFinished()
                     if (constLastFmHost==host) {
                         item=new LastFmCover(reply->property(constLargeProperty).toString(), url, img, list);
                     } else if (constGoogleHost==host) {
-                        int w=reply->property(constWidthProperty).toInt();
-                        int h=reply->property(constHeightProperty).toInt();
-                        if (canUse(w, h)) {
-                            item=new GoogleCover(reply->property(constLargeProperty).toString(), url, img, w, h,
-                                                 reply->property(constSizeProperty).toInt(), list);
-                        }
+                        item=new GoogleCover(reply->property(constLargeProperty).toString(), url, img, reply->property(constWidthProperty).toInt(),
+                                             reply->property(constHeightProperty).toInt(), reply->property(constSizeProperty).toInt(), list);
                     } else if (constDiscogsHost==host) {
-                        int w=reply->property(constWidthProperty).toInt();
-                        int h=reply->property(constHeightProperty).toInt();
-                        if (canUse(w, h)) {
-                            item=new DiscogsCover(reply->property(constLargeProperty).toString(), url, img, w, h, list);
-                        }
+                        item=new DiscogsCover(reply->property(constLargeProperty).toString(), url, img, reply->property(constWidthProperty).toInt(),
+                                              reply->property(constHeightProperty).toInt(), list);
                     } else if (constCoverArtArchiveHost==host) {
                         item=new CoverArtArchiveCover(reply->property(constLargeProperty).toString(), url, img, list);
-                    } else if (constAmazonHost==host) {
-                        item=new AmazonCover(reply->property(constLargeProperty).toString(), url, img,
-                                             reply->property(constWidthProperty).toInt(), reply->property(constHeightProperty).toInt(), list);
                     }
                     if (item) {
                         insertItem(item);
@@ -791,10 +729,7 @@ void CoverDialog::sendQuery()
     currentQueryString=fixedQuery;
     sendLastFmQuery(fixedQuery, page);
     sendGoogleQuery(fixedQuery, page);
-    if (!isArtist) {
-        sendDiscoGsQuery(fixedQuery, page);
-        sendAmazonQuery(fixedQuery, page);
-    }
+    sendDiscoGsQuery(fixedQuery, page);
 }
 
 void CoverDialog::sendLastFmQuery(const QString &fixedQuery, int page)
@@ -853,7 +788,7 @@ void CoverDialog::sendDiscoGsQuery(const QString &fixedQuery, int page)
     url.setPath("/search");
     query.addQueryItem("page", QString::number(page + 1));
     query.addQueryItem("per_page", QString::number(20));
-    query.addQueryItem("type", "release");
+    query.addQueryItem("type", isArtist ? "artist" : "release");
     query.addQueryItem("q", fixedQuery);
     query.addQueryItem("f", "json");
     #if QT_VERSION >= 0x050000
@@ -862,65 +797,6 @@ void CoverDialog::sendDiscoGsQuery(const QString &fixedQuery, int page)
     sendQueryRequest(url);
 }
 
-void CoverDialog::sendAmazonQuery(const QString &fixedQuery, int page)
-{
-    #if QT_VERSION < 0x050000
-    if (0!=page || amazonAccessKey.isEmpty()) {
-        return;
-    }
-
-    // Taken from Clementine!!!
-    typedef QPair<QString, QString> Arg;
-    typedef QList<Arg> ArgList;
-    typedef QPair<QByteArray, QByteArray> EncodedArg;
-    typedef QList<EncodedArg> EncodedArgList;
-
-    ArgList args = ArgList()
-            << Arg("AWSAccessKeyId", amazonAccessKey)
-            << Arg("AssociateTag", constAmazonAssociateTag)
-            << Arg("Keywords", fixedQuery)
-            << Arg("Operation", "ItemSearch")
-            << Arg("ResponseGroup", "Images")
-            << Arg("SearchIndex", "All")
-            << Arg("Service", "AWSECommerceService")
-            << Arg("Timestamp", QDateTime::currentDateTime().toString("yyyy-MM-ddThh:mm:ss.zzzZ"))
-            << Arg("Version", "2009-11-01");
-    EncodedArgList encodedArgs;
-    QStringList queryItems;
-
-    // Encode the arguments
-    foreach (const Arg& arg, args) {
-        EncodedArg encodedArg(QUrl::toPercentEncoding(arg.first), QUrl::toPercentEncoding(arg.second));
-        encodedArgs << encodedArg;
-        queryItems << encodedArg.first+"="+encodedArg.second;
-    }
-
-    // Sign the request
-    QUrl url(constAmazonUrl);
-    #if QT_VERSION < 0x050000
-    QUrl &query=url;
-    #else
-    QUrlQuery query;
-    #endif
-
-    const QByteArray dataToSign = QString("GET\n%1\n%2\n%3").arg(url.host()).arg(url.path()).arg(queryItems.join("&")).toAscii();
-    const QByteArray signature(hmacSha256(amazonSecretAccessKey.toLatin1(), dataToSign));
-
-    // Add the signature to the request
-    encodedArgs << EncodedArg("Signature", QUrl::toPercentEncoding(signature.toBase64()));
-    query.setEncodedQueryItems(encodedArgs);
-    #if QT_VERSION >= 0x050000
-    url.setQuery(query);
-    #endif
-    sendQueryRequest(url);
-
-    #else
-    // Qt5 has no non-deprecated version of 'setEncodedQueryItems', so for the moment Amazon searches are disabled for Qt5 builds...
-    Q_UNUSED(fixedQuery)
-    Q_UNUSED(page)
-    #endif
-}
-
 void CoverDialog::checkStatus()
 {
     QList<QListWidgetItem*> items=list->selectedItems();
@@ -1170,7 +1046,7 @@ void CoverDialog::parseGoogleQueryResponse(const QByteArray &resp)
         #endif
         int width=url.queryItemValue("w").toInt();
         int height=url.queryItemValue("h").toInt();
-        if (width>=100 && height>=100) {
+        if (canUse(width, height)) {
             QString largeUrl=url.queryItemValue("imgurl");
             QString thumbUrl=rx.cap(2);
             if (!thumbUrl.isEmpty() && !largeUrl.isEmpty()) {
@@ -1204,7 +1080,7 @@ void CoverDialog::parseDiscogsQueryResponse(const QByteArray &resp)
                     QVariantList results=searchresults["results"].toList();
                     foreach (const QVariant &r, results) {
                         QVariantMap rm=r.toMap();
-                        if (rm.contains("uri")) {
+                        if (!isArtist && rm.contains("uri")) {
                             QStringList parts=rm["uri"].toString().split("/", QString::SkipEmptyParts);
                             if (!parts.isEmpty()) {
                                 QUrl discogsUrl;
@@ -1222,19 +1098,18 @@ void CoverDialog::parseDiscogsQueryResponse(const QByteArray &resp)
                                 #endif
                                 sendQueryRequest(discogsUrl);
                             }
+                        } else if (isArtist && rm.contains("thumb")) {
+                            QString thumbUrl=rm["thumb"].toString();
+                            if (thumbUrl.contains("/image/A-150-")) {
+                                QString largeUrl=thumbUrl.replace("image/A-150-", "/image/A-");
+                                QNetworkReply *j=downloadImage(thumbUrl, DL_Thumbnail);
+                                if (j) {
+                                    j->setProperty(constHostProperty, constDiscogsHost);
+                                    j->setProperty(constLargeProperty, largeUrl);
+                                    j->setProperty(constThumbProperty, thumbUrl);
+                                }
+                            }
                         }
-//                        if (rm.contains("thumb")) {
-//                            QString thumbUrl=rm["thumb"].toString();
-//                            if (thumbUrl.contains("/image/R-150-")) {
-//                                QString largeUrl=thumbUrl.replace("image/R-150-", "/image/R-");
-//                                QNetworkReply *j=downloadImage(thumbUrl, DL_Thumbnail);
-//                                if (j) {
-//                                    j->setProperty(constHostProperty, constDiscogsHost);
-//                                    j->setProperty(constLargeProperty, largeUrl);
-//                                    j->setProperty(constThumbProperty, thumbUrl);
-//                                }
-//                            }
-//                        }
                     }
                 }
             }
@@ -1244,7 +1119,8 @@ void CoverDialog::parseDiscogsQueryResponse(const QByteArray &resp)
                 QVariantList images=release["images"].toList();
                 foreach (const QVariant &i, images) {
                     QVariantMap im=i.toMap();
-                    if (im.contains("uri") && im.contains("uri150")) {
+                    if (im.contains("uri") && im.contains("uri150") && im.contains("width") && im.contains("height") &&
+                        canUse(im["width"].toString().toInt(), im["height"].toString().toInt())) {
                         QString thumbUrl=im["uri150"].toString();
                         QString largeUrl=im["uri"].toString();
                         if (!thumbUrl.isEmpty() && !largeUrl.isEmpty()) {
@@ -1295,93 +1171,6 @@ void CoverDialog::parseCoverArtArchiveQueryResponse(const QByteArray &resp)
     }
 }
 
-struct AmazonImage
-{
-    AmazonImage() : w(-1), h(-1) { }
-    bool isNull() { return w<0 || h<0 || url.isEmpty(); }
-    QString url;
-    int w;
-    int h;
-};
-
-struct AmazonEntry
-{
-    AmazonImage small;
-    AmazonImage large;
-};
-
-static AmazonImage readImage(QXmlStreamReader &doc)
-{
-    AmazonImage image;
-    QString tag=doc.name().toString();
-
-    while (!doc.atEnd()) {
-        doc.readNext();
-        if (QXmlStreamReader::StartElement==doc.tokenType()) {
-            if (QLatin1String("URL")==doc.name()) {
-                image.url= doc.readElementText();
-            } else if (QLatin1String("Width")==doc.name()) {
-                image.w=doc.readElementText().toInt();
-            } else if (QLatin1String("Height")==doc.name()) {
-                image.h=doc.readElementText().toInt();
-            } else {
-                doc.skipCurrentElement();
-            }
-        } else if (QXmlStreamReader::EndElement==doc.tokenType() && tag==doc.name()) {
-            break;
-        }
-    }
-    return image;
-}
-
-static AmazonEntry readItem(QXmlStreamReader &doc)
-{
-    AmazonEntry entry;
-    QString tag=doc.name().toString();
-    while (!doc.atEnd()) {
-        doc.readNext();
-        if (QXmlStreamReader::StartElement==doc.tokenType()) {
-            if (QLatin1String("LargeImage")==doc.name()) {
-                entry.large=readImage(doc);
-            } else if (QLatin1String("SmallImage")==doc.name()) {
-                entry.small=readImage(doc);
-            } else if (entry.small.h<0 && QLatin1String("MediumImage")==doc.name()) {
-                entry.small=readImage(doc);
-            } else {
-                doc.skipCurrentElement();
-            }
-        } else if (QXmlStreamReader::EndElement==doc.tokenType() && tag==doc.name()) {
-            break;
-        }
-    }
-    return entry;
-}
-
-void CoverDialog::parseAmazonQueryResponse(const QByteArray &resp)
-{
-    QXmlStreamReader doc(resp);
-
-    while (!doc.atEnd()) {
-      doc.readNext();
-        if (QXmlStreamReader::StartElement==doc.tokenType()) {
-            if (QLatin1String("Item")==doc.name()) {
-                AmazonEntry entry=readItem(doc);
-
-                if (!entry.small.isNull() && !entry.large.isNull()) {
-                    QNetworkReply *j=downloadImage(entry.small.url, DL_Thumbnail);
-                    if (j) {
-                        j->setProperty(constHostProperty, constAmazonHost);
-                        j->setProperty(constLargeProperty, entry.large.url);
-                        j->setProperty(constThumbProperty, entry.small.url);
-                        j->setProperty(constWidthProperty, entry.large.w);
-                        j->setProperty(constHeightProperty, entry.large.h);
-                    }
-                }
-            }
-        }
-    }
-}
-
 void CoverDialog::slotButtonClicked(int button)
 {
     switch (button) {
@@ -1484,7 +1273,7 @@ bool CoverDialog::saveCover(const QString &src, const QImage &img)
         if (existing && !existingBackup.isEmpty()) {
             QFile::rename(existingBackup, existing->url());
         }
-        MessageBox::error(this, i18n("Failed to set cover!\nCould not copy file to '%1'!").arg(destName));
+        MessageBox::error(this, i18n("Failed to set cover!\nCould not copy file to '%1'!", destName));
         return false;
     }
 }
