@@ -774,6 +774,7 @@ void CoverLocator::locate()
 Covers::Covers()
     : retrieved(0)
     , cache(300000)
+    , countResetTimer(0)
 {
     qRegisterMetaType<LocatedCover>("LocatedCover");
     qRegisterMetaType<QList<LocatedCover> >("QList<LocatedCover>");
@@ -1081,9 +1082,25 @@ Covers::Image Covers::requestImage(const Song &song)
         DBUG << song.file << song.artist << song.albumartist << song.album << "Need to download";
         emit download(song);
     }
+
+    // We only want to read X files per QEventLoop iteratation. The above takes care of this, and any
+    // extra requests are handled via the 'emit locate' However, after the QEVentLoop, we want to reset
+    // this count back to 0. To do this, create a QTimer with a timout of 0 seconds. This should fire
+    // immediately after the current QEventLoop event.
+    if (!countResetTimer) {
+        countResetTimer=new QTimer(this);
+        countResetTimer->setSingleShot(true);
+        connect(countResetTimer, SIGNAL(timeout()), SLOT(clearCount()), Qt::QueuedConnection);
+    }
+    countResetTimer->start(0);
     return fix(img);
 }
 
+void Covers::clearCount()
+{
+    retrieved=0;
+}
+
 void Covers::located(const QList<LocatedCover> &covers)
 {
     foreach (const LocatedCover &cvr, covers) {
