@@ -29,7 +29,11 @@
 #include "icons.h"
 #include "mpduser.h"
 #include <QDir>
-#include <QDebug>
+#if QT_VERSION > 0x050000
+#include <QStandardPaths>
+#else
+#include <QDesktopServices>
+#endif
 
 enum Pages {
     PAGE_INTRO,
@@ -112,7 +116,7 @@ InitialSettingsWizard::~InitialSettingsWizard()
 MPDConnectionDetails InitialSettingsWizard::getDetails()
 {
     if (basic->isChecked()) {
-        MPDUser::self()->setMusicFolder(basicDir->text());
+        MPDUser::self()->setMusicFolder(basicDir->text().trimmed());
         return MPDUser::self()->details(true);
     }
     MPDConnectionDetails det;
@@ -149,8 +153,15 @@ void InitialSettingsWizard::pageChanged(int p)
     if (PAGE_CONNECTION==p) {
         connectionStack->setCurrentIndex(basic->isChecked() ? 1 : 0);
         if (basic->isChecked() && basicDir->text().isEmpty()) {
-            QString dir=QDir::homePath()+"/Music";
-            dir=dir.replace("//", "/");
+            #if QT_VERSION > 0x050000
+            QString dir=QStandardPaths::writableLocation(QStandardPaths::MusicLocation);
+            #else
+            QString dir=QDesktopServices::storageLocation(QDesktopServices::MusicLocation);
+            #endif
+            if (dir.isEmpty()) {
+                QString dir=QDir::homePath()+"/Music";
+                dir=dir.replace("//", "/");
+            }
             basicDir->setText(dir);
         }
         controlNextButton();
