@@ -129,11 +129,11 @@ void InterfaceSettings::load()
     playQueueAutoExpand->setChecked(Settings::self()->playQueueAutoExpand());
     playQueueStartClosed->setChecked(Settings::self()->playQueueStartClosed());
     playQueueScroll->setChecked(Settings::self()->playQueueScroll());
+    playQueueBackground->setChecked(Settings::self()->playQueueBackground());
     albumsViewChanged();
     albumsCoverSizeChanged();
     playListsStyleChanged();
     playQueueGroupedChanged();
-    lyricsBgnd->setChecked(Settings::self()->lyricsBgnd());
     forceSingleClick->setChecked(Settings::self()->forceSingleClick());
     systemTrayCheckBox->setChecked(Settings::self()->useSystemTray());
     systemTrayPopup->setChecked(Settings::self()->showPopups());
@@ -169,7 +169,7 @@ void InterfaceSettings::save()
     Settings::self()->savePlayQueueAutoExpand(playQueueAutoExpand->isChecked());
     Settings::self()->savePlayQueueStartClosed(playQueueStartClosed->isChecked());
     Settings::self()->savePlayQueueScroll(playQueueScroll->isChecked());
-    Settings::self()->saveLyricsBgnd(lyricsBgnd->isChecked());
+    Settings::self()->savePlayQueueBackground(playQueueBackground->isChecked());
     Settings::self()->saveForceSingleClick(forceSingleClick->isChecked());
     Settings::self()->saveUseSystemTray(systemTrayCheckBox->isChecked());
     Settings::self()->saveShowPopups(systemTrayPopup->isChecked());
@@ -187,10 +187,13 @@ void InterfaceSettings::libraryViewChanged()
     }
 
     bool isIcon=ItemView::Mode_IconTop==vt;
-    libraryArtistImage->setEnabled(!isIcon);
+    bool isSimpleTree=ItemView::Mode_SimpleTree==vt;
+    libraryArtistImage->setEnabled(!isIcon && !isSimpleTree);
     libraryArtistImageLabel->setEnabled(libraryArtistImage->isEnabled());
     if (isIcon) {
         libraryArtistImage->setChecked(true);
+    } else if (isSimpleTree) {
+        libraryArtistImage->setChecked(false);
     }
 }
 
