@@ -30,12 +30,28 @@
 
 class PlaybackSettings : public QWidget, private Ui::PlaybackSettings
 {
+    Q_OBJECT
+
 public:
     PlaybackSettings(QWidget *p);
     virtual ~PlaybackSettings() { }
 
     void load();
     void save();
+
+Q_SIGNALS:
+    // These are for communicating with MPD object (which is in its own thread, so need to talk via signal/slots)
+    void getReplayGain();
+    void setReplayGain(const QString &);
+    void setCrossFade(int secs);
+    void outputs();
+    void enableOutput(int id, bool);
+
+private Q_SLOTS:
+    void replayGainSetting(const QString &rg);
+    void updateOutputs(const QList<Output> &outputs);
+    void mpdConnectionStateChanged(bool c);
+    void showAboutReplayGain();
 };
 
 #endif
