@@ -27,21 +27,23 @@
 #include "icons.h"
 #include "interfacesettings.h"
 #include "serversettings.h"
-#include "serverplaybacksettings.h"
 #include "playbacksettings.h"
 #include "filesettings.h"
 #ifdef TAGLIB_FOUND
 #include "httpserversettings.h"
 #endif
-#include "lyricsettings.h"
+#include "contextsettings.h"
 #include "cachesettings.h"
 #include "localize.h"
 #include "mpdconnection.h"
 #include "pagewidget.h"
-#ifndef ENABLE_KDE_SUPPORT
+#ifdef ENABLE_PROXY_CONFIG
 #include "proxysettings.h"
+#endif
+#ifndef ENABLE_KDE_SUPPORT
 #include "shortcutssettingspage.h"
 #include "actioncollection.h"
+#include "basicitemdelegate.h"
 #endif
 #if defined CDDB_FOUND || defined MUSICBRAINZ5_FOUND
 #include "audiocdsettings.h"
@@ -55,59 +57,69 @@ int PreferencesDialog::instanceCount()
 }
 
 PreferencesDialog::PreferencesDialog(QWidget *parent)
-    : Dialog(parent, "PreferencesDialog", QSize(800, 600))
+    : Dialog(parent, "PreferencesDialog")
 {
     iCount++;
     setButtons(Ok|Apply|Cancel);
 
     PageWidget *widget = new PageWidget(this);
-    server = new ServerSettings(widget);
-    serverplayback = new ServerPlaybackSettings(widget);
-    playback = new PlaybackSettings(widget);
-    files = new FileSettings(widget);
-    interface = new InterfaceSettings(widget);
-    lyrics = new LyricSettings(widget);
-    cache = new CacheSettings(widget);
+    server = new ServerSettings(0);
+    playback = new PlaybackSettings(0);
+    files = new FileSettings(0);
+    interface = new InterfaceSettings(0);
+    context = new ContextSettings(0);
+    cache = new CacheSettings(0);
     server->load();
-    serverplayback->load();
     playback->load();
     files->load();
     interface->load();
-    lyrics->load();
-    widget->addPage(server, i18n("Connection"), Icons::libraryIcon, i18n("Connection Settings"));
-    widget->addPage(serverplayback, i18n("Output"), Icons::speakerIcon, i18n("Output Settings"));
+    context->load();
+    widget->addPage(server, i18n("Collection"), Icons::self()->libraryIcon, i18n("Collection Settings"));
     widget->addPage(playback, i18n("Playback"), Icon("media-playback-start"), i18n("Playback Settings"));
-    widget->addPage(files, i18n("Files"), Icons::filesIcon, i18n("File Settings"));
+    widget->addPage(files, i18n("Files"), Icons::self()->filesIcon, i18n("File Settings"));
     widget->addPage(interface, i18n("Interface"), Icon("preferences-other"), i18n("Interface Settings"));
+    widget->addPage(context, i18n("Context"), Icons::self()->contextIcon, i18n("Context View Settings"));
     #ifdef TAGLIB_FOUND
-    http = new HttpServerSettings(widget);
-    http->load();
-    widget->addPage(http, i18n("HTTP Server"), Icon("network-server"), i18n("HTTP Server Settings"));
+    http = new HttpServerSettings(0);
+    if (http->haveMultipleInterfaces()) {
+        http->load();
+        widget->addPage(http, i18n("HTTP Server"), Icon("network-server"), i18n("HTTP Server Settings"));
+    } else {
+        http->deleteLater();
+        http=0;
+    }
     #endif
-    widget->addPage(lyrics, i18n("Lyrics"), Icons::lyricsIcon, i18n("Lyrics Settings"));
     #if defined CDDB_FOUND || defined MUSICBRAINZ5_FOUND
-    audiocd = new AudioCdSettings(widget);
+    audiocd = new AudioCdSettings(0);
     audiocd->load();
     widget->addPage(audiocd, i18n("Audio CD"), Icon("media-optical"), i18n("Audio CD Settings"));
     #endif
-    #ifndef ENABLE_KDE_SUPPORT
-    proxy = new ProxySettings(widget);
+    #ifdef ENABLE_PROXY_CONFIG
+    proxy = new ProxySettings(0);
     proxy->load();
-    widget->addPage(proxy, i18nc("Qt-only", "Proxy"), Icon("preferences-system-network"), i18nc("Qt-only", "Proxy Settings"));
+    widget->addPage(proxy, i18n("Proxy"), Icon("preferences-system-network"), i18nc("Qt-only", "Proxy Settings"));
+    #endif
+    #ifndef ENABLE_KDE_SUPPORT
     QHash<QString, ActionCollection *> map;
     map.insert("Cantata", ActionCollection::get());
     shortcuts = new ShortcutsSettingsPage(map, widget);
-    widget->addPage(shortcuts, i18nc("Qt-only", "Shortcuts"), Icons::shortcutsIcon, i18nc("Qt-only", "Keyboard Shortcut Settings"));
+    widget->addPage(shortcuts, i18nc("Qt-only", "Shortcuts"), Icons::self()->shortcutsIcon, i18nc("Qt-only", "Keyboard Shortcut Settings"));
+    shortcuts->view()->setAlternatingRowColors(false);
+    shortcuts->view()->setItemDelegate(new BasicItemDelegate(shortcuts->view()));
     #endif
     widget->addPage(cache, i18n("Cache"), Icon("folder"), i18n("Cached Items"));
+//    widget->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);
     widget->allPagesAdded();
+    #ifndef ENABLE_KDE_SUPPORT
+    int h=(widget->minimumHeight()/widget->count())*(qMax(widget->count(), 10)+0.5);
+    setMinimumHeight(h);
+    setMinimumWidth(h*1.333);
+    #endif
     setCaption(i18n("Configure"));
     setMainWidget(widget);
     setAttribute(Qt::WA_DeleteOnClose);
-    connect(server, SIGNAL(connectTo(const MPDConnectionDetails &)), SIGNAL(connectTo(const MPDConnectionDetails &)));
-    connect(server, SIGNAL(disconnectFromMpd()), MPDConnection::self(), SLOT(disconnectMpd()));
     connect(files, SIGNAL(reloadStreams()), SIGNAL(reloadStreams()));
-    widget->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
+    setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
 }
 
 PreferencesDialog::~PreferencesDialog()
@@ -119,21 +131,24 @@ void PreferencesDialog::writeSettings()
 {
     // *Must* save server settings first, so that MPD settings go to the correct instance!
     server->save();
-    serverplayback->save();
     playback->save();
     files->save();
     interface->save();
     #ifdef TAGLIB_FOUND
-    http->save();
+    if (http) {
+        http->save();
+    }
     #endif
     #ifndef ENABLE_KDE_SUPPORT
+    #ifdef ENABLE_PROXY_CONFIG
     proxy->save();
+    #endif
     shortcuts->save();
     #endif
     #if defined CDDB_FOUND || defined MUSICBRAINZ5_FOUND
     audiocd->save();
     #endif
-    lyrics->save();
+    context->save();
     Settings::self()->save();
     emit settingsSaved();
 }
@@ -146,6 +161,7 @@ void PreferencesDialog::slotButtonClicked(int button)
         writeSettings();
         break;
     case Cancel:
+        server->cancel();
         reject();
         // Need to call this - if not, when dialog is closed by window X control, it is not deleted!!!!
         Dialog::slotButtonClicked(button);
