@@ -32,15 +32,14 @@ class ShortcutsSettingsPage;
 #endif
 
 class ServerSettings;
-class ServerPlaybackSettings;
 class PlaybackSettings;
 class FileSettings;
 class InterfaceSettings;
-class LyricSettings;
+class ContextSettings;
 #ifdef TAGLIB_FOUND
 class HttpServerSettings;
 #endif
-class MPDConnectionDetails;
+struct MPDConnectionDetails;
 class CacheSettings;
 #if defined CDDB_FOUND || defined MUSICBRAINZ5_FOUND
 class AudioCdSettings;
@@ -64,21 +63,21 @@ private Q_SLOTS:
 
 Q_SIGNALS:
     void settingsSaved();
-    void connectTo(const MPDConnectionDetails &details);
     void reloadStreams();
 
 private:
     ServerSettings *server;
-    ServerPlaybackSettings *serverplayback;
     PlaybackSettings *playback;
     FileSettings *files;
     InterfaceSettings *interface;
-    LyricSettings *lyrics;
+    ContextSettings *context;
     #ifdef TAGLIB_FOUND
     HttpServerSettings *http;
     #endif
-    #ifndef ENABLE_KDE_SUPPORT
+    #ifdef ENABLE_PROXY_CONFIG
     ProxySettings *proxy;
+    #endif
+    #ifndef ENABLE_KDE_SUPPORT
     ShortcutsSettingsPage *shortcuts;
     #endif
     CacheSettings *cache;
