@@ -29,11 +29,17 @@
 #include "icons.h"
 #include "musiclibrarymodel.h"
 #include "mpduser.h"
+#include "utils.h"
 #include <QDir>
 #include <QComboBox>
 #include <QPushButton>
 #include <QValidator>
 #include <QStyle>
+#if QT_VERSION > 0x050000
+#include <QStandardPaths>
+#else
+#include <QDesktopServices>
+#endif
 
 class CoverNameValidator : public QValidator
 {
@@ -126,13 +132,14 @@ void ServerSettings::load()
     combo->clear();
     int idx=0;
     haveBasicCollection=false;
-    foreach (const MPDConnectionDetails &d, all) {
+    foreach (MPDConnectionDetails d, all) {
         combo->addItem(d.getName(), d.name);
         if (d.name==currentCon) {
             prevIndex=idx;
         }
         idx++;
         if (d.name==MPDUser::constName) {
+            d.dir=MPDUser::self()->details().dir;
             haveBasicCollection=true;
             prevBasic=d;
         }
@@ -243,12 +250,23 @@ void ServerSettings::add()
         details.name=generateName();
         details.port=6600;
         details.hostname=QLatin1String("localhost");
-        details.dir=QLatin1String("/var/lib/mpd/music");
+        details.dir=QLatin1String("/var/lib/mpd/music/");
         details.dynamizerPort=0;
         combo->addItem(details.name);
     } else {
         details=MPDUser::self()->details(true);
-        basicDir->setText(details.dir);
+        #if QT_VERSION > 0x050000
+        QString dir=QStandardPaths::writableLocation(QStandardPaths::MusicLocation);
+        #else
+        QString dir=QDesktopServices::storageLocation(QDesktopServices::MusicLocation);
+        #endif
+        if (dir.isEmpty()) {
+            QString dir=QDir::homePath()+"/Music";
+            dir=dir.replace("//", "/");
+        }
+        dir=Utils::fixPath(dir);
+        basicDir->setText(dir);
+        MPDUser::self()->setMusicFolder(dir);
         combo->addItem(MPDUser::translatedName());
     }
     removeButton->setEnabled(combo->count()>1);
@@ -285,7 +303,7 @@ void ServerSettings::nameChanged()
 void ServerSettings::basicDirChanged()
 {
     if (!prevBasic.details.dir.isEmpty()) {
-        QString d=basicDir->text().trimmed();
+        QString d=Utils::fixPath(basicDir->text().trimmed());
         basicMusicFolderNoteLabel->setOn(d.isEmpty() || d!=prevBasic.details.dir);
     }
 }
@@ -339,13 +357,14 @@ MPDConnectionDetails ServerSettings::getDetails() const
         details.hostname=host->text().trimmed();
         details.port=port->value();
         details.password=password->text();
-        details.dir=dir->text().trimmed();
+        details.dir=Utils::fixPath(dir->text().trimmed());
         details.dynamizerPort=dynamizerPort->value();
         details.coverName=coverName->text().trimmed();
     } else {
         details=MPDUser::self()->details(true);
-        details.dir=basicDir->text().trimmed();
+        details.dir=Utils::fixPath(basicDir->text().trimmed());
         details.coverName=basicCoverName->text().trimmed();
+        MPDUser::self()->setMusicFolder(details.dir);
     }
     details.dirReadable=details.dir.isEmpty() ? false : QDir(details.dir).isReadable();
     return details;
