@@ -105,7 +105,6 @@ public:
     bool minimiseOnClose();
     bool showPopups();
     bool stopOnExit();
-    bool stopAfterCurrent();
     bool stopDynamizerOnExit();
     bool storeCoversInMpdDir();
     bool storeLyricsInMpdDir();
@@ -125,9 +124,13 @@ public:
     bool groupSingle();
     bool groupMultiple();
     QStringList lyricProviders();
-    int lyricsZoom();
-    bool lyricsBgnd();
-    int infoZoom();
+    QStringList wikipediaLangs();
+    bool wikipediaIntroOnly();
+    bool contextBackdrop();
+    bool contextDarkBackground();
+    int contextZoom();
+    QString contextSlimPage();
+    QByteArray contextSplitterState();
     QString page();
     QStringList hiddenPages();
     bool gnomeMediaKeys();
@@ -139,26 +142,23 @@ public:
     int version();
     int stopFadeDuration();
     #ifdef TAGLIB_FOUND
-    int httpPort();
     int httpAllocatedPort();
-    QString httpAddress();
-    bool enableHttp();
-    bool alwaysUseHttp();
+    QString httpInterface();
     #endif
     bool playQueueGrouped();
     bool playQueueAutoExpand();
     bool playQueueStartClosed();
     bool playQueueScroll();
+    bool playQueueBackground();
     bool playListsStartClosed();
-    #ifdef PHONON_FOUND
+    #ifdef ENABLE_HTTP_STREAM_PLAYBACK
     bool playStream();
     QString streamUrl();
     #endif
     #if defined CDDB_FOUND || defined MUSICBRAINZ5_FOUND
     bool cdAuto();
-    #ifdef LAME_FOUND
-    bool cdEncode();
-    #endif
+    bool paranoiaFull();
+    bool paranoiaNeverSkip();
     #endif
     #if defined CDDB_FOUND && defined MUSICBRAINZ5_FOUND
     bool useCddb();
@@ -166,13 +166,11 @@ public:
     #ifdef CDDB_FOUND
     QString cddbHost();
     int cddbPort();
-    bool paranoiaFull();
-    bool paranoiaNeverSkip();
     #endif
     bool forceSingleClick();
     bool startHidden();
-    QString amazonAccessKey();
-    QString amazonSecretAccessKey();
+    bool monoSidebarIcons();
+    bool showTimeRemaining();
 
     void removeConnectionDetails(const QString &v);
     void saveConnectionDetails(const MPDConnectionDetails &v);
@@ -181,7 +179,6 @@ public:
     void saveShowFullScreen(bool v);
     void saveStopOnExit(bool v);
     void saveStopDynamizerOnExit(bool v);
-    void saveStopAfterCurrent(bool v);
     void savePlayQueueHeaderState(const QByteArray &v);
     void saveSplitterState(const QByteArray &v);
     void saveSplitterAutoHide(bool v);
@@ -208,9 +205,13 @@ public:
     void saveGroupSingle(bool v);
     void saveGroupMultiple(bool v);
     void saveLyricProviders(const QStringList &v);
-    void saveLyricsZoom(int v);
-    void saveLyricsBgnd(bool v);
-    void saveInfoZoom(int v);
+    void saveWikipediaLangs(const QStringList &v);
+    void saveWikipediaIntroOnly(bool v);
+    void saveContextBackdrop(bool v);
+    void saveContextDarkBackground(bool v);
+    void saveContextZoom(int v);
+    void saveContextSlimPage(const QString &v);
+    void saveContextSplitterState(const QByteArray &v);
     void savePage(const QString &v);
     void saveHiddenPages(const QStringList &v);
     void saveGnomeMediaKeys(bool v);
@@ -221,26 +222,23 @@ public:
     #endif
     void saveStopFadeDuration(int v);
     #ifdef TAGLIB_FOUND
-    void saveHttpPort(int v);
     void saveHttpAllocatedPort(int v);
-    void saveHttpAddress(const QString &v);
-    void saveEnableHttp(bool v);
-    void saveAlwaysUseHttp(bool v);
+    void saveHttpInterface(const QString &v);
     #endif
     void savePlayQueueGrouped(bool v);
     void savePlayQueueAutoExpand(bool v);
     void savePlayQueueStartClosed(bool v);
     void savePlayQueueScroll(bool v);
+    void savePlayQueueBackground(bool v);
     void savePlayListsStartClosed(bool v);
-    #ifdef PHONON_FOUND
+    #ifdef ENABLE_HTTP_STREAM_PLAYBACK
     void savePlayStream(bool v);
     void saveStreamUrl(const QString &v);
     #endif
     #if defined CDDB_FOUND || defined MUSICBRAINZ5_FOUND
     void saveCdAuto(bool v);
-    #ifdef LAME_FOUND
-    void saveCdEncode(bool v);
-    #endif
+    void saveParanoiaFull(bool v);
+    void saveParanoiaNeverSkip(bool v);
     #endif
     #if defined CDDB_FOUND && defined MUSICBRAINZ5_FOUND
     void saveUseCddb(bool v);
@@ -248,18 +246,17 @@ public:
     #ifdef CDDB_FOUND
     void saveCddbHost(const QString &v);
     void saveCddbPort(int v);
-    void saveParanoiaFull(bool v);
-    void saveParanoiaNeverSkip(bool v);
     #endif
     void saveForceSingleClick(bool v);
     void saveStartHidden(bool v);
+    void saveMonoSidebarIcons(bool v);
+    void saveShowTimeRemaining(bool v);
     void save(bool force=false);
     #ifdef ENABLE_KDE_SUPPORT
     bool openWallet();
     #else
     QString iconTheme();
     #endif
-    bool monoSidebarIcons();
     int id3v2Version();
 
     bool firstRun() const { return isFirstRun; }
