@@ -76,6 +76,7 @@ void TrayItem::setup()
     trayItemMenu->addAction(mw->prevTrackAction);
     trayItemMenu->addAction(mw->playPauseTrackAction);
     trayItemMenu->addAction(mw->stopPlaybackAction);
+    trayItemMenu->addAction(mw->stopAfterCurrentTrackAction);
     trayItemMenu->addAction(mw->nextTrackAction);
     trayItem->setContextMenu(trayItemMenu);
     trayItem->setStatus(KStatusNotifierItem::Active);
@@ -96,13 +97,14 @@ void TrayItem::setup()
     trayItemMenu->addAction(mw->prevTrackAction);
     trayItemMenu->addAction(mw->playPauseTrackAction);
     trayItemMenu->addAction(mw->stopPlaybackAction);
+    trayItemMenu->addAction(mw->stopAfterCurrentTrackAction);
     trayItemMenu->addAction(mw->nextTrackAction);
     trayItemMenu->addSeparator();
     trayItemMenu->addAction(mw->restoreAction);
     trayItemMenu->addSeparator();
     trayItemMenu->addAction(mw->quitAction);
     trayItem->setContextMenu(trayItemMenu);
-    trayItem->setIcon(Icons::appIcon);
+    trayItem->setIcon(Icons::self()->appIcon);
     trayItem->setToolTip(i18n("Cantata"));
     trayItem->show();
     connect(trayItem, SIGNAL(activated(QSystemTrayIcon::ActivationReason)), this, SLOT(trayItemClicked(QSystemTrayIcon::ActivationReason)));
@@ -152,14 +154,19 @@ void TrayItem::trayItemClicked(QSystemTrayIcon::ActivationReason reason)
 void TrayItem::songChanged(const Song &song, bool isPlaying)
 {
     if (Settings::self()->showPopups() || trayItem) {
-        if (!song.title.isEmpty() && !song.artist.isEmpty() &&
-                (!song.album.isEmpty() || (song.isStream() && !song.name.isEmpty()))) {
+        bool isStream=song.isStream() && !song.isCdda() && !song.isCantataStream();
+        bool useable=isStream
+                        ? !song.title.isEmpty() && !song.name.isEmpty()
+                        : !song.title.isEmpty() && !song.artist.isEmpty() && !song.album.isEmpty();
+        if (useable) {
             QString album=song.album.isEmpty() ? song.name : song.album;
-            QString text=song.time<=0
-                            ? i18nc("Song by Artist on Album", "%1 by %2 on %3")
-                                .arg(song.title).arg(song.artist).arg(album)
-                            : i18nc("Song by Artist on Album (track duration)", "%1 by %2 on %3 (%4)")
-                                .arg(song.title).arg(song.artist).arg(album).arg(Song::formattedTime(song.time));
+            QString text=song.artist.isEmpty()
+                            ? song.time<=0
+                              ? i18nc("Song on Album", "%1 on %2", song.title, album)
+                              : i18nc("Song on Album (track duration)", "%1 on %2 (%3)", song.title, album, Song::formattedTime(song.time))
+                            : song.time<=0
+                                ? i18nc("Song by Artist on Album", "%1 by %2 on %3", song.title, song.artist, album)
+                                : i18nc("Song by Artist on Album (track duration)", "%1 by %2 on %3 (%4)", song.title, song.artist, album, Song::formattedTime(song.time));
             if (trayItem) {
                 #ifdef ENABLE_KDE_SUPPORT
                 trayItem->setToolTip("cantata", i18n("Cantata"), text);
