@@ -28,9 +28,6 @@
 #if defined CDDB_FOUND || defined MUSICBRAINZ5_FOUND
 #include "cdparanoia.h"
 #include "extractjob.h"
-#ifdef LAME_FOUND
-#include "lame/lame.h"
-#endif
 #endif
 #include <QTcpSocket>
 #include <QNetworkInterface>
@@ -128,12 +125,21 @@ static QString detectMimeType(const QString &file)
     return QString();
 }
 
-static void writeMimeType(const QString &mimeType, QTcpSocket *socket)
+static void writeMimeType(const QString &mimeType, QTcpSocket *socket, qint32 size, bool allowSeek)
 {
     if (!mimeType.isEmpty()) {
         QTextStream os(socket);
         os.setAutoDetectUnicode(true);
-        os << "HTTP/1.0 200 OK\r\nContent-Type: " << mimeType << "\r\n\r\n";
+        if (allowSeek) {
+            os << "HTTP/1.0 200 OK"
+               << "\r\nAccept-Ranges: bytes"
+               << "\r\nContent-Length: " << QString::number(size)
+               << "\r\nContent-Type: " << mimeType << "\r\n\r\n";
+        } else {
+            os << "HTTP/1.0 200 OK"
+               << "\r\nContent-Length: " << QString::number(size)
+               << "\r\nContent-Type: " << mimeType << "\r\n\r\n";
+        }
     }
 }
 
@@ -144,92 +150,12 @@ static QHostAddress getAddress(const QNetworkInterface &iface)
         QHostAddress hostAddress=addr.ip();
         if (QAbstractSocket::IPv4Protocol==hostAddress.protocol()) {
             return hostAddress;
-            break;
         }
     }
     return QHostAddress();
 }
 
-HttpSocket::HttpSocket(const QString &addr, quint16 p, quint16 prevPort)
-    : QTcpServer(0)
-    , cfgAddress(addr)
-    , terminated(false)
-{
-    QHostAddress a;
-    if (!addr.isEmpty()) {
-        a=QHostAddress(addr);
-
-        if (a.isNull()) {
-            QNetworkInterface iface=QNetworkInterface::interfaceFromName(addr);
-            if (iface.isValid()) {
-                a=getAddress(iface);
-            }
-        }
-    }
-
-    if (a.isNull()) {
-        QList<QNetworkInterface> ifaces=QNetworkInterface::allInterfaces();
-        foreach (const QNetworkInterface &iface, ifaces) {
-            if (QLatin1String("lo")==iface.name()) {
-                continue;
-            }
-            a=getAddress(iface);
-            if (!a.isNull()) {
-                break;
-            }
-        }
-    }
-
-    bool openedPrev=false;
-    if (0==p && 0!=prevPort) {
-        openedPrev=openPort(a, addr, prevPort);
-    }
-
-    if (!openedPrev) {
-        openPort(a, addr, p);
-    }
-    if (isListening() && ifaceAddress.isEmpty()) {
-        ifaceAddress=QLatin1String("127.0.0.1");
-    }
-}
-
-bool HttpSocket::openPort(const QHostAddress &a, const QString &addr, quint16 p)
-{
-    if (listen(QHostAddress::Any, p)) {
-        ifaceAddress=a.isNull() ? serverAddress().toString() : a.toString();
-        return true;
-    } else {
-        bool rv=false;
-        // Failed to liston on 'Any' address
-        if (addr.isEmpty()) {
-            // No specific address was set, so fallback to loopback address...
-            rv=listen(QHostAddress::LocalHost, p);
-            ifaceAddress=QLatin1String("127.0.0.1");
-        } else {
-            // Listen probably failed due to proxy, so unset and try again!
-            setProxy(QNetworkProxy::NoProxy);
-            rv=listen(QHostAddress::Any, p);
-            ifaceAddress=a.isNull() ? serverAddress().toString() : a.toString();
-        }
-        return rv;
-    }
-}
-
-void HttpSocket::terminate()
-{
-    terminated=true;
-    deleteLater();
-}
-
-void HttpSocket::incomingConnection(int socket)
-{
-    QTcpSocket *s = new QTcpSocket(this);
-    connect(s, SIGNAL(readyRead()), this, SLOT(readClient()));
-    connect(s, SIGNAL(disconnected()), this, SLOT(discardClient()));
-    s->setSocketDescriptor(socket);
-}
-
-int getSep(const QByteArray &a, int pos)
+static int getSep(const QByteArray &a, int pos)
 {
     for (int i=pos+1; i<a.length(); ++i) {
         if ('\n'==a[i] || '\r'==a[i] || ' '==a[i]) {
@@ -239,7 +165,7 @@ int getSep(const QByteArray &a, int pos)
     return -1;
 }
 
-QList<QByteArray> split(const QByteArray &a)
+static QList<QByteArray> split(const QByteArray &a)
 {
     QList<QByteArray> rv;
     int lastPos=-1;
@@ -261,6 +187,121 @@ QList<QByteArray> split(const QByteArray &a)
     return rv;
 }
 
+static bool isFromMpd(const QStringList &params)
+{
+    foreach (const QString &str, params) {
+        if (str.startsWith("User-Agent:") && str.contains("Music Player Daemon")) {
+            return true;
+        }
+    }
+    return false;
+}
+
+static void getRange(const QStringList &params, qint32 &from, qint32 &to)
+{
+    foreach (const QString &str, params) {
+        if (str.startsWith("Range:")) {
+            int start=str.indexOf("bytes=");
+            if (start>0) {
+                QStringList range=str.mid(start+6).split("-", QString::SkipEmptyParts);
+                if (1==range.length()) {
+                    from=range.at(0).toLong();
+                } else if (2==range.length()) {
+                    from=range.at(0).toLong();
+                    to=range.at(1).toLong();
+                }
+            }
+            break;
+        }
+    }
+}
+
+HttpSocket::HttpSocket(const QString &iface, quint16 port)
+    : QTcpServer(0)
+    , cfgInterface(iface)
+    , terminated(false)
+{
+    // Get network address...
+    QHostAddress a;
+    if (!iface.isEmpty()) {
+        // Try rquested interface...
+        QNetworkInterface netIface=QNetworkInterface::interfaceFromName(iface);
+        if (netIface.isValid()) {
+            a=getAddress(netIface);
+        }
+    }
+
+    if (a.isNull()) {
+        // Hmm... try first active interface...
+        QNetworkInterface loIface;
+        QList<QNetworkInterface> ifaces=QNetworkInterface::allInterfaces();
+        foreach (const QNetworkInterface &iface, ifaces) {
+            if (iface.flags()&QNetworkInterface::IsUp) {
+                if (QLatin1String("lo")==iface.name()) {
+                    loIface=iface;
+                } else {
+                    a=getAddress(iface);
+                    if (!a.isNull()) {
+                        break;
+                    }
+                }
+            }
+        }
+        if (a.isNull() && !loIface.isValid()) {
+            // Get address of 'loopback' interface...
+            a=getAddress(loIface);
+        }
+    }
+
+    if (!openPort(a, port)) {
+        openPort(a, 0);
+    }
+
+    if (isListening() && ifaceAddress.isEmpty()) {
+        ifaceAddress=QLatin1String("127.0.0.1");
+    }
+}
+
+bool HttpSocket::openPort(const QHostAddress &a, quint16 p)
+{
+    if (!a.isNull() && listen(a, p)) {
+        ifaceAddress=a.toString();
+        return true;
+    }
+    // Listen probably failed due to proxy, so unset and try again!
+    setProxy(QNetworkProxy::NoProxy);
+    if (!a.isNull() && listen(a, p)) {
+        ifaceAddress=a.toString();
+        return true;
+    }
+
+    if (listen(QHostAddress::Any, p)) {
+        ifaceAddress=serverAddress().toString();
+        return true;
+    }
+
+    if (listen(QHostAddress::LocalHost, p)) {
+        ifaceAddress=QLatin1String("127.0.0.1");
+        return true;
+    }
+
+    return false;
+}
+
+void HttpSocket::terminate()
+{
+    terminated=true;
+    deleteLater();
+}
+
+void HttpSocket::incomingConnection(int socket)
+{
+    QTcpSocket *s = new QTcpSocket(this);
+    connect(s, SIGNAL(readyRead()), this, SLOT(readClient()));
+    connect(s, SIGNAL(disconnected()), this, SLOT(discardClient()));
+    s->setSocketDescriptor(socket);
+}
+
 void HttpSocket::readClient()
 {
     if (terminated) {
@@ -271,6 +312,12 @@ void HttpSocket::readClient()
     if (socket->canReadLine()) {
         QList<QByteArray> tokens = split(socket->readLine()); // QRegExp("[ \r\n][ \r\n]*"));
         if (tokens.length()>=2 && "GET"==tokens[0]) {
+            QStringList params = QString(socket->readAll()).split(QRegExp("[\r\n][\r\n]*"));
+
+            if (!isFromMpd(params)) {
+                return;
+            }
+
             #if QT_VERSION < 0x050000
             QUrl url(QUrl::fromEncoded(tokens[1]));
             QUrl &q=url;
@@ -279,6 +326,9 @@ void HttpSocket::readClient()
             QUrlQuery q(url);
             #endif
             bool ok=false;
+            qint32 readBytesFrom=0;
+            qint32 readBytesTo=0;
+            getRange(params, readBytesFrom, readBytesTo);
 
             if (q.hasQueryItem("cantata")) {
                 Song song=HttpServer::self()->decodeUrl(url);
@@ -292,35 +342,21 @@ void HttpSocket::readClient()
                         if (cdparanoia) {
                             int firstSector = cdparanoia.firstSectorOfTrack(song.id);
                             int lastSector = cdparanoia.lastSectorOfTrack(song.id);
+                            qint32 totalSize = ((lastSector-firstSector)+1)*CD_FRAMESIZE_RAW;
                             int count = 0;
+                            //int bytesToDiscard = 0; // Number of bytes to discard in first read sector due to range request in HTTP header
+
+                            //if (readBytesFrom>0) {
+                            //    int sectorsToSeek=readBytesFrom/CD_FRAMESIZE_RAW;
+                            //    firstSector+=sectorsToSeek;
+                            //    bytesToDiscard=readBytesFrom-(sectorsToSeek*CD_FRAMESIZE_RAW);
+                            //}
                             cdparanoia.seek(firstSector, SEEK_SET);
                             ok=true;
-                            #ifdef LAME_FOUND
-                            lame_global_flags *lame=0;
-                            static const int constMp3BufferSize=CD_FRAMESIZE_RAW*2*sizeof(short int);
-                            static const int constPcmSize=CD_FRAMESIZE_RAW/(2*sizeof(short int));
-                            unsigned char mp3Buffer[constMp3BufferSize];
-                            if (Settings::self()->cdEncode()) {
-                                lame = lame_init();
-                                lame_set_num_channels(lame, 2);
-                                lame_set_in_samplerate(lame, 44100);
-                                lame_set_brate(lame, 128);
-                                lame_set_quality(lame, 5);
-                                lame_set_VBR(lame, vbr_off);
-                                if (-1!=lame_init_params(lame)) {
-                                    writeMimeType(QLatin1String("audio/mpeg"), socket);
-                                } else {
-                                    lame_close(lame);
-                                    lame=0;
-                                }
-                            }
-                            if (!lame) {
-                            #endif
-                                writeMimeType(QLatin1String("audio/x-wav"), socket);
-                                ExtractJob::writeWavHeader(*socket);
-                            #ifdef LAME_FOUND
-                            }
-                            #endif
+                            writeMimeType(QLatin1String("audio/x-wav"), socket, totalSize+ExtractJob::constWavHeaderSize, false);
+                            //if (0==readBytesFrom) { // Only write header if we are no seeking...
+                                ExtractJob::writeWavHeader(*socket, totalSize);
+                            //}
                             bool stop=false;
                             while (!terminated && (firstSector+count) <= lastSector && !stop) {
                                 qint16 *buf = cdparanoia.read();
@@ -328,18 +364,17 @@ void HttpSocket::readClient()
                                     break;
                                 }
                                 char *buffer=(char *)buf;
-                                qint64 writePos=0;
-                                qint64 toWrite=CD_FRAMESIZE_RAW;
+                                qint32 writePos=0;
+                                qint32 toWrite=CD_FRAMESIZE_RAW;
 
-                                #ifdef LAME_FOUND
-                                if (lame) {
-                                    toWrite=lame_encode_buffer_interleaved(lame, (short *)buffer, constPcmSize, mp3Buffer, constMp3BufferSize);
-                                    buffer=(char *)mp3Buffer;
-                                }
-                                #endif
+                                //if (0==count && bytesToDiscard) {
+                                //    writePos=bytesToDiscard;
+                                //    toWrite-=bytesToDiscard;
+                                //    bytesToDiscard=0;
+                                //}
 
                                 do {
-                                    qint64 bytesWritten=socket->write(&buffer[writePos], toWrite - writePos);
+                                    qint32 bytesWritten=socket->write(&buffer[writePos], toWrite - writePos);
                                     if (terminated || -1==bytesWritten) {
                                         stop=true;
                                         break;
@@ -349,50 +384,64 @@ void HttpSocket::readClient()
                                 } while (!terminated && writePos<toWrite);
                                 count++;
                             }
-                            #ifdef LAME_FOUND
-                            if (lame) {
-                                lame_close(lame);
-                                lame=0;
-                            }
-                            #endif
                         }
                     }
                     #endif
                 } else {
                     QFile f(url.path());
 
-                    if (f.open(QIODevice::ReadOnly)) {
-                        writeMimeType(detectMimeType(url.path()), socket);
+                    if (f.open(QIODevice::ReadOnly)) {                        
+                        qint32 totalBytes = f.size();
+
+                        writeMimeType(detectMimeType(url.path()), socket, totalBytes, true);
                         ok=true;
-                        static const int constChunkSize=8192;
+                        static const int constChunkSize=32768;
                         char buffer[constChunkSize];
-                        qint64 totalBytes = f.size();
-                        qint64 readPos = 0;
-                        qint64 bytesRead = 0;
+                        qint32 readPos = 0;
+                        qint32 bytesRead = 0;
                         bool stop=false;
 
-                        do {
-                            bytesRead = f.read(buffer, constChunkSize);
-                            readPos+=bytesRead;
-                            if (bytesRead<0 || terminated) {
-                                break;
+                        if (0!=readBytesFrom) {
+                            if (!f.seek(readBytesFrom)) {
+                                ok=false;
                             }
+                            bytesRead+=readBytesFrom;
+                        }
 
-                            qint64 writePos=0;
+                        if (0!=readBytesTo && readBytesTo>readBytesFrom && readBytesTo!=totalBytes) {
+                            totalBytes-=(totalBytes-readBytesTo);
+                        }
+
+                        if (ok) {
                             do {
-                                qint64 bytesWritten = socket->write(&buffer[writePos], bytesRead - writePos);
-                                if (terminated || -1==bytesWritten) {
-                                    stop=true;
+                                bytesRead = f.read(buffer, constChunkSize);
+                                readPos+=bytesRead;
+                                if (bytesRead<0 || terminated) {
                                     break;
                                 }
-                                socket->flush();
-                                writePos+=bytesWritten;
-                            } while (writePos<bytesRead);
 
-                            if (f.atEnd()) {
-                                break;
-                            }
-                        } while ((readPos+bytesRead)<totalBytes && !stop && !terminated);
+                                qint32 writePos=0;
+                                do {
+                                    qint32 bytesWritten = socket->write(&buffer[writePos], bytesRead - writePos);
+                                    if (terminated || -1==bytesWritten) {
+                                        stop=true;
+                                        break;
+                                    }
+                                    socket->flush();
+                                    writePos+=bytesWritten;
+                                } while (writePos<bytesRead);
+
+                                if (f.atEnd()) {
+                                    break;
+                                }
+                                if (QAbstractSocket::ConnectedState==socket->state()) {
+                                    socket->waitForBytesWritten();
+                                }
+                                if (QAbstractSocket::ConnectedState!=socket->state()) {
+                                    break;
+                                }
+                            } while ((readPos+bytesRead)<totalBytes && !stop && !terminated);
+                        }
                     }
                 }
             }
