@@ -83,8 +83,11 @@ public:
         void clearSongs();
         void setSongs(MusicLibraryItemAlbum *ai);
         void setName();
+        quint32 trackCount();
         quint32 totalTime();
+        void updateStats();
         void getCover();
+        void setCover(const QImage &img);
         bool isSingleTracks() const { return Song::SingleTracks==type; }
         const SongItem *getCueFile() const;
         QString artist;
@@ -97,6 +100,7 @@ public:
         bool updated;
         bool coverRequested;
         Song::Type type;
+        quint32 numTracks;
         quint32 time;
     };
 
