@@ -27,15 +27,15 @@
 #include "song.h"
 #include "config.h"
 #include "remotefsdevice.h"
-#include "actionmodel.h"
-#include "cddb.h"
+#include "multimusicmodel.h"
+#include "cdalbum.h"
 #include "musiclibraryproxymodel.h"
 
 class QMimeData;
 class Device;
 class QMenu;
 
-class DevicesModel : public ActionModel
+class DevicesModel : public MultiMusicModel
 {
     Q_OBJECT
 
@@ -46,29 +46,19 @@ public:
 
     DevicesModel(QObject *parent = 0);
     ~DevicesModel();
-    QModelIndex index(int, int, const QModelIndex & = QModelIndex()) const;
-    QModelIndex parent(const QModelIndex &) const;
-    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
-    int rowCount(const QModelIndex &parent = QModelIndex()) const;
-    int columnCount(const QModelIndex &) const;
     QVariant data(const QModelIndex &, int) const;
     Qt::ItemFlags flags(const QModelIndex &index) const;
-    QStringList filenames(const QModelIndexList &indexes, bool playableOnly=false, bool fullPath=false) const;
     QStringList playableUrls(const QModelIndexList &indexes) const;
-    QList<Song> songs(const QModelIndexList &indexes, bool playableOnly=false, bool fullPath=false) const;
     void clear(bool clearConfig=true);
     QMenu * menu() { return itemMenu; }
     Device * device(const QString &udi);
     bool isEnabled() const { return enabled; }
     void setEnabled(bool e);
     void stop();
-    void getDetails(QSet<QString> &artists, QSet<QString> &albumArtists, QSet<QString> &albums, QSet<QString> &genres);
     QMimeData * mimeData(const QModelIndexList &indexes) const;
     #ifdef ENABLE_REMOTE_DEVICES
     void unmountRemote();
     #endif
-    void toggleGrouping();
-    const QSet<QString> & genres() { return devGenres; }
 
     Action * configureAct() const { return configureAction; }
     Action * refreshAct() const { return refreshAction; }
@@ -76,6 +66,7 @@ public:
     Action * disconnectAct() const { return disconnectAction; }
     #if defined CDDB_FOUND || defined MUSICBRAINZ5_FOUND
     Action * editAct() const { return editAction; }
+    void playCd(const QString &dev);
     #endif
 
 public Q_SLOTS:
@@ -94,12 +85,9 @@ public Q_SLOTS:
 private:
     void updateItemMenu();
     void addLocalDevice(const QString &udi);
-    void loadLocal();
     #ifdef ENABLE_REMOTE_DEVICES
     void loadRemote();
     #endif
-    int indexOf(const QString &udi);
-    void updateGenres();
 
 Q_SIGNALS:
     void updateGenres(const QSet<QString> &genres);
@@ -107,11 +95,16 @@ Q_SIGNALS:
     void error(const QString &text);
     void updated(const QModelIndex &idx);
     void matches(const QString &udi, const QList<CdAlbum> &albums);
+    void invalid(const QList<Song> &songs);
+    void updatedDetails(const QList<Song> &songs);
+    void add(const QStringList &files, bool replace, quint8 priorty); // add songs to MPD playqueue
+
+private Q_SLOTS:
+    void play(const QList<Song> &songs);
+    void loadLocal();
 
 private:
-    QList<Device *> devices;
     QSet<QString> volumes;
-    QSet<QString> devGenres;
     QMenu *itemMenu;
     bool enabled;
     bool inhibitMenuUpdate;
@@ -120,6 +113,7 @@ private:
     Action *connectAction;
     Action *disconnectAction;
     #if defined CDDB_FOUND || defined MUSICBRAINZ5_FOUND
+    QString autoplayCd;
     Action *editAction;
     #endif
     friend class Device;
