@@ -30,6 +30,7 @@
 #include <QList>
 #include <QVariant>
 #include <QPixmap>
+#include <QSet>
 #include "musiclibraryitem.h"
 #include "song.h"
 
@@ -68,6 +69,7 @@ public:
     bool hasRealCover() const { return !m_coverIsDefault; }
     quint32 year() const { return m_year; }
     quint32 totalTime();
+    quint32 trackCount();
     void addTracks(MusicLibraryItemAlbum *other);
     bool isSingleTracks() const { return Song::SingleTracks==m_type; }
     void setIsSingleTracks();
@@ -75,6 +77,8 @@ public:
     void append(MusicLibraryItem *i);
     void remove(int row);
     void remove(MusicLibraryItemSong *i);
+    void removeAll(const QSet<QString> &fileNames);
+    QMap<QString, Song> getSongs(const QSet<QString> &fileNames) const;
     bool detectIfIsMultipleArtists();
     bool isMultipleArtists() const { return Song::MultipleArtists==m_type; }
     Song::Type songType() const { return m_type; }
@@ -84,22 +88,30 @@ public:
     const QString & imageUrl() const { return m_imageUrl; }
     void setImageUrl(const QString &u) { m_imageUrl=u; }
     bool updateYear();
+    bool containsArtist(const QString &a);
+    void clearImage();
 
 private:
     void setCoverImage(const QImage &img) const;
     void setYear(const MusicLibraryItemSong *song);
     bool largeImages() const;
+    void updateStats();
 
 private:
     quint32 m_year;
     quint16 m_yearOfTrack;
     quint16 m_yearOfDisc;
     quint32 m_totalTime;
+    quint32 m_numTracks;
     mutable bool m_coverIsDefault;
     mutable QPixmap *m_cover;
     Song::Type m_type;
     QSet<QString> m_singleTrackFiles;
     QString m_imageUrl;
+    // m_artists is used to cache the list of artists in a vraious artists albu
+    // this is built when containsArtist() is called, and is mainly used by the
+    // context view
+    QSet<QString> m_artists;
 };
 
 #endif
