@@ -38,8 +38,14 @@
 #include "device.h"
 #include "utils.h"
 #endif
-#ifdef ENABLE_ONLINE_SERVICES
 #include "onlineservice.h"
+#include <QFile>
+
+#ifdef CACHE_SCALED_COVERS
+static QString cacheCoverName(const QString &artist, int size, bool createDir=false)
+{
+    return Utils::cacheDir(Covers::constCoverDir+QString::number(size)+"/", createDir)+Covers::encodeName(artist)+".png";
+}
 #endif
 
 bool MusicLibraryItemArtist::lessThan(const MusicLibraryItem *a, const MusicLibraryItem *b)
@@ -54,6 +60,7 @@ bool MusicLibraryItemArtist::lessThan(const MusicLibraryItem *a, const MusicLibr
 }
 
 static QPixmap *theDefaultIcon=0;
+static QPixmap *theDefaultLargeIcon=0;
 
 void MusicLibraryItemArtist::clearDefaultCover()
 {
@@ -61,6 +68,10 @@ void MusicLibraryItemArtist::clearDefaultCover()
         delete theDefaultIcon;
         theDefaultIcon=0;
     }
+    if (theDefaultLargeIcon) {
+        delete theDefaultLargeIcon;
+        theDefaultLargeIcon=0;
+    }
 }
 
 MusicLibraryItemArtist::MusicLibraryItemArtist(const QString &data, MusicLibraryItemContainer *parent)
@@ -79,10 +90,16 @@ MusicLibraryItemArtist::MusicLibraryItemArtist(const QString &data, MusicLibrary
 bool MusicLibraryItemArtist::setCover(const QImage &img, bool update) const
 {
     if ((m_coverIsDefault || update) && !img.isNull()) {
-        int size=MusicLibraryItemAlbum::iconSize(!MusicLibraryItemAlbum::itemSize().isNull());
+        int size=MusicLibraryItemAlbum::iconSize(largeImages());
         QImage scaled=img.scaled(QSize(size, size), Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation);
-        m_cover = new QPixmap(QPixmap::fromImage(scaled.width()>size || scaled.height()>size ? scaled.copy((scaled.width()-size)/2, 0, size, size) : scaled));
+        if (scaled.width()>size || scaled.height()>size) {
+            scaled=scaled.copy((scaled.width()-size)/2, 0, size, size);
+        }
+        m_cover = new QPixmap(QPixmap::fromImage(scaled));
         m_coverIsDefault=false;
+        #ifdef CACHE_SCALED_COVERS
+        scaled.save(cacheCoverName(data(), size, true));
+        #endif
         return true;
     }
 
@@ -92,22 +109,44 @@ bool MusicLibraryItemArtist::setCover(const QImage &img, bool update) const
 const QPixmap & MusicLibraryItemArtist::cover()
 {
     if (m_coverIsDefault && theDefaultIcon) {
-        return *theDefaultIcon;
+        if (largeImages()) {
+            if (theDefaultLargeIcon) {
+                return *theDefaultLargeIcon;
+            }
+        } else if (theDefaultIcon) {
+            return *theDefaultIcon;
+        }
     }
 
     if (!m_cover) {
-        int iSize=MusicLibraryItemAlbum::iconSize(!MusicLibraryItemAlbum::itemSize().isNull());
+        bool useLarge=largeImages();
+        int iSize=MusicLibraryItemAlbum::iconSize(useLarge);
         int cSize=iSize;
         if (0==cSize) {
             cSize=22;
         }
 
         if (m_various) {
-            m_cover = new QPixmap(Icons::variousArtistsIcon.pixmap(cSize, cSize).scaled(QSize(cSize, cSize), Qt::IgnoreAspectRatio, Qt::SmoothTransformation));
+            m_cover = new QPixmap(Icons::self()->variousArtistsIcon.pixmap(cSize, cSize).scaled(QSize(cSize, cSize), Qt::IgnoreAspectRatio, Qt::SmoothTransformation));
             m_coverIsDefault=false;
         } else {
-            if (!theDefaultIcon) {
-                theDefaultIcon = new QPixmap(Icons::artistIcon.pixmap(cSize, cSize)
+            #ifdef CACHE_SCALED_COVERS
+            QString cache=cacheCoverName(data(), iSize);
+
+            if (QFile::exists(cache)) {
+                QImage img(cache);
+                if (!img.isNull()) {
+                    m_cover=new QPixmap(QPixmap::fromImage(img));
+                    m_coverIsDefault=false;
+                    return *m_cover;
+                }
+            }
+            #endif
+            if (useLarge) {
+                theDefaultLargeIcon = new QPixmap(Icons::self()->artistIcon.pixmap(cSize, cSize)
+                                                 .scaled(QSize(cSize, cSize), Qt::IgnoreAspectRatio, Qt::SmoothTransformation));
+            } else {
+                theDefaultIcon = new QPixmap(Icons::self()->artistIcon.pixmap(cSize, cSize)
                                             .scaled(QSize(cSize, cSize), Qt::IgnoreAspectRatio, Qt::SmoothTransformation));
             }
             m_coverIsDefault = true;
@@ -129,16 +168,15 @@ const QPixmap & MusicLibraryItemArtist::cover()
             //    static_cast<Device *>(parentItem()->parentItem())->requestArtistImage(song);
             //} else
             //#endif
-            #ifdef ENABLE_ONLINE_SERVICES
             if (parentItem() && parentItem()->parentItem() && dynamic_cast<OnlineService *>(parentItem()->parentItem()) &&
                 static_cast<MusicLibraryItemRoot *>(parentItem()->parentItem())->useArtistImages()) {
                 // ONLINE: Image URL is encoded in song.name...
-                song.name=m_imageUrl;
-                song.title=parentItem()->parentItem()->data().toLower();
-                img=Covers::self()->requestImage(song);
-            } else
-            #endif
-            if (parentItem() && parentItem()->parentItem() && !static_cast<MusicLibraryItemRoot *>(parentItem()->parentItem())->useArtistImages()) {
+                if (!m_imageUrl.isEmpty()) {
+                    song.name=m_imageUrl;
+                    song.title=parentItem()->parentItem()->data().toLower();
+                    img=Covers::self()->requestImage(song);
+                }
+            } else if (parentItem() && parentItem()->parentItem() && !static_cast<MusicLibraryItemRoot *>(parentItem()->parentItem())->useArtistImages()) {
                 // Not showing artist images in this model, so dont request any!
             } else {
                 img=Covers::self()->requestImage(song);
@@ -149,13 +187,30 @@ const QPixmap & MusicLibraryItemArtist::cover()
                 m_coverIsDefault=false;
                 return *m_cover;
             }
-            return *theDefaultIcon;
+            return useLarge ? *theDefaultLargeIcon : *theDefaultIcon;
         }
     }
 
     return *m_cover;
 }
 
+void MusicLibraryItemArtist::clearImages()
+{
+    if (!m_coverIsDefault) {
+        m_coverIsDefault=true;
+        delete m_cover;
+        m_cover=0;
+        if (theDefaultIcon) {
+            m_cover=theDefaultIcon;
+        }
+    }
+    foreach (MusicLibraryItem *i, m_childItems) {
+        if (MusicLibraryItem::Type_Album==i->itemType()) {
+            static_cast<MusicLibraryItemAlbum *>(i)->clearImage();
+        }
+    }
+}
+
 MusicLibraryItemAlbum * MusicLibraryItemArtist::album(const Song &s, bool create)
 {
     QHash<QString, int>::ConstIterator it=m_indexes.find(s.album);
@@ -231,6 +286,7 @@ void MusicLibraryItemArtist::remove(MusicLibraryItemAlbum *album)
     }
     m_indexes.remove(album->data());
     delete m_childItems.takeAt(index);
+    resetRows();
 }
 
 QList<MusicLibraryItem *> MusicLibraryItemArtist::mutipleArtistAlbums()
@@ -259,3 +315,9 @@ void MusicLibraryItemArtist::updateIndexes()
         m_indexes.insert((*it)->data(), i);
     }
 }
+
+bool MusicLibraryItemArtist::largeImages() const
+{
+    return m_parentItem && Type_Root==m_parentItem->itemType() &&
+           static_cast<MusicLibraryItemRoot *>(m_parentItem)->useLargeImages();
+}
