@@ -34,7 +34,7 @@
 
 class MusicLibraryItemRoot;
 class MusicLibraryItemAlbum;
-class Song;
+struct Song;
 
 class MusicLibraryItemArtist : public MusicLibraryItemContainer
 {
@@ -61,6 +61,10 @@ public:
     bool hasRealCover() const { return !m_coverIsDefault; }
     const QString & imageUrl() const { return m_imageUrl; }
     void setImageUrl(const QString &u) { m_imageUrl=u; }
+    void clearImages();
+
+private:
+    bool largeImages() const;
 
 private:
     mutable bool m_coverIsDefault;
