@@ -29,15 +29,16 @@
 
 #include <QDateTime>
 #include <QSet>
+#include <QMap>
 #include "musiclibraryitemroot.h"
 #include "musiclibraryitemalbum.h"
 #include "song.h"
-#include "actionmodel.h"
+#include "musicmodel.h"
 
 class QMimeData;
 class MusicLibraryItemArtist;
 
-class MusicLibraryModel : public ActionModel
+class MusicLibraryModel : public MusicModel
 {
     Q_OBJECT
 
@@ -51,35 +52,38 @@ public:
     static void convertCache(const QString &compressedName);
     static void cleanCache();
 
-    MusicLibraryModel(QObject *parent=0, bool isMpdModel=true);
+    MusicLibraryModel(QObject *parent=0, bool isMpdModel=true, bool isCheckable=false);
     ~MusicLibraryModel();
     QModelIndex index(int, int, const QModelIndex & = QModelIndex()) const;
     QModelIndex parent(const QModelIndex &) const;
-    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
     int rowCount(const QModelIndex &parent = QModelIndex()) const;
-    int columnCount(const QModelIndex &) const;
     QVariant data(const QModelIndex &, int) const;
+    bool setData(const QModelIndex &idx, const QVariant &value, int role = Qt::EditRole);
     Qt::ItemFlags flags(const QModelIndex &index) const;
     QStringList filenames(const QModelIndexList &indexes, bool allowPlaylists=false) const;
     QList<Song> songs(const QModelIndexList &indexes, bool allowPlaylists=false) const;
     QList<Song> songs(const QStringList &filenames, bool insertNotFound=false) const;
     QMimeData *mimeData(const QModelIndexList &indexes) const;
     const MusicLibraryItemRoot * root() const { return rootItem; }
+    const MusicLibraryItemRoot * root(const MusicLibraryItem *) const { return root(); }
     bool isFromSingleTracks(const Song &s) const { return rootItem->isFromSingleTracks(s); }
     bool fromXML();
     void clear();
     QModelIndex findSongIndex(const Song &s) const;
-    QModelIndex findArtistsIndex(const QString &artist) const;
+    QModelIndex findArtistIndex(const QString &artist) const;
+    QModelIndex findAlbumIndex(const QString &artist, const QString &album) const;
     const MusicLibraryItem * findSong(const Song &s) const;
-    bool songExists(const Song &s) const;
-    bool updateSong(const Song &orig, const Song &edit);
-    void addSongToList(const Song &s);
-    void removeSongFromList(const Song &s);
-    void updateSongFile(const Song &from, const Song &to);
+    bool songExists(const Song &s) const { return rootItem->songExists(s); }
+    bool updateSong(const Song &orig, const Song &edit) { return rootItem->updateSong(orig, edit); }
+    void addSongToList(const Song &s) { rootItem->addSongToList(s); }
+    void removeSongFromList(const Song &s) { rootItem->removeSongFromList(s); }
+    void updateSongFile(const Song &from, const Song &to) { rootItem->updateSongFile(from, to); }
     void removeCache();
-    void getDetails(QSet<QString> &artists, QSet<QString> &albumArtists, QSet<QString> &albums, QSet<QString> &genres);
+    void getDetails(QSet<QString> &artists, QSet<QString> &albumArtists, QSet<QString> &albums, QSet<QString> &genres)
+        { rootItem->getDetails(artists, albumArtists, albums, genres); }
     QSet<QString> getAlbumArtists();
     bool update(const QSet<Song> &songs);
+    void uncheckAll();
     bool useAlbumImages() const { return rootItem->useAlbumImages(); }
     void setUseAlbumImages(bool a) { rootItem->setUseAlbumImages(a); }
     bool useArtistImages() const { return rootItem->useArtistImages(); }
@@ -90,6 +94,10 @@ public:
     void setSupportsAlbumArtistTag(bool s) { rootItem->setSupportsAlbumArtistTag(s); }
     void toggleGrouping();
     const QSet<QString> & genres() const { return rootItem->genres(); }
+    // Get tracks of an album
+    QList<Song> getAlbumTracks(const Song &s) const;
+    // Get 1 track from each album by artist - used to create context view backdrop!
+    QList<Song> getArtistAlbumsFirstTracks(const Song &song) const;
 
 public Q_SLOTS:
     void updateMusicLibrary(MusicLibraryItemRoot * root, QDateTime dbUpdate = QDateTime(), bool fromFile = false);
@@ -99,13 +107,16 @@ public Q_SLOTS:
 
 Q_SIGNALS:
 //     void updated(const MusicLibraryItemRoot *root);
-   void updateGenres(const QSet<QString> &genres);
+    void updateGenres(const QSet<QString> &genres);
+    void checkedSongs(const QSet<Song> &songs);
 
 private:
-   void setCover(const Song &song, const QImage &img, const QString &file, bool update);
-    void toXML(const MusicLibraryItemRoot *root, const QDateTime &date);
+    void setCover(const Song &song, const QImage &img, const QString &file, bool update);
+    void setParentState(const QModelIndex &parent, bool childChecked, MusicLibraryItemContainer *parentItem, MusicLibraryItem *item);
 
 private:
+    bool mpdModel;
+    bool checkable;
     MusicLibraryItemRoot *rootItem;
     QDateTime databaseTime;
 };
