@@ -31,8 +31,8 @@
 #include "musiclibraryproxymodel.h"
 
 MusicLibraryProxyModel::MusicLibraryProxyModel(QObject *parent)
-    : ProxyModel(parent) // ,
-//       filterField(3)
+    : ProxyModel(parent)
+    , filter(0)
 {
     setDynamicSortFilter(true);
     setFilterCaseSensitivity(Qt::CaseInsensitive);
@@ -43,7 +43,9 @@ MusicLibraryProxyModel::MusicLibraryProxyModel(QObject *parent)
 bool MusicLibraryProxyModel::filterAcceptsRoot(const MusicLibraryItem *item) const
 {
     foreach (const MusicLibraryItem *i, static_cast<const MusicLibraryItemContainer *>(item)->childItems()) {
-        if (filterAcceptsArtist(i)) {
+        if (MusicLibraryItem::Type_Artist==i->itemType() && filterAcceptsArtist(i)) {
+            return true;
+        } else if (MusicLibraryItem::Type_Song==i->itemType() && filterAcceptsSong(i)) {
             return true;
         }
     }
@@ -94,6 +96,26 @@ bool MusicLibraryProxyModel::filterAcceptsRow(int sourceRow, const QModelIndex &
         return false;
     }
 
+    if (filter) {
+        if (!sourceParent.isValid()) {
+            // All top level items are valid
+            return true;
+        }
+
+        const MusicLibraryItem *p=item->parentItem();
+        while (p->parentItem()) {
+            p=p->parentItem();
+        }
+        if (p!=filter) {
+            // If item is not part of 'filter' tree - then we accept it
+            return true;
+        }
+    }
+
+    if (filterStrings.isEmpty()) {
+        return true;
+    }
+
     switch (item->itemType()) {
     case MusicLibraryItem::Type_Root:
         return filterAcceptsRoot(item);
