@@ -57,7 +57,9 @@ public:
     void stop();
     QMimeData * mimeData(const QModelIndexList &indexes) const;
     void setSearch(const QString &serviceName, const QString &text);
+    #ifdef ENABLE_DEVICES_SUPPORT
     Device *device(const QString &udi);
+    #endif
     Action * configureAct() const { return configureAction; }
     Action * refreshAct() const { return refreshAction; }
 
