@@ -32,6 +32,7 @@
 #include <QSet>
 #include <QUrl>
 #include <QTimer>
+#include <QApplication>
 #include "localize.h"
 #include "playqueuemodel.h"
 #include "groupedview.h"
@@ -47,6 +48,9 @@
 #include "settings.h"
 #include "icon.h"
 #include "config.h"
+#ifdef ENABLE_DEVICES_SUPPORT
+#include "devicesmodel.h"
+#endif
 
 const QLatin1String PlayQueueModel::constMoveMimeType("cantata/move");
 const QLatin1String PlayQueueModel::constFileNameMimeType("cantata/filename");
@@ -121,6 +125,7 @@ PlayQueueModel::PlayQueueModel(QObject *parent)
     connect(this, SIGNAL(modelReset()), this, SLOT(stats()));
     connect(fetcher, SIGNAL(result(const QStringList &, int, bool, quint8)), SLOT(addFiles(const QStringList &, int, bool, quint8)));
     connect(fetcher, SIGNAL(result(const QStringList &, int, bool, quint8)), SIGNAL(streamsFetched()));
+    connect(fetcher, SIGNAL(status(QString)), SIGNAL(streamFetchStatus(QString)));
     connect(this, SIGNAL(filesAdded(const QStringList, quint32, quint32, bool, quint8)),
             MPDConnection::self(), SLOT(add(const QStringList, quint32, quint32, bool, quint8)));
     connect(this, SIGNAL(move(const QList<quint32> &, quint32, quint32)),
@@ -129,6 +134,11 @@ PlayQueueModel::PlayQueueModel(QObject *parent)
     connect(MPDConnection::self(), SIGNAL(stopAfterCurrentChanged(bool)), SLOT(stopAfterCurrentChanged(bool)));
     connect(this, SIGNAL(stop(bool)), MPDConnection::self(), SLOT(stopPlaying(bool)));
     connect(this, SIGNAL(clearStopAfter()), MPDConnection::self(), SLOT(clearStopAfter()));
+    connect(this, SIGNAL(removeSongs(QList<qint32>)), MPDConnection::self(), SLOT(removeSongs(QList<qint32>)));
+    #ifdef ENABLE_DEVICES_SUPPORT
+    connect(DevicesModel::self(), SIGNAL(invalid(QList<Song>)), SLOT(remove(QList<Song>)));
+    connect(DevicesModel::self(), SIGNAL(updatedDetails(QList<Song>)), SLOT(updateDetails(QList<Song>)));
+    #endif
 }
 
 PlayQueueModel::~PlayQueueModel()
@@ -180,7 +190,7 @@ int PlayQueueModel::rowCount(const QModelIndex &idx) const
 
 QVariant PlayQueueModel::data(const QModelIndex &index, int role) const
 {
-    if (!index.isValid() || index.row() >= songs.size()) {
+    if (Qt::SizeHintRole!=role && (!index.isValid() || index.row() >= songs.size())) {
         return QVariant();
     }
 
@@ -350,7 +360,7 @@ QVariant PlayQueueModel::data(const QModelIndex &index, int role) const
                    s.album+(s.year>0 ? (QLatin1String(" (")+QString::number(s.year)+QChar(')')) : QString())+QLatin1String("<br/>")+
                    s.trackAndTitleStr(Song::isVariousArtists(s.albumArtist()))+QLatin1String("<br/>")+
                    Song::formattedTime(s.time)+QLatin1String("<br/>")+
-                   (s.priority>0 ? i18n("<b>(Priority: %1)</b>").arg(s.priority)+QLatin1String("<br/>") : QString())+
+                   (s.priority>0 ? i18n("<b>(Priority: %1)</b>", s.priority)+QLatin1String("<br/>") : QString())+
                    QLatin1String("<small><i>")+s.file+QLatin1String("</i></small>");
         }
     }
@@ -385,8 +395,13 @@ QVariant PlayQueueModel::data(const QModelIndex &index, int role) const
             }
         }
         break;
-    case Qt::SizeHintRole:
-        return QSize(18, 18);
+    case Qt::SizeHintRole: {
+        static int sz=-1;
+        if (-1==sz) {
+            sz=Icon::stdSize(QApplication::fontMetrics().height()*1.2)*1.125;
+        }
+        return QSize(sz, sz);
+    }
     default:
         break;
     }
@@ -427,7 +442,7 @@ QStringList PlayQueueModel::mimeTypes() const
     types << constMoveMimeType;
     types << constFileNameMimeType;
     #ifdef TAGLIB_FOUND
-    if (MPDConnection::self()->getDetails().isLocal() || HttpServer::self()->isAlive()) {
+    if (HttpServer::self()->isAlive()) {
         types << constUriMimeType;
     }
     #endif
@@ -512,23 +527,16 @@ bool PlayQueueModel::dropMimeData(const QMimeData *data,
         QStringList orig=decode(*data, constUriMimeType);
         QStringList useable;
         bool haveHttp=HttpServer::self()->isAlive();
-        bool alwaysUseHttp=haveHttp && Settings::self()->alwaysUseHttp();
-        bool mpdLocal=MPDConnection::self()->getDetails().isLocal();
-        bool allowLocal=haveHttp || mpdLocal;
 
         foreach (QString u, orig) {
             if (u.startsWith(QLatin1String("http://"))) {
                 useable.append(u);
-            } else if (allowLocal && (u.startsWith('/') || u.startsWith(QLatin1String("file://")))) {
+            } else if (haveHttp && (u.startsWith('/') || u.startsWith(QLatin1String("file://")))) {
                 if (u.startsWith(QLatin1String("file://"))) {
                     u=u.mid(7);
                 }
                 if (checkExtension(u)) {
-                    if (alwaysUseHttp || !mpdLocal) {
-                        useable.append(HttpServer::self()->encodeUrl(QUrl::fromPercentEncoding(u.toUtf8())));
-                    } else {
-                        useable.append(QLatin1String("file://")+QUrl::fromPercentEncoding(u.toUtf8()));
-                    }
+                    useable.append(HttpServer::self()->encodeUrl(QUrl::fromPercentEncoding(u.toUtf8())));
                 }
             }
         }
@@ -600,6 +608,17 @@ qint32 PlayQueueModel::getIdByRow(qint32 row) const
     return row>=songs.size() ? -1 : songs.at(row).id;
 }
 
+qint32 PlayQueueModel::getSongId(const QString &file) const
+{
+    foreach (const Song &s, songs) {
+        if (s.file==file) {
+            return s.id;
+        }
+    }
+
+    return -1;
+}
+
 // qint32 PlayQueueModel::getPosByRow(qint32 row) const
 // {
 //     return row>=songs.size() ? -1 : songs.at(row).pos;
@@ -621,6 +640,16 @@ Song PlayQueueModel::getSongByRow(const qint32 row) const
     return row<0 || row>=songs.size() ? Song() : songs.at(row);
 }
 
+Song PlayQueueModel::getSongById(qint32 id) const
+{
+    foreach (const Song &s, songs) {
+        if (s.id==id) {
+            return s;
+        }
+    }
+    return Song();
+}
+
 void PlayQueueModel::updateCurrentSong(quint32 id)
 {
     qint32 oldIndex = currentSongId;
@@ -722,6 +751,7 @@ void PlayQueueModel::update(const QList<Song> &songList)
             } else if (isEmpty) {
                 s=curentSongAtPos;
             } else {
+                s.key=curentSongAtPos.key;
                 songs.replace(i, s);
                 if (s.name!=curentSongAtPos.name || s.title!=curentSongAtPos.title || s.artist!=curentSongAtPos.artist) {
                     emit dataChanged(index(i, 0), index(i, columnCount(QModelIndex())-1));
@@ -776,6 +806,11 @@ void PlayQueueModel::stats()
     emit statsUpdated(songs.size(), time);
 }
 
+void PlayQueueModel::cancelStreamFetch()
+{
+    fetcher->cancel();
+}
+
 void PlayQueueModel::stopAfterCurrentChanged(bool afterCurrent)
 {
     if (afterCurrent!=stopAfterCurrent) {
@@ -784,6 +819,80 @@ void PlayQueueModel::stopAfterCurrentChanged(bool afterCurrent)
     }
 }
 
+void PlayQueueModel::remove(const QList<Song> &rem)
+{
+    QSet<QString> s;
+    QList<qint32> ids;
+
+    foreach (const Song &song, rem) {
+        s.insert(song.file);
+    }
+
+    foreach (const Song &song, songs) {
+        if (s.contains(song.file)) {
+            ids.append(song.id);
+            s.remove(song.file);
+            if (s.isEmpty()) {
+                break;
+            }
+        }
+    }
+
+    if (!ids.isEmpty()) {
+        emit removeSongs(ids);
+    }
+}
+
+void PlayQueueModel::updateDetails(const QList<Song> &updated)
+{
+    QMap<QString, Song> songMap;
+    QList<int> updatedRows;
+    bool currentUpdated=false;
+    Song currentSong;
+
+    foreach (const Song &song, updated) {
+        songMap[song.file]=song;
+    }
+
+    for (int i=0; i<songs.count(); ++i) {
+        Song current=songs.at(i);
+        if (songMap.contains(current.file)) {
+            Song updatedSong=songMap[current.file];
+            updatedSong.id=current.id;
+            updatedSong.setKey();
+
+            if (updatedSong.name!=current.name || updatedSong.title!=current.title || updatedSong.artist!=current.artist) {
+                songs.replace(i, updatedSong);
+                updatedRows.append(i);
+                if (currentSongId==current.id) {
+                    currentUpdated=true;
+                    currentSong=updatedSong;
+                }
+            }
+
+            songMap.remove(current.file);
+            if (songMap.isEmpty()) {
+                break;
+            }
+        }
+    }
+
+    if (!updatedRows.isEmpty()) {
+        if (updatedRows.count()==updated.count()) {
+            beginResetModel();
+            endResetModel();
+        } else {
+            foreach (int row, updatedRows) {
+                emit dataChanged(index(row, 0), index(row, columnCount(QModelIndex())-1));
+            }
+        }
+    }
+
+    if (currentUpdated) {
+        emit updateCurrent(currentSong);
+    }
+}
+
 QSet<qint32> PlayQueueModel::getSongIdSet()
 {
     QSet<qint32> ids;
