@@ -78,9 +78,11 @@ public:
     bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole);
     void updateCurrentSong(quint32 id);
     qint32 getIdByRow(qint32 row) const;
+    qint32 getSongId(const QString &file) const;
 //     qint32 getPosByRow(qint32 row) const;
     qint32 getRowById(qint32 id) const;
     Song getSongByRow(const qint32 row) const;
+    Song getSongById(qint32 id) const;
     Qt::DropActions supportedDropActions() const;
     Qt::ItemFlags flags(const QModelIndex &index) const;
     QStringList mimeTypes() const;
@@ -102,9 +104,12 @@ public Q_SLOTS:
     void addFiles(const QStringList &filenames, int row, bool replace, quint8 priority);
     void prioritySet(const QList<qint32> &ids, quint8 priority);
     void stats();
+    void cancelStreamFetch();
 
 private Q_SLOTS:
     void stopAfterCurrentChanged(bool afterCurrent);
+    void remove(const QList<Song> &rem);
+    void updateDetails(const QList<Song> &updated);
 
 Q_SIGNALS:
     void stop(bool afterCurrent);
@@ -114,6 +119,9 @@ Q_SIGNALS:
     void statsUpdated(int songs, quint32 time);
     void fetchingStreams();
     void streamsFetched();
+    void removeSongs(const QList<qint32> &items);
+    void updateCurrent(const Song &s);
+    void streamFetchStatus(const QString &msg);
 
 private:
     QList<Song> songs;
