@@ -31,23 +31,28 @@
 class ProxyModel : public QSortFilterProxyModel
 {
 public:
-    ProxyModel(QObject *parent) : QSortFilterProxyModel(parent), filterEnabled(false) { }
+    ProxyModel(QObject *parent) : QSortFilterProxyModel(parent), isSorted(false), filterEnabled(false) { }
     virtual ~ProxyModel() { }
 
     bool update(const QString &text, const QString &genre=QString());
     void setRootIndex(const QModelIndex &idx) { rootIndex=idx.isValid() ? mapToSource(idx) : idx; }
     bool isChildOfRoot(const QModelIndex &idx) const;
-    bool isEmpty() const { return filterGenre.isEmpty() && filterRegExp().isEmpty(); }
+    bool isEmpty() const { return filterGenre.isEmpty() && filterStrings.isEmpty(); }
     bool enabled() const { return filterEnabled; }
+    const QString & filterText() const { return origFilterText; }
+    void sort() { isSorted=false; sort(0); }
+    void sort(int column, Qt::SortOrder order = Qt::AscendingOrder);
 
 protected:
     bool matchesFilter(const Song &s) const;
     bool matchesFilter(const QStringList &strings) const;
 
 protected:
+    bool isSorted;
     bool filterEnabled;
     QString filterGenre;
     QModelIndex rootIndex;
+    QString origFilterText;
     QStringList filterStrings;
     uint unmatchedStrings;
 };
