@@ -238,12 +238,12 @@ void StreamsModel::CategoryItem::removeCache()
 }
 
 void StreamsModel::ListenLiveCategoryItem::removeCache()
-{foreach (Item *i, children) {
+{
+    foreach (Item *i, children) {
         if (i->isCategory()) {
             static_cast<CategoryItem *>(i)->removeCache();
         }
     }
-
 }
 
 void StreamsModel::CategoryItem::saveCache() const
@@ -541,7 +541,7 @@ QVariant StreamsModel::data(const QModelIndex &index, int role) const
             const CategoryItem *cat=static_cast<const CategoryItem *>(item);
             switch (cat->state) {
             case CategoryItem::Initial:
-                return i18n("No Loaded");
+                return i18n("Not Loaded");
             case CategoryItem::Fetching:
                 return i18n("Loading...");
             default:
@@ -895,16 +895,19 @@ static QString addDiHash(const StreamsModel::Item *item)
             ? DigitallyImported::self()->modifyUrl(item->url) : item->url;
 }
 
-static void filenames(QStringList &fn, bool addPrefix, const StreamsModel::CategoryItem *cat)
-{
-    foreach (const StreamsModel::Item *i, cat->children) {
-        if (i->isCategory()) {
-            ::filenames(fn, addPrefix, static_cast<const StreamsModel::CategoryItem *>(i));
-        } else if (!fn.contains(i->url) && StreamsModel::validProtocol(i->url)) {
-            fn << StreamsModel::modifyUrl(addDiHash(i), addPrefix, i->name);
-        }
-    }
-}
+//static void filenames(QStringList &fn, bool addPrefix, const StreamsModel::CategoryItem *cat)
+//{
+//    foreach (const StreamsModel::Item *i, cat->children) {
+//        if (i->isCategory()) {
+//            ::filenames(fn, addPrefix, static_cast<const StreamsModel::CategoryItem *>(i));
+//        } else if (StreamsModel::validProtocol(i->url)) {
+//            QString url=StreamsModel::modifyUrl(addDiHash(i), addPrefix, i->name);
+//            if (!fn.contains(i->url)) {
+//                fn << url;
+//            }
+//        }
+//    }
+//}
 
 QStringList StreamsModel::filenames(const QModelIndexList &indexes, bool addPrefix) const
 {
@@ -912,9 +915,15 @@ QStringList StreamsModel::filenames(const QModelIndexList &indexes, bool addPref
     foreach(QModelIndex index, indexes) {
         Item *item=static_cast<Item *>(index.internalPointer());
 
-        if (item->isCategory()) {
-            ::filenames(fnames, addPrefix, static_cast<const StreamsModel::CategoryItem *>(item));
-        } else if (!fnames.contains(item->url) && validProtocol(item->url)) {
+//        if (item->isCategory()) {
+//            ::filenames(fnames, addPrefix, static_cast<const StreamsModel::CategoryItem *>(item));
+//        } else if (validProtocol(item->url)) {
+//            QString url=modifyUrl(addDiHash(item), addPrefix, item->name);
+//            if (!fnames.contains(url)) {
+//                fnames << url;
+//            }
+//        }
+        if (!item->isCategory()) {
             fnames << modifyUrl(addDiHash(item), addPrefix, item->name);
         }
     }
@@ -1265,7 +1274,11 @@ QList<StreamsModel::Item *> StreamsModel::parseDigitallyImportedResponse(QIODevi
 {
     QList<Item *> newItems;
     QJson::Parser parser;
+    #ifdef Q_OS_WIN
+    QVariantMap data = parser.parse(dev->readAll()).toMap();
+    #else
     QVariantMap data = parser.parse(dev).toMap();
+    #endif
     QString listenHost=QLatin1String("listen.")+QUrl(cat->url).host().remove("www.");
 
     if (data.contains("channel_filters")) {
