@@ -26,12 +26,15 @@
 
 #include "proxymodel.h"
 
+
 class StreamsProxyModel : public ProxyModel
 {
 public:
     StreamsProxyModel(QObject *parent = 0);
-    void setFilterGenre(const QString &genre);
+
+    bool filterAcceptsItem(const void *i, QStringList strings) const;
     bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const;
+    bool lessThan(const QModelIndex &left, const QModelIndex &right) const;
 };
 
 #endif
