@@ -26,20 +26,26 @@
 
 #include "mpdconnection.h"
 #include "mpdparseutils.h"
+#include "mpduser.h"
 #include "localize.h"
 #include "utils.h"
 #ifdef ENABLE_KDE_SUPPORT
 #include <KDE/KGlobal>
 #endif
 #include <QApplication>
-#include <QDebug>
 #include <QStringList>
 #include <QTimer>
 #include "thread.h"
 #include "settings.h"
+#include "cuefile.h"
 
-// #define DBUG qWarning() << "MPDConnection" << QThread::currentThreadId()
-#define DBUG qDebug()
+#include <QDebug>
+static bool debugEnabled=false;
+#define DBUG if (debugEnabled) qWarning() << "MPDConnection" << QThread::currentThreadId()
+void MPDConnection::enableDebug()
+{
+    debugEnabled=true;
+}
 
 static const int constSocketCommsTimeout=2000;
 static const int constMaxReadAttempts=4;
@@ -61,7 +67,7 @@ MPDConnection * MPDConnection::self()
     #endif
 }
 
-static QByteArray encodeName(const QString &name)
+QByteArray MPDConnection::encodeName(const QString &name)
 {
     return '\"'+name.toUtf8().replace("\\", "\\\\").replace("\"", "\\\"")+'\"';
 }
@@ -128,17 +134,23 @@ QString MPDConnection::Response::getError()
 }
 
 MPDConnectionDetails::MPDConnectionDetails()
-    : dirReadable(false)
+    : port(6600)
+    , dynamizerPort(0)
+    , dirReadable(false)
 {
 }
 
+QString MPDConnectionDetails::getName() const
+{
+    return name.isEmpty() ? i18n("Default") : (name==MPDUser::constName ? MPDUser::translatedName() : name);
+}
+
 QString MPDConnectionDetails::description() const
 {
-    QString n=name.isEmpty() ? i18n("Default") : name;
     if (hostname.startsWith('/')) {
-        return i18nc("name (host)", "%1 (%2)").arg(n).arg(hostname);
+        return i18nc("name (host)", "\"%1\"", getName());
     } else {
-        return i18nc("name (host:port)", "%1 (%2:%3)").arg(n).arg(hostname).arg(port);
+        return i18nc("name (host:port)", "\"%1\" (%2:%3)", getName(), hostname, port);
     }
 }
 
@@ -191,6 +203,10 @@ void MPDConnection::start()
 
 void MPDConnection::stop()
 {
+    if (details.name==MPDUser::constName && Settings::self()->stopOnExit()) {
+        MPDUser::self()->stop();
+    }
+
     if (thread) {
         thread->stop();
         thread=0;
@@ -337,25 +353,27 @@ void MPDConnection::reconnect()
                 connect(reconnectTimer, SIGNAL(timeout()), this, SLOT(reconnect()), Qt::QueuedConnection);
             }
             if (abs(now-reconnectStart)>1) {
-                emit info(i18n("Connecting to %1").arg(details.description()));
+                emit info(i18n("Connecting to %1", details.description()));
             }
             reconnectTimer->start(500);
         } else {
             emit stateChanged(false);
-            emit error(i18n("Connection to %1 failed").arg(details.description()), true);
+            emit error(i18n("Connection to %1 failed", details.description()), true);
             reconnectStart=0;
         }
         break;
     case IncorrectPassword:
         emit stateChanged(false);
-        emit error(i18n("Connection to %1 failed - incorrect password").arg(details.description()), true);
+        emit error(i18n("Connection to %1 failed - incorrect password", details.description()), true);
         reconnectStart=0;
         break;
     }
 }
 
-void MPDConnection::setDetails(const MPDConnectionDetails &det)
+void MPDConnection::setDetails(const MPDConnectionDetails &d)
 {
+    bool isUser=d.name==MPDUser::constName;
+    const MPDConnectionDetails &det=isUser ? MPDUser::self()->details() : d;
     bool changedDir=det.dir!=details.dir;
     bool diffName=det.name!=details.name;
     bool diffDetails=det!=details;
@@ -368,6 +386,9 @@ void MPDConnection::setDetails(const MPDConnectionDetails &det)
         DBUG << "call connectToMPD";
         unmuteVol=-1;
         toggleStopAfterCurrent(false);
+        if (isUser) {
+            MPDUser::self()->start();
+        }
         switch (connectToMPD()) {
         case Success:
             getStatus();
@@ -377,11 +398,11 @@ void MPDConnection::setDetails(const MPDConnectionDetails &det)
             break;
         case Failed:
             emit stateChanged(false);
-            emit error(i18n("Connection to %1 failed").arg(details.description()), true);
+            emit error(i18n("Connection to %1 failed", details.description()), true);
             break;
         case IncorrectPassword:
             emit stateChanged(false);
-            emit error(i18n("Connection to %1 failed - incorrect password").arg(details.description()), true);
+            emit error(i18n("Connection to %1 failed - incorrect password", details.description()), true);
             break;
         }
     } else if (diffName) {
@@ -412,7 +433,7 @@ MPDConnection::Response MPDConnection::sendCommand(const QByteArray &command, bo
     DBUG << (void *)(&sock) << "sendCommand:" << command << emitErrors << retry;
 
     if (!isConnected()) {
-        emit error(i18n("Failed to send command to %1 - not connected").arg(details.description()), true);
+        emit error(i18n("Failed to send command to %1 - not connected", details.description()), true);
         return Response(false);
     }
 
@@ -422,7 +443,7 @@ MPDConnection::Response MPDConnection::sendCommand(const QByteArray &command, bo
             // Failed to connect, so close *both* sockets!
             disconnectFromMPD();
             emit stateChanged(false);
-            emit error(i18n("Failed to reconnect to %1").arg(details.description()), true);
+            emit error(i18n("Connection to %1 failed", details.description()), true);
             return Response(false);
         }
     }
@@ -456,14 +477,14 @@ MPDConnection::Response MPDConnection::sendCommand(const QByteArray &command, bo
                 } else {
                     disconnectFromMPD();
                     emit stateChanged(false);
-                    emit error(i18n("Failed to send command. Disconnected from %1").arg(details.description()), true);
+                    emit error(i18n("Failed to send command. Disconnected from %1", details.description()), true);
                 }
             } else if (!response.getError().isEmpty()) {
                 emit error(response.getError());
             } else {
                 disconnectFromMPD();
                 emit stateChanged(false);
-                emit error(i18n("Failed to send command. Disconnected from %1").arg(details.description()), true);
+                emit error(i18n("Failed to send command. Disconnected from %1", details.description()), true);
             }
         }
     }
@@ -497,18 +518,22 @@ void MPDConnection::add(const QStringList &files, quint32 pos, quint32 size, boo
     QByteArray send = "command_list_begin\n";
     int curSize = size;
     int curPos = pos;
-    bool addedFile=false;
+//    bool addedFile=false;
     bool havePlaylist=false;
     bool usePrio=priority>0 && canUsePriority();
     for (int i = 0; i < files.size(); i++) {
-        if (isPlaylist(files.at(i))) {
-            send+="load ";
-            havePlaylist=true;
+        if (CueFile::isCue(files.at(i))) {
+            send += "load "+CueFile::getLoadLine(files.at(i))+"\n";
         } else {
-            addedFile=true;
-            send += "add ";
+            if (isPlaylist(files.at(i))) {
+                send+="load ";
+                havePlaylist=true;
+            } else {
+//                addedFile=true;
+                send += "add ";
+            }
+            send += encodeName(files.at(i))+"\n";
         }
-        send += encodeName(files.at(i))+"\n";
         if (!havePlaylist) {
             if (0!=size) {
                 send += "move "+QByteArray::number(curSize)+" "+QByteArray::number(curPos)+"\n";
@@ -524,13 +549,28 @@ void MPDConnection::add(const QStringList &files, quint32 pos, quint32 size, boo
     send += "command_list_end";
 
     if (sendCommand(send).ok) {
-        if (replace && addedFile && !files.isEmpty()) {
-            startPlayingSong();
+        if (replace /*&& addedFile */&& !files.isEmpty()) {
+            // Dont emit error if fail plays, might be that playlist was not loaded...
+            sendCommand("play "+QByteArray::number(0), false);
         }
         emit added(files);
     }
 }
 
+void MPDConnection::addAndPlay(const QString &file)
+{
+    toggleStopAfterCurrent(false);
+    Response response=sendCommand("status");
+    if (response.ok) {
+        MPDStatusValues sv=MPDParseUtils::parseStatus(response.data);
+        QByteArray send = "command_list_begin\n";
+        send+="add "+encodeName(file)+"\n";
+        send+="play "+QByteArray::number(sv.playlistLength)+"\n";
+        send+="command_list_end";
+        sendCommand(send);
+    }
+}
+
 void MPDConnection::clear()
 {
     toggleStopAfterCurrent(false);
@@ -941,7 +981,7 @@ void MPDConnection::onSocketStateChanged(QAbstractSocket::SocketState socketStat
             // Failed to connect idle socket - so close *both*
             disconnectFromMPD();
             emit stateChanged(false);
-            emit error(i18n("Failed to reconnect to %1").arg(details.description()), true);
+            emit error(i18n("Connection to %1 failed", details.description()), true);
         }
         if (QAbstractSocket::ConnectedState==idleSocket.state()) {
             connect(&idleSocket, SIGNAL(stateChanged(QAbstractSocket::SocketState)), this, SLOT(onSocketStateChanged(QAbstractSocket::SocketState)));
@@ -968,7 +1008,7 @@ void MPDConnection::parseIdleReturn(const QByteArray &data)
             // Failed to connect idle socket - so close *both*
             disconnectFromMPD();
             emit stateChanged(false);
-            emit error(i18n("Failed to reconnect to %1").arg(details.description()), true);
+            emit error(i18n("Connection to %1 failed", details.description()), true);
         }
         return;
     }
@@ -1041,7 +1081,7 @@ void MPDConnection::loadLibrary()
     emit updatingLibrary();
     Response response=sendCommand("listallinfo");
     if (response.ok) {
-        emit musicLibraryUpdated(MPDParseUtils::parseLibraryItems(response.data), dbUpdate);
+        emit musicLibraryUpdated(MPDParseUtils::parseLibraryItems(response.data, details.dir, ver), dbUpdate);
     }
     emit updatedLibrary();
 }
@@ -1103,7 +1143,7 @@ void MPDConnection::renamePlaylist(const QString oldName, const QString newName)
     if (sendCommand("rename "+encodeName(oldName)+' '+encodeName(newName), false).ok) {
         emit playlistRenamed(oldName, newName);
     } else {
-        emit error(i18n("Failed to rename <b>%1</b> to <b>%2</b>").arg(oldName).arg(newName));
+        emit error(i18n("Failed to rename <b>%1</b> to <b>%2</b>", oldName, newName));
     }
 }
 
@@ -1115,7 +1155,7 @@ void MPDConnection::removePlaylist(const QString &name)
 void MPDConnection::savePlaylist(const QString &name)
 {
     if (!sendCommand("save "+encodeName(name), false).ok) {
-        emit error(i18n("Failed to save <b>%1</b>").arg(name));
+        emit error(i18n("Failed to save <b>%1</b>", name));
     }
 }
 
@@ -1125,6 +1165,18 @@ void MPDConnection::addToPlaylist(const QString &name, const QStringList &songs,
         return;
     }
 
+    if (!name.isEmpty()) {
+        foreach (const QString &song, songs) {
+            if (CueFile::isCue(song)) {
+                emit error(i18n("You cannot add parts of a cue sheet to a playlist!"));
+                return;
+            } else if (isPlaylist(song)) {
+                emit error(i18n("You cannot add a playlist to another playlist!"));
+                return;
+            }
+        }
+    }
+
     QByteArray encodedName=encodeName(name);
     QByteArray send = "command_list_begin\n";
     foreach (const QString &s, songs) {
