@@ -132,10 +132,11 @@ private:
 
 struct MPDConnectionDetails {
     MPDConnectionDetails();
+    QString getName() const;
     QString description() const;
     bool isLocal() const { return hostname.startsWith('/'); }
     bool isEmpty() const { return hostname.isEmpty() || (!isLocal() && 0==port); }
-    bool operator==(const MPDConnectionDetails &o) const { return hostname==o.hostname && isLocal()==o.isLocal() && (!isLocal() || port==o.port) && password==o.password; }
+    bool operator==(const MPDConnectionDetails &o) const { return hostname==o.hostname && isLocal()==o.isLocal() && (isLocal() || port==o.port) && password==o.password; }
     bool operator!=(const MPDConnectionDetails &o) const { return !(*this==o); }
     bool operator<(const MPDConnectionDetails &o) const { return name.localeAwareCompare(o.name)<0; }
     static QString configGroupName(const QString &n=QString()) { return n.isEmpty() ? "Connection" : ("Connection-"+n); }
@@ -158,6 +159,7 @@ class MPDConnection : public QObject
 
 public:
     static MPDConnection * self();
+    static QByteArray encodeName(const QString &name);
 
     struct Response {
         Response(bool o=true, const QByteArray &d=QByteArray());
@@ -166,6 +168,8 @@ public:
         QByteArray data;
     };
 
+    static void enableDebug();
+
     MPDConnection();
     ~MPDConnection();
 
@@ -183,11 +187,12 @@ public:
 
 public Q_SLOTS:
     void reconnect();
-    void setDetails(const MPDConnectionDetails &det);
+    void setDetails(const MPDConnectionDetails &d);
     void disconnectMpd();
     // Current Playlist
     void add(const QStringList &files, bool replace, quint8 priority);
     void add(const QStringList &files, quint32 pos, quint32 size, bool replace, quint8 priority);
+    void addAndPlay(const QString &file);
     void currentSong();
     void playListChanges();
     void playListInfo();
