@@ -388,7 +388,6 @@ MusicLibraryItemRoot * MPDParseUtils::parseLibraryItems(const QByteArray &data,
     MusicLibraryItemAlbum *albumItem = 0;
     MusicLibraryItemSong *songItem = 0;
     QString unknown=i18n("Unknown");
-    QString lastGenre;
 
     for (int i = 0; i < amountOfLines; i++) {
         currentItem += lines.at(i);
@@ -504,13 +503,9 @@ MusicLibraryItemRoot * MPDParseUtils::parseLibraryItems(const QByteArray &data,
                             songItem = new MusicLibraryItemSong(s, albumItem);
                             albumItem->append(songItem);
                             updatedAlbums.insert(albumItem);
-
-                            if (s.genre!=lastGenre) {
-                                lastGenre=s.genre;
-                                albumItem->addGenre(s.genre);
-                                artistItem->addGenre(s.genre);
-                                rootItem->addGenre(s.genre);
-                            }
+                            albumItem->addGenre(s.genre);
+                            artistItem->addGenre(s.genre);
+                            rootItem->addGenre(s.genre);
                         }
 
                         // For each album that was updated/created, remove any source files referenced in cue file...
@@ -560,12 +555,9 @@ MusicLibraryItemRoot * MPDParseUtils::parseLibraryItems(const QByteArray &data,
             }
             songItem = new MusicLibraryItemSong(currentSong, albumItem);
             albumItem->append(songItem);
-            if (currentSong.genre!=lastGenre) {
-                lastGenre=currentSong.genre;
-                albumItem->addGenre(currentSong.genre);
-                artistItem->addGenre(currentSong.genre);
-                rootItem->addGenre(currentSong.genre);
-            }
+            albumItem->addGenre(currentSong.genre);
+            artistItem->addGenre(currentSong.genre);
+            rootItem->addGenre(currentSong.genre);
         }
     }
     rootItem->applyGrouping();
