@@ -135,14 +135,15 @@ void MPDUser::setMusicFolder(const QString &folder)
     if (folder==det.dir) {
         return;
     }
+    init(true);
 
     QFile cfgFile(Utils::configDir(constDir, true)+constConfigFile);
     QStringList lines;
     if (cfgFile.open(QIODevice::ReadOnly|QIODevice::Text)) {
-        while (!cfgFile.atEnd() && (det.dir.isEmpty() || det.hostname.isEmpty())) {
+        while (!cfgFile.atEnd()) {
             QString line = cfgFile.readLine();
             if (line.startsWith(constMusicFolderKey)) {
-                lines.append(constMusicFolderKey+" \""+folder+"\"");
+                lines.append(constMusicFolderKey+" \""+folder+"\"\n");
             } else {
                 lines.append(line);
             }
@@ -154,12 +155,24 @@ void MPDUser::setMusicFolder(const QString &folder)
         if (cfgFile.open(QIODevice::WriteOnly|QIODevice::Text)) {
             QTextStream out(&cfgFile);
             foreach (const QString &line, lines) {
-                out << line << endl;
+                out << line;
             }
         }
     }
     det.dir=folder;
     det.dirReadable=QDir(det.dir).isReadable();
+    if (0!=getPid()) {
+        controlMpd(true); // Stop
+        controlMpd(false); // Start
+    }    
+}
+
+void MPDUser::setDetails(const MPDConnectionDetails &d)
+{
+    setMusicFolder(d.dir);
+    bool dirReadable=det.dirReadable;
+    det=d;
+    det.dirReadable=dirReadable;
 }
 
 static void removeDir(const QString &d)
@@ -235,7 +248,7 @@ void MPDUser::cleanup()
 
 void MPDUser::init(bool create)
 {
-    if (det.dir.isEmpty() || det.hostname.isEmpty() || pidFileName.isEmpty()) {
+    if (create || det.dir.isEmpty() || det.hostname.isEmpty() || pidFileName.isEmpty()) {
         // Read coverFileName from Cantata settings...
         det.coverName=Settings::self()->connectionDetails(constName).coverName;
         det.dirReadable=false;
@@ -267,7 +280,7 @@ void MPDUser::init(bool create)
                         out << line;
 
                         if (det.dir.isEmpty()) {
-                            det.dir=readValue(line, constMusicFolderKey);
+                            det.dir=Utils::fixPath(readValue(line, constMusicFolderKey));
                         }
                         if (det.hostname.isEmpty()) {
                             det.hostname=readValue(line, constSocketKey);
@@ -293,7 +306,7 @@ void MPDUser::init(bool create)
                 while (!cfgFile.atEnd() && (det.dir.isEmpty() || det.hostname.isEmpty() || pidFileName.isEmpty())) {
                     QString line = cfgFile.readLine();
                     if (det.dir.isEmpty()) {
-                        det.dir=readValue(line, constMusicFolderKey);
+                        det.dir=Utils::fixPath(readValue(line, constMusicFolderKey));
                     }
                     if (det.hostname.isEmpty()) {
                         det.hostname=readValue(line, constSocketKey);
@@ -327,7 +340,11 @@ int MPDUser::getPid()
 
 bool MPDUser::controlMpd(bool stop)
 {
-    QStringList args=QStringList() << Utils::configDir(constDir, true)+constConfigFile;
+    QString confFile=Utils::configDir(constDir, true)+constConfigFile;
+    if (!QFile::exists(confFile)) {
+        return false;
+    }
+    QStringList args=QStringList() << confFile;
     if (stop) {
         args+="--kill";
     }
