@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2012 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2013 Craig Drummond <craig.p.drummond@gmail.com>
  *
  */
 /*
@@ -27,7 +27,7 @@
 #ifndef OUTPUT_H
 #define OUTPUT_H
 
-#include <QtCore/QString>
+#include <QString>
 
 struct Output
 {
