@@ -24,13 +24,15 @@
 #ifndef NETWORK_ACCESS_MANAGER_H
 #define NETWORK_ACCESS_MANAGER_H
 
-#ifdef ENABLE_KDE_SUPPORT
-#include <KDE/KIO/AccessManager>
-#define BASE_NETWORK_ACCESS_MANAGER KIO::Integration::AccessManager
-#else
+// KIO is not thread safe, and we get segfaults if it is used in non-gui thread.
+// Therefore, we dont use KIO::Integration::AccessManager :-(
+//#ifdef ENABLE_KDE_SUPPORT
+//#include <KDE/KIO/AccessManager>
+//#define BASE_NETWORK_ACCESS_MANAGER KIO::Integration::AccessManager
+//#else
 #include <QNetworkAccessManager>
 #define BASE_NETWORK_ACCESS_MANAGER QNetworkAccessManager
-#endif
+//#endif
 #include <QNetworkReply>
 #include <QMap>
 
