@@ -27,6 +27,7 @@
 #include <QMutex>
 #include <QNetworkProxyFactory>
 #include <QUrl>
+#include "config.h"
 
 class NetworkProxyFactory : public QNetworkProxyFactory
 {
@@ -42,23 +43,23 @@ public:
     static const char * constSettingsGroup;
 
     // These methods are thread-safe
+    #ifdef ENABLE_PROXY_CONFIG
     void reloadSettings();
+    #endif
     QList<QNetworkProxy> queryProxy(const QNetworkProxyQuery& query);
 
 private:
     NetworkProxyFactory();
 
 private:
+    #ifdef ENABLE_PROXY_CONFIG
     QMutex mutex;
     Mode mode;
     QNetworkProxy::ProxyType type;
     QString hostname;
     int port;
-    bool useAuthentication;
     QString username;
     QString password;
-    #ifdef Q_OS_LINUX
-    QUrl envUrl;
     #endif
 };
 
