@@ -27,23 +27,21 @@
 #include <QObject>
 
 class Thread;
+class QProcess;
 
 class Job : public QObject
 {
     Q_OBJECT
 public:
     Job();
-    virtual ~Job();
+    virtual ~Job() { }
 
     virtual void requestAbort() { abortRequested=true; }
-    void start();
-    void stop();
+    virtual void start()=0;
+    virtual void stop()=0;
     void setFinished(bool f);
     bool success() { return finished; }
 
-private Q_SLOTS:
-    virtual void run() =0;
-
 Q_SIGNALS:
     void exec();
     void progress(int);
@@ -52,6 +50,21 @@ Q_SIGNALS:
 protected:
     bool abortRequested;
     bool finished;
+};
+
+class StandardJob : public Job
+{
+    Q_OBJECT
+public:
+    StandardJob();
+    virtual ~StandardJob() { stop(); }
+
+    virtual void start();
+    virtual void stop();
+
+private Q_SLOTS:
+    virtual void run() =0;
+
 private:
     Thread *thread;
 };
@@ -61,8 +74,9 @@ class JobController : public QObject
     Q_OBJECT
 public:
     static JobController * self();
-    JobController() { }
+    JobController();
 
+    void setMaxActive(int m);
     void add(Job *job);
     void finishedWith(Job *job);
     void startJobs();
@@ -72,6 +86,7 @@ private Q_SLOTS:
     void jobDone();
 
 private:
+    int maxActive;
     QList<Job *> active;
     QList<Job *> jobs;
 };
