@@ -54,7 +54,7 @@ static inline QString formatNumber(double number, int precision)
     #ifdef ENABLE_KDE_SUPPORT
     return KGlobal::locale()->formatNumber(number, precision);
     #else
-    return QString::number(number, 'g', precision);
+    return QString::number(number, 'f', precision);
     #endif
 }
 
