@@ -28,7 +28,7 @@
 #include "song.h"
 #include "tags.h"
 
-class TagReader : public Job
+class TagReader : public StandardJob
 {
     Q_OBJECT
 
