@@ -176,15 +176,11 @@ void StreamsPage::addSelectionToPlaylist(bool replace, quint8 priorty)
 
 void StreamsPage::addItemsToPlayQueue(const QModelIndexList &indexes, bool replace, quint8 priorty)
 {
-    if (0==indexes.size()) {
+    if (indexes.isEmpty()) {
         return;
     }
-
-    QModelIndexList sorted=indexes;
-    qSort(sorted);
-
     QModelIndexList mapped;
-    foreach (const QModelIndex &idx, sorted) {
+    foreach (const QModelIndex &idx, indexes) {
         mapped.append(proxy->mapToSource(idx));
     }
 
@@ -211,8 +207,7 @@ void StreamsPage::configureStreams()
         return;
     }
 
-    QModelIndexList selected = itemView()->selectedIndexes();
-
+    QModelIndexList selected = itemView()->selectedIndexes(false); // Dont need sorted selection here...
     if (1!=selected.count()) {
         return;
     }
@@ -302,7 +297,7 @@ void StreamsPage::add()
 
 void StreamsPage::addBookmark()
 {
-    QModelIndexList selected = itemView()->selectedIndexes();
+    QModelIndexList selected = itemView()->selectedIndexes(false); // Dont need sorted selection here...
 
     if (1!=selected.count()) {
         return;
@@ -372,7 +367,7 @@ void StreamsPage::reload()
         return;
     }
 
-    QModelIndexList selected = itemView()->selectedIndexes();
+    QModelIndexList selected = itemView()->selectedIndexes(false); // Dont need sorted selection here...
     if (1!=selected.count()) {
         return;
     }
@@ -462,7 +457,7 @@ void StreamsPage::edit()
         return;
     }
 
-    QModelIndexList selected = itemView()->selectedIndexes();
+    QModelIndexList selected = itemView()->selectedIndexes(false); // Dont need sorted selection here...
 
     if (1!=selected.size()) {
         return;
@@ -524,7 +519,7 @@ void StreamsPage::controlSearch(bool on)
 
 void StreamsPage::controlActions()
 {
-    QModelIndexList selected=itemView()->selectedIndexes();
+    QModelIndexList selected=itemView()->selectedIndexes(false); // Dont need sorted selection here...
     bool haveSelection=!selected.isEmpty();
     bool enableAddToFav=true;
     bool onlyStreamsSelected=true;
