@@ -43,7 +43,7 @@
 #include <QMouseEvent>
 #include <QPainter>
 #include <QSplitter>
-#include <QStackedLayout>
+#include <QStackedWidget>
 #include <QStyleOption>
 #include <QToolButton>
 #include <QToolTip>
@@ -153,6 +153,10 @@ void FancyTabProxyStyle::drawControl(
 
   const QRect draw_rect(QPoint(0, 0), m.mapRect(rect).size());
 
+  if (!selected && GtkStyle::isActive()) {
+      p->fillRect(option->rect, option->palette.background());
+  }
+
   p->save();
   p->setTransform(m);
 
@@ -594,7 +598,7 @@ FancyTabWidget::FancyTabWidget(QWidget* parent, bool allowContext, bool drawBord
   : QWidget(parent),
     mode_(Mode_None),
     tab_bar_(NULL),
-    stack_(new QStackedLayout),
+    stack_(new QStackedWidget(this)),
     side_widget_(new QWidget),
     side_layout_(new QVBoxLayout),
     top_layout_(new QVBoxLayout),
@@ -613,7 +617,7 @@ FancyTabWidget::FancyTabWidget(QWidget* parent, bool allowContext, bool drawBord
 
   top_layout_->setMargin(0);
   top_layout_->setSpacing(0);
-  top_layout_->addLayout(stack_);
+  top_layout_->addWidget(stack_);
 
   QHBoxLayout* main_layout = new QHBoxLayout;
   main_layout->setMargin(0);
@@ -633,9 +637,7 @@ void FancyTabWidget::InsertTab(QWidget* tab, const QIcon& icon, const QString& l
   stack_->insertWidget(0, tab);
   items_.prepend(Item(icon, label, tt, enabled));
   setMinimumWidth(128);
-  Mode m=mode_;
-  mode_=Mode_None;
-  SetMode(m);
+  Recreate();
 }
 
 void FancyTabWidget::RemoveTab(QWidget *tab)
@@ -644,9 +646,7 @@ void FancyTabWidget::RemoveTab(QWidget *tab)
   if (idx>-1 && idx<items_.count()) {
     stack_->removeWidget(tab);
     items_.takeAt(idx);
-    Mode m=mode_;
-    mode_=Mode_None;
-    SetMode(m);
+    Recreate();
   }
 }
 
@@ -713,7 +713,10 @@ void FancyTabWidget::paintEvent(QPaintEvent*e) {
         drawFadedLine(&painter, r, palette().foreground().color());
     } else*/ {
         QRect rect = side_widget_->rect().adjusted(0, 0, 1, 0);
-        rect = style()->visualRect(layoutDirection(), geometry(), rect);
+//        rect = style()->visualRect(layoutDirection(), geometry(), rect);
+        if (Qt::RightToLeft==layoutDirection()) {
+            rect.adjust(geometry().width()-(rect.width()-1), 0, geometry().width()-(rect.width()-1), 0);
+        }
         drawFadedLine(&painter, QRect(rect.x(), rect.y(), 1, rect.height()), palette().foreground().color());
         drawFadedLine(&painter, QRect(rect.x()+rect.width()-2, rect.y(), 1, rect.height()), palette().foreground().color());
     }
@@ -887,9 +890,7 @@ void FancyTabWidget::SetMode(Mode mode) {
 void FancyTabWidget::ToggleTab(int tab, bool show) {
     if (tab>=0 && tab<items_.count()) {
         items_[tab].enabled_=show;
-        Mode m=mode_;
-        mode_=Mode_None;
-        SetMode(m);
+        Recreate();
         emit TabToggled(tab);
     }
 }
@@ -967,6 +968,9 @@ void FancyTabWidget::contextMenuEvent(QContextMenuEvent* e) {
     connect(iconOnlyAct, SIGNAL(triggered()), this, SLOT(SetMode()));
     modeMenu->addSeparator();
     modeMenu->addAction(iconOnlyAct);
+    foreach (QAction *a, otherStyleActions) {
+      modeMenu->addAction(a);
+    }
     modeAct->setMenu(modeMenu);
     modeAct->setData(-1);
     menu_->addAction(modeAct);
@@ -1106,3 +1110,21 @@ int FancyTabWidget::TabToIndex(int tab) const
 
     return 0;
 }
+
+void FancyTabWidget::SetIcon(int index, const QIcon &icon)
+{
+    if (index>0 && index<items_.count()) {
+        items_[index].tab_icon_=icon;
+    }
+    if (menu_) {
+        menu_->deleteLater();
+        menu_=0;
+    }
+}
+
+void FancyTabWidget::Recreate()
+{
+    Mode m=mode_;
+    mode_=Mode_None;
+    SetMode(m);
+}
