@@ -50,7 +50,7 @@ class QActionGroup;
 class QMenu;
 class QPainter;
 class QSignalMapper;
-class QStackedLayout;
+class QStackedWidget;
 class QStatusBar;
 class QVBoxLayout;
 
@@ -222,6 +222,10 @@ public:
     void addMenuAction(QAction *a) { removeMenuAction(a); otherActions.append(a); }
     void removeMenuAction(QAction *a) { otherActions.removeAll(a); }
     QSize tabSize() const;
+    void addStyleAction(QAction *a) { removeMenuAction(a); otherStyleActions.append(a); }
+    void removeStyleAction(QAction *a) { otherStyleActions.removeAll(a); }
+    void SetIcon(int index, const QIcon &icon);
+    void Recreate();
 
 public slots:
     void SetCurrentIndex(int index);
@@ -253,7 +257,7 @@ private:
     QList<Item> items_;
 
     QWidget* tab_bar_;
-    QStackedLayout* stack_;
+    QStackedWidget* stack_;
     QPixmap background_pixmap_;
     QWidget* side_widget_;
     QVBoxLayout* side_layout_;
@@ -269,6 +273,7 @@ private:
     bool drawBorder_;
 
     QList<QAction *> otherActions;
+    QList<QAction *> otherStyleActions;
 };
 
 } // namespace Internal
