@@ -23,9 +23,13 @@
 
 #include "gtkproxystyle.h"
 #include "gtkstyle.h"
+#include "shortcuthandler.h"
 #ifdef ENABLE_OVERLAYSCROLLBARS
 #include "osthumb.h"
 #endif
+#ifndef ENABLE_KDE_SUPPORT
+#include "acceleratormanager.h"
+#endif
 #include <QComboBox>
 #include <QToolBar>
 #include <QAbstractScrollArea>
@@ -33,6 +37,7 @@
 #include <QTreeView>
 #include <QHeaderView>
 #include <QScrollBar>
+#include <QMenu>
 #include <QApplication>
 #include <QHoverEvent>
 #include <QPainter>
@@ -41,6 +46,11 @@
 
 const char * GtkProxyStyle::constSlimComboProperty="gtkslim";
 
+static const char * constOnCombo="on-combo";
+#ifndef ENABLE_KDE_SUPPORT
+static const char * constAccelProp="catata-accel";
+#endif
+
 //static bool revertQGtkStyleOverlayMod()
 //{
 //    // TODO: This is not working. ubuntu_gtk_set_use_overlay_scrollbar is found, and called.
@@ -58,6 +68,12 @@ const char * GtkProxyStyle::constSlimComboProperty="gtkslim";
 //    return false;
 //}
 
+
+static bool isOnCombo(const QWidget *w)
+{
+    return w && (qobject_cast<const QComboBox *>(w) || isOnCombo(w->parentWidget()));
+}
+
 GtkProxyStyle::GtkProxyStyle(ScrollbarType sb)
     : QProxyStyle()
     #ifdef ENABLE_OVERLAYSCROLLBARS
@@ -69,6 +85,8 @@ GtkProxyStyle::GtkProxyStyle(ScrollbarType sb)
     , sbarThumbTarget(0)
     #endif
 {
+    shortcutHander=new ShortcutHandler(this);
+
     sbarType=sb;
 
     if (SB_Standard!=sbarType) {
@@ -135,8 +153,17 @@ QSize GtkProxyStyle::sizeFromContents(ContentsType type, const QStyleOption *opt
 
 int GtkProxyStyle::styleHint(StyleHint hint, const QStyleOption *option, const QWidget *widget, QStyleHintReturn *returnData) const
 {
-    if (SB_Standard!=sbarType && SH_ScrollView_FrameOnlyAroundContents==hint) {
+    switch (hint) {
+    case SH_DialogButtonBox_ButtonsHaveIcons:
         return false;
+    case SH_UnderlineShortcut:
+        return widget ? shortcutHander->showShortcut(widget) : true;
+    case SH_ScrollView_FrameOnlyAroundContents:
+        if (SB_Standard!=sbarType) {
+            return false;
+        }
+    default:
+        break;
     }
 
     return baseStyle()->styleHint(hint, option, widget, returnData);
@@ -260,11 +287,19 @@ void GtkProxyStyle::drawComplexControl(ComplexControl control, const QStyleOptio
             #endif
 
             if (usePlain) {
+                #if 0
                 QLinearGradient grad(r.topLeft(), Qt::Horizontal==sb->orientation ? r.bottomLeft() : r.topRight());
                 QColor col=option->palette.base().color();
                 grad.setColorAt(0, col.darker(110));
                 grad.setColorAt(1, col.darker(102));
                 painter->fillRect(r, grad);
+                #else
+                if (widget && widget->property(constOnCombo).toBool()) {
+                    painter->fillRect(r, option->palette.background());
+                } else if (!widget || widget->testAttribute(Qt::WA_OpaquePaintEvent)) {
+                    painter->fillRect(r, option->palette.base());
+                }
+                #endif
             }
             #ifdef ENABLE_OVERLAYSCROLLBARS
             else {
@@ -357,6 +392,12 @@ void GtkProxyStyle::destroySliderThumb()
 }
 #endif
 
+inline void addEventFilter(QObject *object, QObject *filter)
+{
+    object->removeEventFilter(filter);
+    object->installEventFilter(filter);
+}
+
 void GtkProxyStyle::polish(QWidget *widget)
 {
     #ifdef ENABLE_OVERLAYSCROLLBARS
@@ -367,11 +408,22 @@ void GtkProxyStyle::polish(QWidget *widget)
         widget->setAttribute(Qt::WA_Hover, true);
     }
     #else
-    if (SB_Standard!=sbarType) {
-        widget->setAttribute(Qt::WA_Hover, true);
+
+//    TODO: Why was this here?? Should it not have just been for QScrollBars???
+//    if (SB_Standard!=sbarType) {
+//        widget->setAttribute(Qt::WA_Hover, true);
+//    }
+    if (SB_Standard!=sbarType && qobject_cast<QScrollBar *>(widget) && isOnCombo(widget)) {
+        widget->setProperty(constOnCombo, true);
     }
     #endif
 
+    #ifndef ENABLE_KDE_SUPPORT
+    if (widget && qobject_cast<QMenu *>(widget) && !widget->property(constAccelProp).isValid()) {
+        AcceleratorManager::manage(widget);
+        widget->setProperty(constAccelProp, true);
+    }
+    #endif
     baseStyle()->polish(widget);
 }
 
@@ -382,6 +434,7 @@ void GtkProxyStyle::polish(QPalette &pal)
 
 void GtkProxyStyle::polish(QApplication *app)
 {
+    addEventFilter(app, shortcutHander);
     baseStyle()->polish(app);
 }
 
@@ -402,6 +455,7 @@ void GtkProxyStyle::unpolish(QWidget *widget)
 
 void GtkProxyStyle::unpolish(QApplication *app)
 {
+    app->removeEventFilter(shortcutHander);
     baseStyle()->unpolish(app);
 }
 
