@@ -31,6 +31,9 @@
 #include <QTextStream>
 #include <QFile>
 #include <qglobal.h>
+#ifndef ENABLE_KDE_SUPPORT
+#include "proxystyle.h"
+#endif
 #if !defined Q_OS_WIN && !defined QT_NO_STYLE_GTK
 #include "gtkproxystyle.h"
 #include "windowmanager.h"
@@ -108,6 +111,28 @@ void GtkStyle::drawSelection(const QStyleOptionViewItemV4 &opt, QPainter *painte
     painter->setOpacity(opacityB4);
 }
 
+#if !defined Q_OS_WIN && !defined QT_NO_STYLE_GTK
+// For some reason, dconf does not seem to terminate correclty when run under some desktops (e.g. KDE)
+// Destrying the QProcess seems to block, causing the app to appear to hang before starting.
+// So, create QProcess on the heap - and only wait 100ms for response. Connect finished to deleteLater
+// so that the object is destroyed.
+static QString runProc(const QString &cmd, const QStringList &args)
+{
+    QProcess *process=new QProcess();
+    process->start(cmd, args);
+    QObject::connect(process, SIGNAL(finished(int)), process, SLOT(deleteLater()));
+
+    if (process->waitForFinished(1000)) {
+        QString resp = process->readAllStandardOutput();
+        resp = resp.trimmed();
+        resp.remove('\'');
+        return resp;
+    }
+    process->kill();
+    return QString();
+}
+#endif
+
 // Copied from musique
 QString GtkStyle::themeName()
 {
@@ -115,17 +140,17 @@ QString GtkStyle::themeName()
     return QString();
     #else
     static QString name;
+    static bool read=false;
+
+    if (read) {
+        return name;
+    }
+    read=true;
 
     if (name.isEmpty()) {
-        QProcess process;
-        process.start("dconf",  QStringList() << "read" << "/org/gnome/desktop/interface/gtk-theme");
-        if (process.waitForFinished()) {
-            name = process.readAllStandardOutput();
-            name = name.trimmed();
-            name.remove('\'');
-            if (!name.isEmpty()) {
-                return name;
-            }
+        name=runProc("dconf",  QStringList() << "read" << "/org/gnome/desktop/interface/gtk-theme");
+        if (!name.isEmpty()) {
+            return name;
         }
 
         QString rcPaths = QString::fromLocal8Bit(qgetenv("GTK2_RC_FILES"));
@@ -170,26 +195,22 @@ QString GtkStyle::iconTheme()
     #if defined Q_OS_WIN || defined QT_NO_STYLE_GTK
     return QString();
     #else
+    static bool read=false;
     static QString name;
 
-    if (name.isEmpty()) {
-        QProcess process;
-        process.start("dconf",  QStringList() << "read" << "/org/gnome/desktop/interface/icon-theme");
-        if (process.waitForFinished()) {
-            name = process.readAllStandardOutput();
-            name = name.trimmed();
-            name.remove('\'');
-            if (!name.isEmpty()) {
-                return name;
-            }
-        }
+    if (!read) {
+        read=true;
+        name=runProc("dconf",  QStringList() << "read" << "/org/gnome/desktop/interface/icon-theme");
     }
     return name;
     #endif
 }
 
 #if !defined Q_OS_WIN && !defined QT_NO_STYLE_GTK
-static GtkProxyStyle *style=0;
+static GtkProxyStyle *gtkProxyStyle=0;
+#endif
+#ifndef ENABLE_KDE_SUPPORT
+static ProxyStyle *plainProxyStyle=0;
 #endif
 static bool symbolicIcons=false;
 static bool lightIcons=false;
@@ -198,6 +219,12 @@ void GtkStyle::applyTheme(QWidget *widget)
 {
     #if defined Q_OS_WIN || defined QT_NO_STYLE_GTK
     Q_UNUSED(widget)
+    #ifndef ENABLE_KDE_SUPPORT
+    if (!plainProxyStyle) {
+        plainProxyStyle=new ProxyStyle();
+        qApp->setStyle(plainProxyStyle);
+    }
+    #endif
     #else
     if (widget && isActive()) {
         QString theme=GtkStyle::themeName().toLower();
@@ -229,19 +256,26 @@ void GtkStyle::applyTheme(QWidget *widget)
                 QCoreApplication::setAttribute(Qt::AA_DontShowIconsInMenus);
             }
         }
-        if (!style) {
-            style=new GtkProxyStyle(sbType);
-            qApp->setStyle(style);
+        if (!gtkProxyStyle) {
+            gtkProxyStyle=new GtkProxyStyle(sbType);
+            qApp->setStyle(gtkProxyStyle);
         }
     }
+
+    #ifndef ENABLE_KDE_SUPPORT
+    if (!gtkProxyStyle && !plainProxyStyle) {
+        plainProxyStyle=new ProxyStyle();
+        qApp->setStyle(plainProxyStyle);
+    }
+    #endif
     #endif
 }
 
 void GtkStyle::cleanup()
 {
     #if !defined Q_OS_WIN && !defined QT_NO_STYLE_GTK && defined ENABLE_OVERLAYSCROLLBARS
-    if (style) {
-        style->destroySliderThumb();
+    if (gtkProxyStyle) {
+        gtkProxyStyle->destroySliderThumb();
     }
     #endif
 }
