@@ -24,18 +24,18 @@
 #include "icon.h"
 #include <QApplication>
 #include <QToolButton>
-
+#include <QDebug>
 int Icon::stdSize(int v)
 {
     if (v<19) {
         return 16;
-    } else if (v<28) {
+    } else if (v<=28) {
         return 22;
-    } else if (v<40) {
+    } else if (v<=40) {
         return 32;
-    } else if (v<56) {
+    } else if (v<=56) {
         return 48;
-    } else if (v<90) {
+    } else if (v<=90) {
         return 64;
     } else {
         return 128;
@@ -47,7 +47,7 @@ int Icon::dlgIconSize()
     static int size=-1;
 
     if (-1==size) {
-        size=stdSize(QApplication::fontMetrics().height()*3);
+        size=stdSize(QApplication::fontMetrics().height()*3.5);
     }
     return size;
 }
@@ -81,6 +81,7 @@ Icon Icon::getMediaIcon(const QString &name)
         icn.addPixmap(icon.pixmap(QSize(64, 64), mode).scaled(QSize(28, 28), Qt::KeepAspectRatio, Qt::SmoothTransformation), mode);
         icn.addPixmap(icon.pixmap(QSize(48, 48), mode), mode);
         icn.addPixmap(icon.pixmap(QSize(32, 32), mode), mode);
+        icn.addPixmap(icon.pixmap(QSize(24, 24), mode), mode);
         icn.addPixmap(icon.pixmap(QSize(22, 22), mode), mode);
         icn.addPixmap(icon.pixmap(QSize(16, 16), mode), mode);
     }
