@@ -54,16 +54,12 @@ MessageBox::ButtonCode MessageBox::questionYesNoCancel(QWidget *parent, const QS
     if (!yesText.text.isEmpty()) {
         QAbstractButton *btn=box.button(QMessageBox::Yes);
         btn->setText(yesText.text);
-        if (!yesText.icon.isEmpty() && !GtkStyle::isActive()) {
-            btn->setIcon(Icon(yesText.icon));
-        }
+        btn->setIcon(yesText.icon.isEmpty() || GtkStyle::isActive() ? Icon() : Icon(yesText.icon));
     }
     if (!noText.text.isEmpty()) {
         QAbstractButton *btn=box.button(QMessageBox::No);
         btn->setText(noText.text);
-        if (!noText.icon.isEmpty() && !GtkStyle::isActive()) {
-            btn->setIcon(Icon(noText.icon));
-        }
+        btn->setIcon(noText.icon.isEmpty() || GtkStyle::isActive() ? Icon() : Icon(noText.icon));
     }
     AcceleratorManager::manage(&box);
     return -1==box.exec() ? Cancel : map(box.standardButton(box.clickedButton()));
