@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2012 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2013 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -24,7 +24,7 @@
 #ifndef ONOFF_BUTTON_H
 #define ONOFF_BUTTON_H
 
-#include <QtGui/QCheckBox>
+#include <QCheckBox>
 
 #ifdef Q_OS_WIN
 typedef QCheckBox OnOffButton;
@@ -33,8 +33,7 @@ class OnOffButton : public QCheckBox
 {
 public:
     OnOffButton(QWidget *p);
-    virtual ~OnOffButton() {
-    }
+    virtual ~OnOffButton() { }
 
     QSize sizeHint() const;
     bool hitButton(const QPoint &pos) const;
