@@ -65,6 +65,7 @@ ShortcutsSettingsPage::ShortcutsSettingsPage(const QHash<QString, ActionCollecti
   shortcutsView->expandAll();
   shortcutsView->resizeColumnToContents(0);
   shortcutsView->sortByColumn(0, Qt::AscendingOrder);
+  shortcutsView->setUniformRowHeights(true);
   if (1==_shortcutsModel->rowCount()) {
       shortcutsView->setIndentation(0);
       shortcutsView->setRootIndex(_shortcutsFilter->index(0, 0));
@@ -86,6 +87,11 @@ ShortcutsSettingsPage::ShortcutsSettingsPage(const QHash<QString, ActionCollecti
   QTimer::singleShot(0, searchEdit, SLOT(setFocus()));
 }
 
+QTreeView * ShortcutsSettingsPage::view()
+{
+    return shortcutsView;
+}
+
 void ShortcutsSettingsPage::setWidgetStates() {
   if(shortcutsView->currentIndex().isValid() && shortcutsView->currentIndex().parent().isValid()) {
     QKeySequence active = shortcutsView->currentIndex().data(ShortcutsModel::ActiveShortcutRole).value<QKeySequence>();
