@@ -29,36 +29,28 @@
 typedef KUrlLabel UrlLabel;
 #else
 #include <QLabel>
-#include <QFont>
-class QResizeEvent;
+#include <QCursor>
 
 class UrlLabel : public QLabel
 {
     Q_OBJECT
 
 public:
-    UrlLabel(QWidget *p)
-        : QLabel(p) {
-        QFont f(font());
-        f.setUnderline(true);
-        setFont(f);
-        QPalette pal(palette());
-        pal.setColor(QPalette::Normal, QPalette::Foreground, pal.color(QPalette::Normal, QPalette::Highlight));
-        pal.setColor(QPalette::Inactive, QPalette::Foreground, pal.color(QPalette::Inactive, QPalette::Highlight));
-        pal.setColor(QPalette::Disabled, QPalette::Foreground, pal.color(QPalette::Disabled, QPalette::Highlight));
-        setPalette(pal);
-    }
+    UrlLabel(QWidget *p);
+    virtual ~UrlLabel() { }
 
-    virtual ~UrlLabel() {
-    }
+    void setText(const QString &t);
+    void setProperty(const char *name, const QVariant &value);
 
 Q_SIGNALS:
     void leftClickedUrl();
 
 protected:
-    void mouseReleaseEvent(QMouseEvent *) {
-        emit leftClickedUrl();
-    }
+    void mousePressEvent(QMouseEvent *);
+    void mouseReleaseEvent(QMouseEvent *);
+
+private:
+    bool pressed;
 };
 #endif
 
