@@ -30,9 +30,7 @@
 #include "inputdialog.h"
 #include "localize.h"
 #include "trackorganiser.h"
-#ifdef ENABLE_KDE_SUPPORT
-#include <KDE/KStandardGuiItem>
-#endif
+#include "cuefile.h"
 #ifdef ENABLE_DEVICES_SUPPORT
 #include "devicesmodel.h"
 #include "device.h"
@@ -65,11 +63,7 @@ int TagEditor::instanceCount()
 
 TagEditor::TagEditor(QWidget *parent, const QList<Song> &songs,
                      const QSet<QString> &existingArtists, const QSet<QString> &existingAlbumArtists,
-                     const QSet<QString> &existingAlbums, const QSet<QString> &existingGenres
-                     #ifdef ENABLE_DEVICES_SUPPORT
-                     , const QString &udi
-                     #endif
-                     )
+                     const QSet<QString> &existingAlbums, const QSet<QString> &existingGenres, const QString &udi)
     : Dialog(parent, "TagEditor", QSize(500, 200))
     #ifdef ENABLE_DEVICES_SUPPORT
     , deviceUdi(udi)
@@ -84,6 +78,9 @@ TagEditor::TagEditor(QWidget *parent, const QList<Song> &songs,
 {
     iCount++;
     foreach (const Song &s, songs) {
+        if (CueFile::isCue(s.file)) {
+            continue;
+        }
         if (s.guessed) {
             Song song(s);
             song.revertGuessedTags();
@@ -93,6 +90,11 @@ TagEditor::TagEditor(QWidget *parent, const QList<Song> &songs,
         }
     }
 
+    if (original.isEmpty()) {
+        deleteLater();
+        return;
+    }
+
     #ifdef ENABLE_DEVICES_SUPPORT
     if (deviceUdi.isEmpty()) {
         baseDir=MPDConnection::self()->getDetails().dir;
@@ -107,6 +109,7 @@ TagEditor::TagEditor(QWidget *parent, const QList<Song> &songs,
         baseDir=dev->path();
     }
     #else
+    Q_UNUSED(udi)
     baseDir=MPDConnection::self()->getDetails().dir;
     #endif
     qSort(original);
@@ -125,25 +128,13 @@ TagEditor::TagEditor(QWidget *parent, const QList<Song> &songs,
     setCaption(i18n("Tags"));
     progress->setVisible(false);
     if (songs.count()>1) {
-        #ifdef ENABLE_KDE_SUPPORT
-        setButtonGuiItem(User2, KStandardGuiItem::back(KStandardGuiItem::UseRTL));
-        setButtonText(User2, i18n("Previous"));
-        setButtonGuiItem(User1, KStandardGuiItem::forward(KStandardGuiItem::UseRTL));
-        setButtonText(User1, i18n("Next"));
-        #else
-        setButtonGuiItem(User2, GuiItem(i18n("Previous"), "go-previous"));
-        setButtonGuiItem(User1, GuiItem(i18n("Next"), "go-next"));
-        #endif
+        setButtonGuiItem(User2, StdGuiItem::back(true));
+        setButtonGuiItem(User1,StdGuiItem::forward(true));
         enableButton(User1, false);
         enableButton(User2, false);
     }
-    #ifdef ENABLE_KDE_SUPPORT
-    setButtonGuiItem(Ok, KStandardGuiItem::save());
+    setButtonGuiItem(Ok, StdGuiItem::save());
     setButtonGuiItem(User3, GuiItem(i18n("Tools"), "tools-wizard"));
-    #else
-    setButtonGuiItem(Ok, GuiItem(i18n("Save"), "document-save"));
-    setButtonGuiItem(User3, GuiItem(i18n("Tools"), "tools-wizard"));
-    #endif
     QMenu *toolsMenu=new QMenu(this);
     toolsMenu->addAction(i18n("Apply \"Various Artists\" Workaround"), this, SLOT(applyVa()));
     toolsMenu->addAction(i18n("Revert \"Various Artists\" Workaround"), this, SLOT(revertVa()));
@@ -333,7 +324,8 @@ void TagEditor::applyVa()
                                                            QLatin1String("<br/><hr/><br/>")+
                                                            i18n("<i>This will set 'Album artist' and 'Artist' to "
                                                                 "\"Various Artists\", and set 'Title' to "
-                                                                "\"TrackArtist - TrackTitle\"</i>"))) {
+                                                                "\"TrackArtist - TrackTitle\"</i>"), i18n("Apply \"Various Artists\" Workaround"),
+                                                  StdGuiItem::apply(), StdGuiItem::cancel())) {
         return;
     }
 
@@ -377,7 +369,8 @@ void TagEditor::revertVa()
                                                                 "'Artist' will be taken from 'Title' and 'Title' itself will be "
                                                                 "set to just the title. e.g. <br/><br/>"
                                                                 "If 'Title' is \"Wibble - Wobble\", then 'Artist' will be set to "
-                                                                "\"Wibble\" and 'Title' will be set to \"Wobble\"</i>"))) {
+                                                                "\"Wibble\" and 'Title' will be set to \"Wobble\"</i>"), i18n("Revert \"Various Artists\" Workaround"),
+                                                  GuiItem(i18n("Revert")), StdGuiItem::cancel())) {
         return;
     }
 
@@ -419,7 +412,8 @@ void TagEditor::setAlbumArtistFromArtist()
     bool isAll=0==currentSongIndex && original.count()>1;
 
     if (MessageBox::No==MessageBox::questionYesNo(this, isAll ? i18n("Set 'Album Artist' from 'Artist' (if 'Album Artist' is empty) for <b>all</b> tracks?")
-                                                              : i18n("Set 'Album Artist' from 'Artist' (if 'Album Artist' is empty)?"))) {
+                                                              : i18n("Set 'Album Artist' from 'Artist' (if 'Album Artist' is empty)?"),
+                                                  i18n("Album Artist from Artist"), StdGuiItem::apply(), StdGuiItem::cancel())) {
         return;
     }
 
@@ -455,7 +449,8 @@ void TagEditor::capitalise()
     if (MessageBox::No==MessageBox::questionYesNo(this, isAll ? i18n("Capitalize the first letter of 'Title', 'Artist', 'Album artist', and "
                                                                      "'Album' of <b>all</b> tracks?")
                                                               : i18n("Capitalize the first letter of 'Title', 'Artist', 'Album artist', and "
-                                                                     "'Album'"))) {
+                                                                     "'Album'"),
+                                                  i18n("Capitalize"), GuiItem(i18n("Capitalize")), StdGuiItem::cancel())) {
         return;
     }
 
@@ -544,7 +539,7 @@ void TagEditor::updateTrackName(int index, bool edited)
         if (isAll) {
             trackName->setItemText(index, i18n("All tracks [modified]"));
         } else {
-            trackName->setItemText(index, i18n("%1 [modified]").arg(original.at(index).file));
+            trackName->setItemText(index, i18n("%1 [modified]", original.at(index).file));
         }
     } else {
         if (isAll) {
@@ -675,7 +670,7 @@ void TagEditor::applyUpdates()
             return;
         }
         opts=dev->options();
-        udi=dev->udi();
+        udi=dev->id();
     } else
     #endif
     opts.load(MPDConnectionDetails::configGroupName(MPDConnection::self()->getDetails().name), true);
@@ -757,7 +752,8 @@ void TagEditor::applyUpdates()
         }
 
         if (renameFiles &&
-            MessageBox::Yes==MessageBox::questionYesNo(this, i18n("Would you also like to rename your song files, so as to match your tags?"), i18n("Rename Files?"))) {
+            MessageBox::Yes==MessageBox::questionYesNo(this, i18n("Would you also like to rename your song files, so as to match your tags?"),
+                                                       i18n("Rename Files"), GuiItem(i18n("Rename")), StdGuiItem::cancel())) {
             TrackOrganiser *dlg=new TrackOrganiser(parentWidget());
             dlg->show(updatedSongs, udi);
         }
