@@ -1004,11 +1004,16 @@ static Update update(const TagLib::FileRef fileref, const Song &from, const Song
         TagLib::MPEG::File *mpeg=dynamic_cast<TagLib::MPEG::File *>(fileref.file());
         if (mpeg) {
             TagLib::ID3v1::Tag *v1=mpeg->ID3v1Tag(false);
-            TagLib::ID3v2::Tag *v2=mpeg->ID3v2Tag(false);
             bool haveV1=v1 && (!v1->title().isEmpty() || !v1->artist().isEmpty() || !v1->album().isEmpty());
+            #ifdef TAGLIB_CAN_SAVE_ID3VER
+            TagLib::ID3v2::Tag *v2=mpeg->ID3v2Tag(false);
             bool isID3v24=v2 && isId3V24(v2->header());
             int ver=id3Ver==3 ? 3 : (id3Ver==4 ? 4 : (isID3v24 ? 4 : 3));
-            return mpeg->save((haveV1 && -1==id3Ver ? TagLib::MPEG::File::ID3v1 : 0)|TagLib::MPEG::File::ID3v2, true, ver) ? Update_Modified : Update_Failed;
+            return mpeg->save((haveV1 ? TagLib::MPEG::File::ID3v1 : 0)|TagLib::MPEG::File::ID3v2, true, ver) ? Update_Modified : Update_Failed;
+            #else
+            Q_UNUSED(id3Ver)
+            return mpeg->save((haveV1 ? TagLib::MPEG::File::ID3v1 : 0)|TagLib::MPEG::File::ID3v2, true) ? Update_Modified : Update_Failed;
+            #endif
         }
         return fileref.file()->save() ? Update_Modified : Update_Failed;
     }
@@ -1033,10 +1038,14 @@ Update updateArtistAndTitle(const QString &fileName, const Song &song)
 
     if (mpeg) {
         TagLib::ID3v1::Tag *v1=mpeg->ID3v1Tag(false);
-        TagLib::ID3v2::Tag *v2=mpeg->ID3v2Tag(false);
         bool haveV1=v1 && (!v1->title().isEmpty() || !v1->artist().isEmpty() || !v1->album().isEmpty());
-        bool isID3v24=v2 && isId3V24(v2->header());
-        return mpeg->save((haveV1 ? TagLib::MPEG::File::ID3v1 : 0)|TagLib::MPEG::File::ID3v2, true, isID3v24 ? 4 : 3) ? Update_Modified : Update_Failed;
+        #ifdef TAGLIB_CAN_SAVE_ID3VER
+        TagLib::ID3v2::Tag *v2=mpeg->ID3v2Tag(false);
+        int ver=v2 && isId3V24(v2->header()) ? 4 : 3;
+        return mpeg->save((haveV1 ? TagLib::MPEG::File::ID3v1 : 0)|TagLib::MPEG::File::ID3v2, true, ver) ? Update_Modified : Update_Failed;
+        #else
+        return mpeg->save((haveV1 ? TagLib::MPEG::File::ID3v1 : 0)|TagLib::MPEG::File::ID3v2, true) ? Update_Modified : Update_Failed;
+        #endif
     }
     return fileref.file()->save() ? Update_Modified : Update_Failed;
 }
