@@ -32,10 +32,12 @@
 #include "settings.h"
 #include "mpdconnection.h"
 #include "utils.h"
-#include "lyricspage.h"
+#include "songview.h"
 #include "localize.h"
 #include "messagebox.h"
 #include "icons.h"
+#include "basicitemdelegate.h"
+#include "cuefile.h"
 #include <QTimer>
 #include <QFile>
 #include <QDir>
@@ -59,10 +61,19 @@ TrackOrganiser::TrackOrganiser(QWidget *parent)
     QWidget *mainWidet = new QWidget(this);
     setupUi(mainWidet);
     setMainWidget(mainWidet);
-    configFilename->setIcon(Icons::configureIcon);
+    configFilename->setIcon(Icons::self()->configureIcon);
     setButtonGuiItem(Ok, GuiItem(i18n("Rename"), "edit-rename"));
     connect(this, SIGNAL(update()), MPDConnection::self(), SLOT(update()));
     progress->setVisible(false);
+    files->setItemDelegate(new BasicItemDelegate(files));
+    files->setAlternatingRowColors(false);
+    files->setContextMenuPolicy(Qt::ActionsContextMenu);
+    files->setSelectionMode(QAbstractItemView::ExtendedSelection);
+    removeAct=new Action(i18n("Remove From List"), files);
+    removeAct->setEnabled(false);
+    files->addAction(removeAct);
+    connect(files, SIGNAL(itemSelectionChanged()), SLOT(controlRemoveAct()));
+    connect(removeAct, SIGNAL(triggered(bool)), SLOT(removeItems()));
 }
 
 TrackOrganiser::~TrackOrganiser()
@@ -72,9 +83,17 @@ TrackOrganiser::~TrackOrganiser()
 
 void TrackOrganiser::show(const QList<Song> &songs, const QString &udi)
 {
-    Q_UNUSED(udi)
+    foreach (const Song &s, songs) {
+        if (!CueFile::isCue(s.file)) {
+           origSongs.append(s);
+        }
+    }
+
+    if (origSongs.isEmpty()) {
+        deleteLater();
+        return;
+    }
 
-    origSongs=songs;
     #ifdef ENABLE_DEVICES_SUPPORT
     if (udi.isEmpty()) {
         opts.load(MPDConnectionDetails::configGroupName(MPDConnection::self()->getDetails().name), true);
@@ -90,6 +109,7 @@ void TrackOrganiser::show(const QList<Song> &songs, const QString &udi)
         opts=dev->options();
     }
     #else
+    Q_UNUSED(udi)
     opts.load(MPDConnectionDetails::configGroupName(MPDConnection::self()->getDetails().name), true);
     #endif
     qSort(origSongs);
@@ -120,7 +140,7 @@ void TrackOrganiser::slotButtonClicked(int button)
     case Cancel:
         if (!optionsBox->isEnabled()) {
             paused=true;
-            if (MessageBox::No==MessageBox::questionYesNo(this, i18n("Cancel renaming of files?"))) {
+            if (MessageBox::No==MessageBox::questionYesNo(this, i18n("Abort renaming of files?"), i18n("Abort"), GuiItem(i18n("Abort")), StdGuiItem::cancel())) {
                 paused=false;
                 QTimer::singleShot(0, this, SLOT(renameFile()));
                 return;
@@ -234,8 +254,8 @@ void TrackOrganiser::renameFile()
             if (autoSkip) {
                 skip=true;
             } else {
-                switch(MessageBox::questionYesNoCancel(this, i18n("Destination file already exists!<br/>%1").arg(dest),
-                                                       QString(), GuiItem(i18n("Skip")), GuiItem("Auto Skip"))) {
+                switch(MessageBox::questionYesNoCancel(this, i18n("Destination file already exists!<br/>%1", dest),
+                                                       QString(), GuiItem(i18n("Skip")), GuiItem(i18n("Auto Skip")))) {
                 case MessageBox::Yes:
                     skip=true;
                     break;
@@ -256,8 +276,8 @@ void TrackOrganiser::renameFile()
                 if (autoSkip) {
                     skip=true;
                 } else {
-                    switch(MessageBox::questionYesNoCancel(this, i18n("Failed to create destination folder!<br/>%1").arg(dir.absolutePath()),
-                                                           QString(), GuiItem(i18n("Skip")), GuiItem("Auto Skip"))) {
+                    switch(MessageBox::questionYesNoCancel(this, i18n("Failed to create destination folder!<br/>%1", dir.absolutePath()),
+                                                           QString(), GuiItem(i18n("Skip")), GuiItem(i18n("Auto Skip")))) {
                     case MessageBox::Yes:
                         skip=true;
                         break;
@@ -277,8 +297,8 @@ void TrackOrganiser::renameFile()
             if (autoSkip) {
                 skip=true;
             } else {
-                switch(MessageBox::questionYesNoCancel(this, i18n("Failed to rename %1 to %2").arg(source).arg(dest),
-                                                       QString(), GuiItem(i18n("Skip")), GuiItem("Auto Skip"))) {
+                switch(MessageBox::questionYesNoCancel(this, i18n("Failed to rename %1 to %2", source, dest),
+                                                       QString(), GuiItem(i18n("Skip")), GuiItem(i18n("Auto Skip")))) {
                 case MessageBox::Yes:
                     skip=true;
                     break;
@@ -294,8 +314,8 @@ void TrackOrganiser::renameFile()
 
         // If file was renamed, then also rename any lyrics file...
         if (renamed) {
-            QString lyricsSource=Utils::changeExtension(source, LyricsPage::constExtension);
-            QString lyricsDest=Utils::changeExtension(dest, LyricsPage::constExtension);
+            QString lyricsSource=Utils::changeExtension(source, SongView::constExtension);
+            QString lyricsDest=Utils::changeExtension(dest, SongView::constExtension);
 
             if (QFile::exists(lyricsSource) && !QFile::exists(lyricsDest)) {
                 QFile::rename(lyricsSource, lyricsDest);
@@ -346,6 +366,31 @@ void TrackOrganiser::renameFile()
     }
 }
 
+void TrackOrganiser::controlRemoveAct()
+{
+    removeAct->setEnabled(files->topLevelItemCount()>1 && !files->selectedItems().isEmpty());
+}
+
+void TrackOrganiser::removeItems()
+{
+    if (files->topLevelItemCount()<1) {
+        return;
+    }
+
+    if (MessageBox::Yes==MessageBox::questionYesNo(this, i18n("Remove the selected tracks from the list?"),
+                                                   i18n("Remove Tracks"), StdGuiItem::remove(), StdGuiItem::cancel())) {
+
+        QList<QTreeWidgetItem *> selection=files->selectedItems();
+        foreach (QTreeWidgetItem *item, selection) {
+            int idx=files->indexOfTopLevelItem(item);
+            if (idx>-1 && idx<origSongs.count()) {
+                origSongs.removeAt(idx);
+                delete files->takeTopLevelItem(idx);
+            }
+        }
+    }
+}
+
 void TrackOrganiser::finish(bool ok)
 {
     if (updated) {
