@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2012 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2013 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -24,7 +24,7 @@
 #ifndef __ACTION_LABEL_H__
 #define __ACTION_LABEL_H__
 
-#include <QtGui/QLabel>
+#include <QLabel>
 
 class QTimer;
 class QLabel;
