@@ -52,13 +52,16 @@ static QString encode(const QImage &img)
 }
 
 #ifndef Q_OS_WIN
-static QStringList iconThemes;
-static void themes(const QString &theme)
+static void themes(const QString &theme, QStringList &iconThemes)
 {
     if (iconThemes.contains(theme)) {
         return;
     }
+    QString lower=theme.toLower();
     iconThemes << theme;
+    if (lower!=theme) {
+        iconThemes << lower;
+    }
     QStringList paths=QIcon::themeSearchPaths();
     QString key("Inherits=");
     foreach (const QString &p, paths) {
@@ -70,7 +73,7 @@ static void themes(const QString &theme)
                 if (line.startsWith(key)) {
                     QStringList inherited=line.mid(key.length()).split(",", QString::SkipEmptyParts);
                     foreach (const QString &i, inherited) {
-                        themes(i);
+                        themes(i, iconThemes);
                     }
                     return;
                 }
@@ -79,14 +82,14 @@ static void themes(const QString &theme)
     }
 }
 
-static void initIconThemes()
+void CoverWidget::initIconThemes()
 {
     if (iconThemes.isEmpty()) {
-        themes(QIcon::themeName());
+        themes(Icon::currentTheme(), iconThemes);
     }
 }
 
-static QString findIcon(const QStringList &names)
+QString CoverWidget::findIcon(const QStringList &names)
 {
     initIconThemes();
     QList<int> sizes=QList<int>() << 256 << 128 << 64 << 48 << 32 << 24 << 22;
@@ -138,8 +141,8 @@ CoverWidget::CoverWidget(QWidget *parent)
     , valid(false)
     , pressed(false)
 {
-    connect(Covers::self(), SIGNAL(cover(const Song &, const QImage &, const QString &)), SLOT(coverRetreived(const Song &, const QImage &, const QString &)));
-    connect(Covers::self(), SIGNAL(coverUpdated(const Song &, const QImage &, const QString &)), SLOT(coverRetreived(const Song &, const QImage &, const QString &)));
+    connect(Covers::self(), SIGNAL(cover(const Song &, const QImage &, const QString &)), SLOT(coverRetrieved(const Song &, const QImage &, const QString &)));
+    connect(Covers::self(), SIGNAL(coverUpdated(const Song &, const QImage &, const QString &)), SLOT(coverRetrieved(const Song &, const QImage &, const QString &)));
     installEventFilter(this);
     QTimer::singleShot(0, this, SLOT(init())); // Need to do this after constructed, so that size is set....
     setStyleSheet(QString("QLabel {border: %1px solid transparent} QToolTip {background-color:#111111; color: #DDDDDD}").arg(constBorder));
@@ -156,12 +159,12 @@ const QPixmap & CoverWidget::stdPixmap(bool stream)
     if (pix.isNull()) {
         QSize s=size()-QSize(constBorder*2, constBorder*2);
         int iconSize=s.width()<=128 ? 128 : 256;
-        pix = (stream ? Icons::streamIcon : Icons::albumIcon).pixmap(iconSize, iconSize).scaled(s, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
+        pix = (stream ? Icons::self()->streamIcon : Icons::self()->albumIcon).pixmap(iconSize, iconSize).scaled(s, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
 
         #ifndef Q_OS_WIN
         QString &file=stream ? noStreamCoverFileName : noCoverFileName;
         if (stream &file.isEmpty()) {
-            QString iconFile=QString(INSTALL_PREFIX"/share/")+QCoreApplication::applicationName()+"/streamicons/stream.png";
+            QString iconFile=QString(INSTALL_PREFIX"/share/")+QCoreApplication::applicationName()+"/icons/stream.png";
             if (QFile::exists(iconFile)) {
                 file=iconFile;
             }
@@ -202,6 +205,7 @@ void CoverWidget::update(const Song &s)
                 coverFileName=cImg.fileName;
                 emit coverImage(cImg.img);
                 emit coverFile(cImg.fileName);
+                emit albumCover(cImg.img);
             } else {
                 // We ned to set the image here, so that TrayItem gets the correct 'noCover' image
                 // ...but if Covers does eventually download a cover, we dont want valid->noCover->valid
@@ -214,6 +218,7 @@ void CoverWidget::update(const Song &s)
             img=isStream ? noStreamCover.toImage() : noCover.toImage();
             emit coverImage(img);
             emit coverFile(coverFileName);
+            emit albumCover(QImage());
         }
     }
 }
@@ -223,7 +228,7 @@ void CoverWidget::init()
     update(stdPixmap(false));
 }
 
-void CoverWidget::coverRetreived(const Song &s, const QImage &img, const QString &file)
+void CoverWidget::coverRetrieved(const Song &s, const QImage &img, const QString &file)
 {
     if (!s.isArtistImageRequest() && s.albumArtist()==current.albumArtist() && s.album==current.album) {
         valid=!img.isNull();
@@ -232,12 +237,14 @@ void CoverWidget::coverRetreived(const Song &s, const QImage &img, const QString
             coverFileName=file;
             emit coverImage(img);
             emit coverFile(file);
+            emit albumCover(img);
         } else {
             bool stream=current.isStream() && !current.isCdda();
             update(stdPixmap(stream));
             coverFileName=stream ? noStreamCoverFileName : noCoverFileName;
             emit coverImage(QImage());
             emit coverFile(coverFileName);
+            emit albumCover(QImage());
         }
     }
 }
@@ -246,7 +253,7 @@ bool CoverWidget::eventFilter(QObject *object, QEvent *event)
 {
     switch(event->type()) {
     case QEvent::ToolTip: {
-        if (current.isEmpty()) {
+        if (current.isEmpty() || (current.isStream() && !current.isCantataStream() && !current.isCdda())) {
             setToolTip(QString());
             break;
         }
@@ -254,7 +261,7 @@ bool CoverWidget::eventFilter(QObject *object, QEvent *event)
 
         toolTip+=i18n("<tr><td align=\"right\"><b>Artist:</b></td><td>%1</td></tr>"
                       "<tr><td align=\"right\"><b>Album:</b></td><td>%2</td></tr>"
-                      "<tr><td align=\"right\"><b>Year:</b></td><td>%3</td></tr>").arg(current.artist).arg(current.album).arg(current.year);
+                      "<tr><td align=\"right\"><b>Year:</b></td><td>%3</td></tr>", current.artist, current.album, current.year);
         toolTip+="</table>";
         if (!img.isNull()) {
             if (img.size().width()>Covers::constMaxSize.width() || img.size().height()>Covers::constMaxSize.height() ||
