@@ -48,13 +48,16 @@ public:
     const QImage &image() const { return img; }
 
 Q_SIGNALS:
+    // coverImage /might/ contain the default images, if no cover was found
     void coverImage(const QImage &img);
+    // albumCover will only ever contain a valid cover, or a null image
+    void albumCover(const QImage &img);
     void coverFile(const QString &name);
     void clicked();
 
 private Q_SLOTS:
     void init();
-    void coverRetreived(const Song &s, const QImage &img, const QString &file);
+    void coverRetrieved(const Song &s, const QImage &img, const QString &file);
 
 private:
     const QPixmap & stdPixmap(bool stream);
@@ -63,6 +66,10 @@ private:
     bool eventFilter(QObject *object, QEvent *event);
     void resizeEvent(QResizeEvent *e);
 //     void paintEvent(QPaintEvent *e);
+    #ifndef Q_OS_WIN
+    void initIconThemes();
+    QString findIcon(const QStringList &names);
+    #endif
 
 private:
     bool empty;
@@ -77,6 +84,9 @@ private:
     QPixmap noCover;
     QString noStreamCoverFileName;
     QString noCoverFileName;
+    #ifndef Q_OS_WIN
+    QStringList iconThemes;
+    #endif
 };
 
 #endif
