@@ -1,7 +1,7 @@
 /*
  * Cantata
  *
- * Copyright (c) 2011-2012 Craig Drummond <craig.p.drummond@gmail.com>
+ * Copyright (c) 2011-2013 Craig Drummond <craig.p.drummond@gmail.com>
  *
  * ----
  *
@@ -24,10 +24,10 @@
 #ifndef GENRECOMBO_H
 #define GENRECOMBO_H
 
-#include <QtGui/QComboBox>
-#include <QtCore/QSet>
+#include "combobox.h"
+#include <QSet>
 
-class GenreCombo : public QComboBox
+class GenreCombo : public ComboBox
 {
     Q_OBJECT
 public:
@@ -36,7 +36,7 @@ public:
 
     const QSet<QString> & entries() const { return genres; }
 
-private Q_SLOTS:
+public Q_SLOTS:
     void update(const QSet<QString> &g);
 
 private:
