@@ -229,7 +229,7 @@ public:
         QString duration=song.time>0 ? Song::formattedTime(song.time) : QString();
         bool stream=!isCollection && (song.isStream() && !song.isCantataStream());
         bool audiocd=stream && song.isCdda();
-        bool isEmpty=song.title.isEmpty() & song.artist.isEmpty() && !song.file.isEmpty();
+        bool isEmpty=song.title.isEmpty() && song.artist.isEmpty() && !song.file.isEmpty();
         QString trackTitle=isEmpty
                         ? song.file
                         : !song.albumartist.isEmpty() && song.albumartist != song.artist
@@ -242,6 +242,7 @@ public:
         QFontMetrics fm(f);
         int textHeight=fm.height();
 
+
         if (isCollection) {
             title=index.data(Qt::DisplayRole).toString();
         } else if (AlbumHeader==type) {
@@ -259,21 +260,28 @@ public:
                 title=i18n("Unknown");
                 track=trackTitle;
             } else {
-                QString album=song.album;
                 quint16 year=Song::albumYear(song);
 
                 if (year>0) {
-                    title=i18nc("artist - album (albumYear)", "%1 - %2 (%3)", song.albumArtist(), album, year);
+                    if (song.isFromOnlineService()) {
+                        title=song.album+QLatin1String(" (")+QString::number(year)+QLatin1Char(')');
+                    } else {
+                        title=i18nc("artist - album (albumYear)", "%1 - %2 (%3)", song.albumArtist(), song.album, QString::number(year));
+                    }
                 } else {
-                    title=i18nc("artist - album", "%1 - %2", song.albumArtist(), album);
+                    if (song.isFromOnlineService()) {
+                        title=song.album;
+                    } else {
+                        title=i18nc("artist - album", "%1 - %2", song.albumArtist(), song.album);
+                    }
                 }
-                track=formatNumber(song.track)+QChar(' ')+trackTitle;
+                track=song.track ? formatNumber(song.track)+QChar(' ')+trackTitle : trackTitle;
             }
         } else {
             if (stream) {
                 track=streamText(song, trackTitle);
             } else {
-                track=formatNumber(song.track)+QChar(' ')+trackTitle;
+                track=song.track ? formatNumber(song.track)+QChar(' ')+trackTitle : trackTitle;
             }
         }
 
@@ -619,13 +627,17 @@ void GroupedView::toggle(const QModelIndex &idx)
 
 // Calculate list of selected indexes. If a collapsed album is selected, we also pretend all of its tracks
 // are selected.
-QModelIndexList GroupedView::selectedIndexes() const
+QModelIndexList GroupedView::selectedIndexes(bool sorted) const
 {
-    QModelIndexList indexes = selectionModel()->selectedRows();
-    QSet<QModelIndex> allIndexes;
+    QModelIndexList indexes = TreeView::selectedIndexes(sorted);
+    QSet<QModelIndex> indexSet;
+    QModelIndexList sel;
 
     foreach (const QModelIndex &idx, indexes) {
-        allIndexes.insert(idx);
+        if (!indexSet.contains(idx)) {
+            indexSet.insert(idx);
+            sel.append(idx);
+        }
         if (!idx.data(GroupedView::Role_IsCollection).toBool()) {
             quint16 key=idx.data(GroupedView::Role_Key).toUInt();
             quint32 collection=idx.data(GroupedView::Role_CollectionId).toUInt();
@@ -638,7 +650,10 @@ QModelIndexList GroupedView::selectedIndexes() const
                         quint32 nextCollection=idx.data(GroupedView::Role_CollectionId).toUInt();
 
                         if (nextCollection==collection && nextKey==key) {
-                            allIndexes.insert(next);
+                            if (!indexSet.contains(next)) {
+                                indexSet.insert(next);
+                                sel.append(next);
+                            }
                         } else {
                             break;
                         }
@@ -649,7 +664,7 @@ QModelIndexList GroupedView::selectedIndexes() const
             }
         }
     }
-    return allIndexes.toList();
+    return sel;
 }
 
 // If we are dropping onto a collapsed album, and we are in the bottom 1/2 of the row - then
