@@ -32,10 +32,27 @@
 #include <QDir>
 #include <QFile>
 #include <math.h>
-#if !defined ENABLE_KDE_SUPPORT && !defined Q_OS_WIN
+#ifndef Q_OS_WIN
 #include "gtkstyle.h"
 #endif
 
+#ifdef ENABLE_KDE_SUPPORT
+K_GLOBAL_STATIC(Icons, instance)
+#endif
+
+Icons * Icons::self()
+{
+    #ifdef ENABLE_KDE_SUPPORT
+    return instance;
+    #else
+    static Icons *instance=0;
+    if(!instance) {
+        instance=new Icons;
+    }
+    return instance;
+    #endif
+}
+
 static QList<int> constStdSizes=QList<int>() << 16 << 22 << 32 << 48;
 static const double constDisabledOpacity=0.5;
 static const int constShadeFactor=75;
@@ -288,69 +305,6 @@ static Icon createRecolourableIcon(const QString &name, const QColor &stdColor,
     return icon;
 }
 
-#ifndef ENABLE_KDE_SUPPORT
-Icon Icons::appIcon;
-Icon Icons::shortcutsIcon;
-#endif
-Icon Icons::artistIcon;
-Icon Icons::albumIcon;
-Icon Icons::playlistIcon;
-Icon Icons::dynamicRuleIcon;
-Icon Icons::singleIcon;
-Icon Icons::consumeIcon;
-Icon Icons::repeatIcon;
-Icon Icons::shuffleIcon;
-Icon Icons::libraryIcon;
-Icon Icons::streamCategoryIcon;
-Icon Icons::radioStreamIcon;
-Icon Icons::addRadioStreamIcon;
-Icon Icons::streamIcon;
-Icon Icons::configureIcon;
-Icon Icons::connectIcon;
-Icon Icons::disconnectIcon;
-Icon Icons::speakerIcon;
-Icon Icons::variousArtistsIcon;
-Icon Icons::editIcon;
-Icon Icons::clearListIcon;
-Icon Icons::menuIcon;
-#ifdef ENABLE_ONLINE_SERVICES
-Icon Icons::jamendoIcon;
-Icon Icons::magnatuneIcon;
-#endif
-Icon Icons::filesIcon;
-Icon Icons::cancelIcon;
-Icon Icons::importIcon;
-
-Icon Icons::playqueueIcon;
-Icon Icons::artistsIcon;
-Icon Icons::albumsIcon;
-Icon Icons::foldersIcon;
-Icon Icons::playlistsIcon;
-Icon Icons::dynamicIcon;
-Icon Icons::streamsIcon;
-#ifdef ENABLE_ONLINE_SERVICES
-Icon Icons::onlineIcon;
-#endif
-Icon Icons::lyricsIcon;
-Icon Icons::infoIcon;
-#ifdef ENABLE_DEVICES_SUPPORT
-Icon Icons::devicesIcon;
-#endif
-
-Icon Icons::toolbarMenuIcon;
-Icon Icons::toolbarPrevIcon;
-Icon Icons::toolbarPlayIcon;
-Icon Icons::toolbarPauseIcon;
-Icon Icons::toolbarNextIcon;
-Icon Icons::toolbarStopIcon;
-Icon Icons::toolbarVolumeMutedIcon;
-Icon Icons::toolbarVolumeLowIcon;
-Icon Icons::toolbarVolumeMediumIcon;
-Icon Icons::toolbarVolumeHighIcon;
-#ifdef PHONON_FOUND
-Icon Icons::toolbarStreamIcon;
-#endif
-
 static QColor stdColor;
 static QColor highlightColor;
 
@@ -400,40 +354,33 @@ static Icon loadSidebarIcon(const QString &name, const QColor &normal, const QCo
     return i;
 }
 
-void Icons::init()
+Icons::Icons()
 {
     calcIconColors(stdColor, highlightColor);
     singleIcon=createSingleIcon(stdColor, highlightColor);
     consumeIcon=createConsumeIcon(stdColor, highlightColor);
     menuIcon=createMenuIcon(stdColor, highlightColor);
-    libraryIcon=Icon("cantata-view-media-library");
-    streamCategoryIcon=Icon(QLatin1String("oxygen")==QIcon::themeName() ? "inode-directory" : "folder-music");
-    radioStreamIcon=Icon("cantata-view-radiostream");
-    addRadioStreamIcon=Icon("cantata-radiostream-add");
-    QString iconFile=QString(INSTALL_PREFIX"/share/")+QCoreApplication::applicationName()+"/streamicons/stream.png";
+    streamCategoryIcon=Icon(QLatin1String("oxygen")==Icon::currentTheme().toLower() ? "inode-directory" : "folder-music");
+    QString iconFile=QString(INSTALL_PREFIX"/share/")+QCoreApplication::applicationName()+"/icons/stream.png";
     if (QFile::exists(iconFile)) {
         streamIcon.addFile(iconFile);
     }
     if (streamIcon.isNull()) {
         streamIcon=Icon("applications-internet");
     }
-    artistIcon=Icon("view-media-artist");
     albumIcon=Icon("media-optical");
+    audioFileIcon=Icon("audio-x-generic");
     playlistIcon=Icon("view-media-playlist");
     dynamicRuleIcon=Icon("media-playlist-shuffle");
     configureIcon=Icon("configure");
     connectIcon=Icon("dialog-ok");
     disconnectIcon=Icon("media-eject");
     speakerIcon=Icon("speaker");
-    variousArtistsIcon=Icon("cantata-view-media-artist-various");
     editIcon=Icon("document-edit");
+    searchIcon=Icon("edit-find");
     clearListIcon=Icon("edit-clear-list");
     repeatIcon=createRecolourableIcon("repeat", stdColor, highlightColor);
     shuffleIcon=createRecolourableIcon("shuffle", stdColor, highlightColor);
-    #ifdef ENABLE_ONLINE_SERVICES
-    jamendoIcon=Icon("cantata-view-services-jamendo");
-    magnatuneIcon=Icon("cantata-view-services-jamendo");
-    #endif
     filesIcon=Icon("document-multiple");
     cancelIcon=Icon("dialog-cancel");
     importIcon=Icon("document-import");
@@ -443,32 +390,19 @@ void Icons::init()
     if (importIcon.isNull()) {
         importIcon=Icon("down");
     }
+    libraryIcon=Icon::create("lib", constStdSizes);
+    radioStreamIcon=Icon::create("radio", constStdSizes);
+    addRadioStreamIcon=Icon::create("addradio", constStdSizes);
+    variousArtistsIcon=Icon::create("va", QList<int>() << 16 << 22 << 32 << 48 << 64 << 128);
+    artistIcon=Icon::create("artist", QList<int>() << 16 << 22 << 32 << 48 << 64 << 128);
     #ifndef ENABLE_KDE_SUPPORT
+    QList<int> appSizes=QList<int>() << 16 << 22 << 24 << 32 << 48 << 64;
+    foreach (int s, appSizes) {
+        appIcon.addFile(QString(":cantata%1.png").arg(s), QSize(s, s));
+    }
     appIcon.addFile(":cantata.svg");
+
     shortcutsIcon=Icon("preferences-desktop-keyboard");
-    if (libraryIcon.isNull()) {
-        libraryIcon=Icon::create("lib", constStdSizes);
-    }
-    if (radioStreamIcon.isNull()) {
-        radioStreamIcon=Icon::create("radio", constStdSizes);
-    }
-    if (addRadioStreamIcon.isNull()) {
-        addRadioStreamIcon=Icon::create("addradio", constStdSizes);
-    }
-    if (variousArtistsIcon.isNull()) {
-        variousArtistsIcon=Icon::create("va", QList<int>() << 16 << 22 << 32 << 48 << 64 << 128);
-    }
-    if (artistIcon.isNull()) {
-        artistIcon=Icon::create("artist", QList<int>() << 16 << 22 << 32 << 48 << 64 << 128);
-    }
-    #ifdef ENABLE_ONLINE_SERVICES
-    if (jamendoIcon.isNull()) {
-        jamendoIcon=Icon::create("jamendo", constStdSizes);
-    }
-    if (magnatuneIcon.isNull()) {
-        magnatuneIcon=Icon::create("magnatune", constStdSizes);
-    }
-    #endif
     #ifndef Q_OS_WIN
     if (shortcutsIcon.isNull()) {
         shortcutsIcon=Icon("keyboard");
@@ -481,10 +415,10 @@ void Icons::init()
     }
     if (connectIcon.isNull()) {
         connectIcon=Icon("gtk-stock-ok");
+        if (connectIcon.isNull()) {
+            connectIcon=Icon("go-bottom");
+        }
     }
-    //if (disconnectIcon.isNull()) {
-    //    disconnectIcon=Icon("media-eject");
-    //}
     if (speakerIcon.isNull()) {
         speakerIcon=Icon("audio-speakers");
         if (speakerIcon.isNull()) {
@@ -518,7 +452,6 @@ void Icons::init()
     if (streamCategoryIcon.isNull()) {
         streamCategoryIcon=libraryIcon;
     }
-
 }
 
 void Icons::initSidebarIcons()
@@ -533,11 +466,8 @@ void Icons::initSidebarIcons()
         playlistsIcon=loadSidebarIcon("playlists", textCol, highlightedTexCol);
         dynamicIcon=loadSidebarIcon("dynamic", textCol, highlightedTexCol);
         streamsIcon=loadSidebarIcon("streams", textCol, highlightedTexCol);
-        #ifdef ENABLE_ONLINE_SERVICES
         onlineIcon=loadSidebarIcon("online", textCol, highlightedTexCol);
-        #endif
-        lyricsIcon=loadSidebarIcon("lyrics", textCol, highlightedTexCol);
-        infoIcon=loadSidebarIcon("info", textCol, highlightedTexCol);
+        infoSidebarIcon=loadSidebarIcon("info", textCol, highlightedTexCol);
         #ifdef ENABLE_DEVICES_SUPPORT
         devicesIcon=loadSidebarIcon("devices", textCol, highlightedTexCol);
         #endif
@@ -549,17 +479,16 @@ void Icons::initSidebarIcons()
         playlistsIcon=playlistIcon;
         dynamicIcon=dynamicRuleIcon;
         streamsIcon=radioStreamIcon;
-        #ifdef ENABLE_ONLINE_SERVICES
         onlineIcon=Icon("applications-internet");
-        #endif
-        lyricsIcon=Icon("view-media-lyrics");
-        infoIcon=Icon("dialog-information");
+        if (QLatin1String("gnome")==Icon::currentTheme().toLower()) {
+            QColor col=QApplication::palette().color(QPalette::Active, QPalette::ButtonText);
+            infoSidebarIcon=loadSidebarIcon("info", col, col);
+        } else {
+            infoSidebarIcon=Icon("dialog-information");
+        }
         #ifdef ENABLE_DEVICES_SUPPORT
         devicesIcon=Icon("multimedia-player");
         #endif
-        if (lyricsIcon.isNull()) {
-            lyricsIcon=Icon("text-x-generic");
-        }
     }
 }
 
@@ -611,7 +540,7 @@ void Icons::initToolbarIcons(const QColor &color, bool forceLight)
         toolbarMenuIcon=menuIcon;
     }
 
-    #if !defined ENABLE_KDE_SUPPORT && !defined Q_OS_WIN
+    #ifndef Q_OS_WIN
     if (light && GtkStyle::useSymbolicIcons()) {
         toolbarPrevIcon=Icon("media-skip-backward-symbolic");
         toolbarPlayIcon=Icon("media-playback-start-symbolic");
@@ -622,8 +551,27 @@ void Icons::initToolbarIcons(const QColor &color, bool forceLight)
         toolbarVolumeLowIcon=Icon("audio-volume-low-symbolic");
         toolbarVolumeMediumIcon=Icon("audio-volume-medium-symbolic");
         toolbarVolumeHighIcon=Icon("audio-volume-high-symbolic");
-    }
+        QColor col(196, 196, 196);
+        infoIcon=loadSidebarIcon("info", col, col);
+    } else
     #endif
+        if (QLatin1String("gnome")==Icon::currentTheme().toLower()) {
+            QColor col=QApplication::palette().color(QPalette::Active, QPalette::ButtonText);
+            infoIcon=loadSidebarIcon("info", col, col);
+        }
+
+    if (infoIcon.isNull()) {
+        infoIcon=Icon("dialog-information");
+    }
+
+    #if !defined ENABLE_KDE_SUPPORT && !defined Q_OS_WIN
+    if (QLatin1String("gnome")==Icon::currentTheme().toLower()) {
+        QColor col=QApplication::palette().color(QPalette::Active, QPalette::ButtonText);
+        contextIcon=loadSidebarIcon("info", col, col);
+    } else
+    #endif
+        contextIcon=Icon("dialog-information");
+
     if (toolbarPrevIcon.isNull()) {
         toolbarPrevIcon=Icon::getMediaIcon("media-skip-backward");
     } else {
@@ -661,8 +609,4 @@ void Icons::initToolbarIcons(const QColor &color, bool forceLight)
     if (toolbarVolumeHighIcon.isNull()) {
         toolbarVolumeHighIcon=Icon("audio-volume-high");
     }
-
-    #ifdef PHONON_FOUND
-    toolbarStreamIcon=streamIcon;
-    #endif
 }
